/*
 * --------------------------------------------------------------------------------------------------------------------
 * <copyright company="Aspose">
 *   Copyright (c) 2018 Aspose.Slides for Cloud
 * </copyright>
 * <summary>
 *   Permission is hereby granted, free of charge, to any person obtaining a copy
 *  of this software and associated documentation files (the "Software"), to deal
 *  in the Software without restriction, including without limitation the rights
 *  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 *  copies of the Software, and to permit persons to whom the Software is
 *  furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included in all
 *  copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 *  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 *  SOFTWARE.
 * </summary>
 * --------------------------------------------------------------------------------------------------------------------
 */

package com.aspose.slides.api;

import com.aspose.slides.ApiCallback;
import com.aspose.slides.ApiClient;
import com.aspose.slides.ApiException;
import com.aspose.slides.ApiResponse;
import com.aspose.slides.Configuration;
import com.aspose.slides.FileInfo;
import com.aspose.slides.Pair;
import com.aspose.slides.ProgressRequestBody;
import com.aspose.slides.ProgressResponseBody;
import com.aspose.slides.auth.NeedRepeatRequestException;

import com.google.gson.reflect.TypeToken;

import java.io.IOException;


import com.aspose.slides.model.ApiInfo;
import com.aspose.slides.model.Chart;
import com.aspose.slides.model.ChartCategory;
import com.aspose.slides.model.ColorScheme;
import com.aspose.slides.model.DataPoint;
import com.aspose.slides.model.DiscUsage;
import com.aspose.slides.model.Document;
import com.aspose.slides.model.DocumentProperties;
import com.aspose.slides.model.DocumentProperty;
import com.aspose.slides.model.DocumentReplaceResult;
import com.aspose.slides.model.Effect;
import com.aspose.slides.model.EntityExists;
import com.aspose.slides.model.ExportOptions;
import java.io.File;
import com.aspose.slides.model.FileVersions;
import com.aspose.slides.model.FilesList;
import com.aspose.slides.model.FilesUploadResult;
import com.aspose.slides.model.FontScheme;
import com.aspose.slides.model.FormatScheme;
import com.aspose.slides.model.GeometryPaths;
import com.aspose.slides.model.HeaderFooter;
import com.aspose.slides.model.IShapeExportOptions;
import com.aspose.slides.model.Images;
import com.aspose.slides.model.InteractiveSequence;
import com.aspose.slides.model.LayoutSlide;
import com.aspose.slides.model.LayoutSlides;
import com.aspose.slides.model.MasterSlide;
import com.aspose.slides.model.MasterSlides;
import com.aspose.slides.model.NotesSlide;
import com.aspose.slides.model.NotesSlideHeaderFooter;
import com.aspose.slides.model.ObjectExist;
import com.aspose.slides.model.OrderedMergeRequest;
import com.aspose.slides.model.Paragraph;
import com.aspose.slides.model.Paragraphs;
import com.aspose.slides.model.PictureFrame;
import com.aspose.slides.model.Pipeline;
import com.aspose.slides.model.Placeholder;
import com.aspose.slides.model.Placeholders;
import com.aspose.slides.model.Portion;
import com.aspose.slides.model.Portions;
import com.aspose.slides.model.PresentationsMergeRequest;
import com.aspose.slides.model.ProtectionProperties;
import com.aspose.slides.model.Sections;
import com.aspose.slides.model.Series;
import com.aspose.slides.model.Shape;
import com.aspose.slides.model.ShapeBase;
import com.aspose.slides.model.Shapes;
import com.aspose.slides.model.Slide;
import com.aspose.slides.model.SlideAnimation;
import com.aspose.slides.model.SlideBackground;
import com.aspose.slides.model.SlideCommentBase;
import com.aspose.slides.model.SlideComments;
import com.aspose.slides.model.SlideProperties;
import com.aspose.slides.model.SlideReplaceResult;
import com.aspose.slides.model.Slides;
import com.aspose.slides.model.SplitDocumentResult;
import com.aspose.slides.model.StorageExist;
import com.aspose.slides.model.TextBounds;
import com.aspose.slides.model.TextItems;
import com.aspose.slides.model.Theme;
import com.aspose.slides.model.ViewProperties;
import com.aspose.slides.model.*;

import java.lang.reflect.Type;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.LinkedHashMap;
import java.util.List;
import java.util.Map;

public class SlidesApi {
    public SlidesApi(Configuration configuration) {
        apiClient = new ApiClient(configuration);
    }

    public SlidesApi(String appSid, String appKey) {
        this(new Configuration(appSid, appKey));
    }

    /**
     * Build call for alignShapes
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call alignShapesCall(String name, Integer slideIndex, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling alignShapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling alignShapes(Async)");
        }
        // verify the required parameter 'alignmentType' is set
        if (alignmentType == null) {
            throw new ApiException("Missing the required parameter 'alignmentType' when calling alignShapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/align/{alignmentType}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "alignmentType" + "\\}", apiClient.objectToString(alignmentType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "alignToSlide", alignToSlide);
        apiClient.addQueryParameter(queryParams, "shapes", shapes);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Changes the placement of selected shapes on the slide. Aligns shapes to the margins or the edge of the slide or aligns them relative to each other.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes alignShapes(String name, Integer slideIndex, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = alignShapesWithHttpInfo(name, slideIndex, alignmentType, alignToSlide, shapes, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = alignShapesWithHttpInfo(name, slideIndex, alignmentType, alignToSlide, shapes, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Changes the placement of selected shapes on the slide. Aligns shapes to the margins or the edge of the slide or aligns them relative to each other.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> alignShapesWithHttpInfo(String name, Integer slideIndex, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = alignShapesCall(name, slideIndex, alignmentType, alignToSlide, shapes, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Changes the placement of selected shapes on the slide. Aligns shapes to the margins or the edge of the slide or aligns them relative to each other. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call alignShapesAsync(String name, Integer slideIndex, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = alignShapesCall(name, slideIndex, alignmentType, alignToSlide, shapes, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for alignSpecialSlideShapes
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call alignSpecialSlideShapesCall(String name, Integer slideIndex, SpecialSlideType slideType, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling alignSpecialSlideShapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling alignSpecialSlideShapes(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling alignSpecialSlideShapes(Async)");
        }
        // verify the required parameter 'alignmentType' is set
        if (alignmentType == null) {
            throw new ApiException("Missing the required parameter 'alignmentType' when calling alignSpecialSlideShapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/align/{alignmentType}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "alignmentType" + "\\}", apiClient.objectToString(alignmentType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "alignToSlide", alignToSlide);
        apiClient.addQueryParameter(queryParams, "shapes", shapes);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Changes the placement of selected shapes on the master slide. Aligns shapes to the margins or the edge of the slide or aligns them relative to each other.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes alignSpecialSlideShapes(String name, Integer slideIndex, SpecialSlideType slideType, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = alignSpecialSlideShapesWithHttpInfo(name, slideIndex, slideType, alignmentType, alignToSlide, shapes, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = alignSpecialSlideShapesWithHttpInfo(name, slideIndex, slideType, alignmentType, alignToSlide, shapes, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Changes the placement of selected shapes on the master slide. Aligns shapes to the margins or the edge of the slide or aligns them relative to each other.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> alignSpecialSlideShapesWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = alignSpecialSlideShapesCall(name, slideIndex, slideType, alignmentType, alignToSlide, shapes, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Changes the placement of selected shapes on the master slide. Aligns shapes to the margins or the edge of the slide or aligns them relative to each other. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call alignSpecialSlideShapesAsync(String name, Integer slideIndex, SpecialSlideType slideType, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = alignSpecialSlideShapesCall(name, slideIndex, slideType, alignmentType, alignToSlide, shapes, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for alignSubshapes
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call alignSubshapesCall(String name, Integer slideIndex, String path, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling alignSubshapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling alignSubshapes(Async)");
        }
        // verify the required parameter 'alignmentType' is set
        if (alignmentType == null) {
            throw new ApiException("Missing the required parameter 'alignmentType' when calling alignSubshapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/align/{alignmentType}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "alignmentType" + "\\}", apiClient.objectToString(alignmentType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "alignToSlide", alignToSlide);
        apiClient.addQueryParameter(queryParams, "shapes", shapes);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Changes the placement of selected shapes on the slide. Aligns shapes to the margins or the edge of the slide or aligns them relative to each other (for group shapes only).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes alignSubshapes(String name, Integer slideIndex, String path, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = alignSubshapesWithHttpInfo(name, slideIndex, path, alignmentType, alignToSlide, shapes, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = alignSubshapesWithHttpInfo(name, slideIndex, path, alignmentType, alignToSlide, shapes, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Changes the placement of selected shapes on the slide. Aligns shapes to the margins or the edge of the slide or aligns them relative to each other (for group shapes only).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> alignSubshapesWithHttpInfo(String name, Integer slideIndex, String path, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = alignSubshapesCall(name, slideIndex, path, alignmentType, alignToSlide, shapes, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Changes the placement of selected shapes on the slide. Aligns shapes to the margins or the edge of the slide or aligns them relative to each other (for group shapes only). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param alignmentType Alignment type that will be applied to the shapes. (required)
     * @param alignToSlide If true, shapes will be aligned relative to the slide edges. 
     * @param shapes Shapes indexes. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call alignSubshapesAsync(String name, Integer slideIndex, String path, ShapesAlignmentType alignmentType, Boolean alignToSlide, List<Integer> shapes, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = alignSubshapesCall(name, slideIndex, path, alignmentType, alignToSlide, shapes, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for convert
     * @param document Document data. (required)
     * @param format Export format. (required)
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be converted. If not specified, all slides are converted by default. 
     * @param options Export options. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call convertCall(byte[] document, ExportFormat format, String password, String storage, String fontsFolder, List<Integer> slides, ExportOptions options, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling convert(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling convert(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/convert/{format}"
            .replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);
        apiClient.addQueryParameter(queryParams, "slides", slides);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Convert presentation from request content to format specified.
     * 
     * @param document Document data. (required)
     * @param format Export format. (required)
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be converted. If not specified, all slides are converted by default. 
     * @param options Export options. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File convert(byte[] document, ExportFormat format, String password, String storage, String fontsFolder, List<Integer> slides, ExportOptions options) throws ApiException {
        try {
            ApiResponse<File> resp = convertWithHttpInfo(document, format, password, storage, fontsFolder, slides, options);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = convertWithHttpInfo(document, format, password, storage, fontsFolder, slides, options);
            return resp.getData();
        }
    }

    /**
     * Convert presentation from request content to format specified.
     * 
     * @param document Document data. (required)
     * @param format Export format. (required)
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be converted. If not specified, all slides are converted by default. 
     * @param options Export options. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> convertWithHttpInfo(byte[] document, ExportFormat format, String password, String storage, String fontsFolder, List<Integer> slides, ExportOptions options) throws ApiException {
        com.squareup.okhttp.Call call = convertCall(document, format, password, storage, fontsFolder, slides, options, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Convert presentation from request content to format specified. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param format Export format. (required)
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be converted. If not specified, all slides are converted by default. 
     * @param options Export options. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call convertAsync(byte[] document, ExportFormat format, String password, String storage, String fontsFolder, List<Integer> slides, ExportOptions options, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = convertCall(document, format, password, storage, fontsFolder, slides, options, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for convertAndSave
     * @param document Document data. (required)
     * @param format Export format. (required)
     * @param outPath Path to save result. (required)
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be converted. If not specified, all slides are converted by default. 
     * @param options Export options. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call convertAndSaveCall(byte[] document, ExportFormat format, String outPath, String password, String storage, String fontsFolder, List<Integer> slides, ExportOptions options, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling convertAndSave(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling convertAndSave(Async)");
        }
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling convertAndSave(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/convert/{format}"
            .replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);
        apiClient.addQueryParameter(queryParams, "slides", slides);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Convert presentation from request content to format specified.
     * 
     * @param document Document data. (required)
     * @param format Export format. (required)
     * @param outPath Path to save result. (required)
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be converted. If not specified, all slides are converted by default. 
     * @param options Export options. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void convertAndSave(byte[] document, ExportFormat format, String outPath, String password, String storage, String fontsFolder, List<Integer> slides, ExportOptions options) throws ApiException {
        try {
            convertAndSaveWithHttpInfo(document, format, outPath, password, storage, fontsFolder, slides, options);
        } catch (NeedRepeatRequestException e) {
            convertAndSaveWithHttpInfo(document, format, outPath, password, storage, fontsFolder, slides, options);
        }
    }

    /**
     * Convert presentation from request content to format specified.
     * 
     * @param document Document data. (required)
     * @param format Export format. (required)
     * @param outPath Path to save result. (required)
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be converted. If not specified, all slides are converted by default. 
     * @param options Export options. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> convertAndSaveWithHttpInfo(byte[] document, ExportFormat format, String outPath, String password, String storage, String fontsFolder, List<Integer> slides, ExportOptions options) throws ApiException {
        com.squareup.okhttp.Call call = convertAndSaveCall(document, format, outPath, password, storage, fontsFolder, slides, options, null, null);
        return apiClient.execute(call);
    }

    /**
     * Convert presentation from request content to format specified. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param format Export format. (required)
     * @param outPath Path to save result. (required)
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be converted. If not specified, all slides are converted by default. 
     * @param options Export options. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call convertAndSaveAsync(byte[] document, ExportFormat format, String outPath, String password, String storage, String fontsFolder, List<Integer> slides, ExportOptions options, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = convertAndSaveCall(document, format, outPath, password, storage, fontsFolder, slides, options, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for copyFile
     * @param srcPath Source file path e.g. '/folder/file.ext' (required)
     * @param destPath Destination file path (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param versionId File version ID to copy 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call copyFileCall(String srcPath, String destPath, String srcStorageName, String destStorageName, String versionId, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'srcPath' is set
        if (srcPath == null) {
            throw new ApiException("Missing the required parameter 'srcPath' when calling copyFile(Async)");
        }
        // verify the required parameter 'destPath' is set
        if (destPath == null) {
            throw new ApiException("Missing the required parameter 'destPath' when calling copyFile(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/file/copy/{srcPath}"
            .replaceAll("\\{" + "srcPath" + "\\}", apiClient.objectToString(srcPath));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "destPath", destPath);
        apiClient.addQueryParameter(queryParams, "srcStorageName", srcStorageName);
        apiClient.addQueryParameter(queryParams, "destStorageName", destStorageName);
        apiClient.addQueryParameter(queryParams, "versionId", versionId);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Copy file
     * 
     * @param srcPath Source file path e.g. '/folder/file.ext' (required)
     * @param destPath Destination file path (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param versionId File version ID to copy 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void copyFile(String srcPath, String destPath, String srcStorageName, String destStorageName, String versionId) throws ApiException {
        try {
            copyFileWithHttpInfo(srcPath, destPath, srcStorageName, destStorageName, versionId);
        } catch (NeedRepeatRequestException e) {
            copyFileWithHttpInfo(srcPath, destPath, srcStorageName, destStorageName, versionId);
        }
    }

    /**
     * Copy file
     * 
     * @param srcPath Source file path e.g. '/folder/file.ext' (required)
     * @param destPath Destination file path (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param versionId File version ID to copy 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> copyFileWithHttpInfo(String srcPath, String destPath, String srcStorageName, String destStorageName, String versionId) throws ApiException {
        com.squareup.okhttp.Call call = copyFileCall(srcPath, destPath, srcStorageName, destStorageName, versionId, null, null);
        return apiClient.execute(call);
    }

    /**
     * Copy file (asynchronously)
     * 
     * @param srcPath Source file path e.g. '/folder/file.ext' (required)
     * @param destPath Destination file path (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param versionId File version ID to copy 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call copyFileAsync(String srcPath, String destPath, String srcStorageName, String destStorageName, String versionId, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = copyFileCall(srcPath, destPath, srcStorageName, destStorageName, versionId, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for copyFolder
     * @param srcPath Source folder path e.g. '/src' (required)
     * @param destPath Destination folder path e.g. '/dst' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call copyFolderCall(String srcPath, String destPath, String srcStorageName, String destStorageName, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'srcPath' is set
        if (srcPath == null) {
            throw new ApiException("Missing the required parameter 'srcPath' when calling copyFolder(Async)");
        }
        // verify the required parameter 'destPath' is set
        if (destPath == null) {
            throw new ApiException("Missing the required parameter 'destPath' when calling copyFolder(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/folder/copy/{srcPath}"
            .replaceAll("\\{" + "srcPath" + "\\}", apiClient.objectToString(srcPath));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "destPath", destPath);
        apiClient.addQueryParameter(queryParams, "srcStorageName", srcStorageName);
        apiClient.addQueryParameter(queryParams, "destStorageName", destStorageName);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Copy folder
     * 
     * @param srcPath Source folder path e.g. '/src' (required)
     * @param destPath Destination folder path e.g. '/dst' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void copyFolder(String srcPath, String destPath, String srcStorageName, String destStorageName) throws ApiException {
        try {
            copyFolderWithHttpInfo(srcPath, destPath, srcStorageName, destStorageName);
        } catch (NeedRepeatRequestException e) {
            copyFolderWithHttpInfo(srcPath, destPath, srcStorageName, destStorageName);
        }
    }

    /**
     * Copy folder
     * 
     * @param srcPath Source folder path e.g. '/src' (required)
     * @param destPath Destination folder path e.g. '/dst' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> copyFolderWithHttpInfo(String srcPath, String destPath, String srcStorageName, String destStorageName) throws ApiException {
        com.squareup.okhttp.Call call = copyFolderCall(srcPath, destPath, srcStorageName, destStorageName, null, null);
        return apiClient.execute(call);
    }

    /**
     * Copy folder (asynchronously)
     * 
     * @param srcPath Source folder path e.g. '/src' (required)
     * @param destPath Destination folder path e.g. '/dst' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call copyFolderAsync(String srcPath, String destPath, String srcStorageName, String destStorageName, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = copyFolderCall(srcPath, destPath, srcStorageName, destStorageName, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for copyLayoutSlide
     * @param name Document name. (required)
     * @param cloneFrom Name of the document to clone layoutSlide from. (required)
     * @param cloneFromPosition Position of cloned layout slide. (required)
     * @param cloneFromPassword Password for the document to clone layoutSlide from. 
     * @param cloneFromStorage Storage of the document to clone layoutSlide from. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call copyLayoutSlideCall(String name, String cloneFrom, Integer cloneFromPosition, String cloneFromPassword, String cloneFromStorage, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling copyLayoutSlide(Async)");
        }
        // verify the required parameter 'cloneFrom' is set
        if (cloneFrom == null) {
            throw new ApiException("Missing the required parameter 'cloneFrom' when calling copyLayoutSlide(Async)");
        }
        // verify the required parameter 'cloneFromPosition' is set
        if (cloneFromPosition == null) {
            throw new ApiException("Missing the required parameter 'cloneFromPosition' when calling copyLayoutSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/layoutSlides"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "cloneFrom", cloneFrom);
        apiClient.addQueryParameter(queryParams, "cloneFromPosition", cloneFromPosition);
        apiClient.addQueryParameter(queryParams, "cloneFromStorage", cloneFromStorage);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (cloneFromPassword != null)
        headerParams.put("cloneFromPassword", apiClient.parameterToString(cloneFromPassword));
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Copy layoutSlide from source presentation.
     * 
     * @param name Document name. (required)
     * @param cloneFrom Name of the document to clone layoutSlide from. (required)
     * @param cloneFromPosition Position of cloned layout slide. (required)
     * @param cloneFromPassword Password for the document to clone layoutSlide from. 
     * @param cloneFromStorage Storage of the document to clone layoutSlide from. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return LayoutSlide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public LayoutSlide copyLayoutSlide(String name, String cloneFrom, Integer cloneFromPosition, String cloneFromPassword, String cloneFromStorage, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<LayoutSlide> resp = copyLayoutSlideWithHttpInfo(name, cloneFrom, cloneFromPosition, cloneFromPassword, cloneFromStorage, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<LayoutSlide> resp = copyLayoutSlideWithHttpInfo(name, cloneFrom, cloneFromPosition, cloneFromPassword, cloneFromStorage, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Copy layoutSlide from source presentation.
     * 
     * @param name Document name. (required)
     * @param cloneFrom Name of the document to clone layoutSlide from. (required)
     * @param cloneFromPosition Position of cloned layout slide. (required)
     * @param cloneFromPassword Password for the document to clone layoutSlide from. 
     * @param cloneFromStorage Storage of the document to clone layoutSlide from. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;LayoutSlide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<LayoutSlide> copyLayoutSlideWithHttpInfo(String name, String cloneFrom, Integer cloneFromPosition, String cloneFromPassword, String cloneFromStorage, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = copyLayoutSlideCall(name, cloneFrom, cloneFromPosition, cloneFromPassword, cloneFromStorage, password, folder, storage, null, null);
        Type returnType = new TypeToken<LayoutSlide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Copy layoutSlide from source presentation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param cloneFrom Name of the document to clone layoutSlide from. (required)
     * @param cloneFromPosition Position of cloned layout slide. (required)
     * @param cloneFromPassword Password for the document to clone layoutSlide from. 
     * @param cloneFromStorage Storage of the document to clone layoutSlide from. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call copyLayoutSlideAsync(String name, String cloneFrom, Integer cloneFromPosition, String cloneFromPassword, String cloneFromStorage, String password, String folder, String storage, final ApiCallback<LayoutSlide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = copyLayoutSlideCall(name, cloneFrom, cloneFromPosition, cloneFromPassword, cloneFromStorage, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<LayoutSlide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for copyMasterSlide
     * @param name Document name. (required)
     * @param cloneFrom Name of the document to clone masterSlide from. (required)
     * @param cloneFromPosition Position of cloned master slide. (required)
     * @param cloneFromPassword Password for the document to clone masterSlide from. 
     * @param cloneFromStorage Storage of the document to clone masterSlide from. 
     * @param applyToAll True to apply cloned master slide to every existing slide. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call copyMasterSlideCall(String name, String cloneFrom, Integer cloneFromPosition, String cloneFromPassword, String cloneFromStorage, Boolean applyToAll, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling copyMasterSlide(Async)");
        }
        // verify the required parameter 'cloneFrom' is set
        if (cloneFrom == null) {
            throw new ApiException("Missing the required parameter 'cloneFrom' when calling copyMasterSlide(Async)");
        }
        // verify the required parameter 'cloneFromPosition' is set
        if (cloneFromPosition == null) {
            throw new ApiException("Missing the required parameter 'cloneFromPosition' when calling copyMasterSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/masterSlides"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "cloneFrom", cloneFrom);
        apiClient.addQueryParameter(queryParams, "cloneFromPosition", cloneFromPosition);
        apiClient.addQueryParameter(queryParams, "cloneFromStorage", cloneFromStorage);
        apiClient.addQueryParameter(queryParams, "applyToAll", applyToAll);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (cloneFromPassword != null)
        headerParams.put("cloneFromPassword", apiClient.parameterToString(cloneFromPassword));
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Copy masterSlide from source presentation.
     * 
     * @param name Document name. (required)
     * @param cloneFrom Name of the document to clone masterSlide from. (required)
     * @param cloneFromPosition Position of cloned master slide. (required)
     * @param cloneFromPassword Password for the document to clone masterSlide from. 
     * @param cloneFromStorage Storage of the document to clone masterSlide from. 
     * @param applyToAll True to apply cloned master slide to every existing slide. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return MasterSlide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public MasterSlide copyMasterSlide(String name, String cloneFrom, Integer cloneFromPosition, String cloneFromPassword, String cloneFromStorage, Boolean applyToAll, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<MasterSlide> resp = copyMasterSlideWithHttpInfo(name, cloneFrom, cloneFromPosition, cloneFromPassword, cloneFromStorage, applyToAll, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<MasterSlide> resp = copyMasterSlideWithHttpInfo(name, cloneFrom, cloneFromPosition, cloneFromPassword, cloneFromStorage, applyToAll, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Copy masterSlide from source presentation.
     * 
     * @param name Document name. (required)
     * @param cloneFrom Name of the document to clone masterSlide from. (required)
     * @param cloneFromPosition Position of cloned master slide. (required)
     * @param cloneFromPassword Password for the document to clone masterSlide from. 
     * @param cloneFromStorage Storage of the document to clone masterSlide from. 
     * @param applyToAll True to apply cloned master slide to every existing slide. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;MasterSlide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<MasterSlide> copyMasterSlideWithHttpInfo(String name, String cloneFrom, Integer cloneFromPosition, String cloneFromPassword, String cloneFromStorage, Boolean applyToAll, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = copyMasterSlideCall(name, cloneFrom, cloneFromPosition, cloneFromPassword, cloneFromStorage, applyToAll, password, folder, storage, null, null);
        Type returnType = new TypeToken<MasterSlide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Copy masterSlide from source presentation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param cloneFrom Name of the document to clone masterSlide from. (required)
     * @param cloneFromPosition Position of cloned master slide. (required)
     * @param cloneFromPassword Password for the document to clone masterSlide from. 
     * @param cloneFromStorage Storage of the document to clone masterSlide from. 
     * @param applyToAll True to apply cloned master slide to every existing slide. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call copyMasterSlideAsync(String name, String cloneFrom, Integer cloneFromPosition, String cloneFromPassword, String cloneFromStorage, Boolean applyToAll, String password, String folder, String storage, final ApiCallback<MasterSlide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = copyMasterSlideCall(name, cloneFrom, cloneFromPosition, cloneFromPassword, cloneFromStorage, applyToAll, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<MasterSlide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for copySlide
     * @param name Document name. (required)
     * @param slideToCopy The index of the slide to be copied from the source presentation. (required)
     * @param position The target position at which to copy the slide. Copy to the end by default. 
     * @param source Name of the document to copy a slide from. 
     * @param sourcePassword Password for the document to copy a slide from. 
     * @param sourceStorage Template storage name. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call copySlideCall(String name, Integer slideToCopy, Integer position, String source, String sourcePassword, String sourceStorage, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling copySlide(Async)");
        }
        // verify the required parameter 'slideToCopy' is set
        if (slideToCopy == null) {
            throw new ApiException("Missing the required parameter 'slideToCopy' when calling copySlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/copy"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "slideToCopy", slideToCopy);
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "source", source);
        apiClient.addQueryParameter(queryParams, "sourceStorage", sourceStorage);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (sourcePassword != null)
        headerParams.put("sourcePassword", apiClient.parameterToString(sourcePassword));
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Copy a slide from the current or another presentation.
     * 
     * @param name Document name. (required)
     * @param slideToCopy The index of the slide to be copied from the source presentation. (required)
     * @param position The target position at which to copy the slide. Copy to the end by default. 
     * @param source Name of the document to copy a slide from. 
     * @param sourcePassword Password for the document to copy a slide from. 
     * @param sourceStorage Template storage name. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Slides
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Slides copySlide(String name, Integer slideToCopy, Integer position, String source, String sourcePassword, String sourceStorage, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Slides> resp = copySlideWithHttpInfo(name, slideToCopy, position, source, sourcePassword, sourceStorage, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Slides> resp = copySlideWithHttpInfo(name, slideToCopy, position, source, sourcePassword, sourceStorage, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Copy a slide from the current or another presentation.
     * 
     * @param name Document name. (required)
     * @param slideToCopy The index of the slide to be copied from the source presentation. (required)
     * @param position The target position at which to copy the slide. Copy to the end by default. 
     * @param source Name of the document to copy a slide from. 
     * @param sourcePassword Password for the document to copy a slide from. 
     * @param sourceStorage Template storage name. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Slides&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Slides> copySlideWithHttpInfo(String name, Integer slideToCopy, Integer position, String source, String sourcePassword, String sourceStorage, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = copySlideCall(name, slideToCopy, position, source, sourcePassword, sourceStorage, password, folder, storage, null, null);
        Type returnType = new TypeToken<Slides>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Copy a slide from the current or another presentation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideToCopy The index of the slide to be copied from the source presentation. (required)
     * @param position The target position at which to copy the slide. Copy to the end by default. 
     * @param source Name of the document to copy a slide from. 
     * @param sourcePassword Password for the document to copy a slide from. 
     * @param sourceStorage Template storage name. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call copySlideAsync(String name, Integer slideToCopy, Integer position, String source, String sourcePassword, String sourceStorage, String password, String folder, String storage, final ApiCallback<Slides> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = copySlideCall(name, slideToCopy, position, source, sourcePassword, sourceStorage, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Slides>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createAnimationEffect
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createAnimationEffectCall(String name, Integer slideIndex, Effect effect, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createAnimationEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createAnimationEffect(Async)");
        }
        // verify the required parameter 'effect' is set
        if (effect == null) {
            throw new ApiException("Missing the required parameter 'effect' when calling createAnimationEffect(Async)");
        }
        Object postBody = effect;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation/mainSequence"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Add an effect to slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation createAnimationEffect(String name, Integer slideIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = createAnimationEffectWithHttpInfo(name, slideIndex, effect, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = createAnimationEffectWithHttpInfo(name, slideIndex, effect, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Add an effect to slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> createAnimationEffectWithHttpInfo(String name, Integer slideIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createAnimationEffectCall(name, slideIndex, effect, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Add an effect to slide animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createAnimationEffectAsync(String name, Integer slideIndex, Effect effect, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createAnimationEffectCall(name, slideIndex, effect, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createAnimationInteractiveSequence
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequence Animation sequence DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createAnimationInteractiveSequenceCall(String name, Integer slideIndex, InteractiveSequence sequence, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createAnimationInteractiveSequence(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createAnimationInteractiveSequence(Async)");
        }
        // verify the required parameter 'sequence' is set
        if (sequence == null) {
            throw new ApiException("Missing the required parameter 'sequence' when calling createAnimationInteractiveSequence(Async)");
        }
        Object postBody = sequence;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation/interactiveSequences"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequence Animation sequence DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation createAnimationInteractiveSequence(String name, Integer slideIndex, InteractiveSequence sequence, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = createAnimationInteractiveSequenceWithHttpInfo(name, slideIndex, sequence, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = createAnimationInteractiveSequenceWithHttpInfo(name, slideIndex, sequence, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequence Animation sequence DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> createAnimationInteractiveSequenceWithHttpInfo(String name, Integer slideIndex, InteractiveSequence sequence, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createAnimationInteractiveSequenceCall(name, slideIndex, sequence, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set slide animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequence Animation sequence DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createAnimationInteractiveSequenceAsync(String name, Integer slideIndex, InteractiveSequence sequence, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createAnimationInteractiveSequenceCall(name, slideIndex, sequence, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createAnimationInteractiveSequenceEffect
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createAnimationInteractiveSequenceEffectCall(String name, Integer slideIndex, Integer sequenceIndex, Effect effect, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'sequenceIndex' is set
        if (sequenceIndex == null) {
            throw new ApiException("Missing the required parameter 'sequenceIndex' when calling createAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'effect' is set
        if (effect == null) {
            throw new ApiException("Missing the required parameter 'effect' when calling createAnimationInteractiveSequenceEffect(Async)");
        }
        Object postBody = effect;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation/interactiveSequences/{sequenceIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "sequenceIndex" + "\\}", apiClient.objectToString(sequenceIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Add an animation effect to a slide interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation createAnimationInteractiveSequenceEffect(String name, Integer slideIndex, Integer sequenceIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = createAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, sequenceIndex, effect, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = createAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, sequenceIndex, effect, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Add an animation effect to a slide interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> createAnimationInteractiveSequenceEffectWithHttpInfo(String name, Integer slideIndex, Integer sequenceIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createAnimationInteractiveSequenceEffectCall(name, slideIndex, sequenceIndex, effect, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Add an animation effect to a slide interactive sequence. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createAnimationInteractiveSequenceEffectAsync(String name, Integer slideIndex, Integer sequenceIndex, Effect effect, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createAnimationInteractiveSequenceEffectCall(name, slideIndex, sequenceIndex, effect, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createChartCategory
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param category Category DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createChartCategoryCall(String name, Integer slideIndex, Integer shapeIndex, ChartCategory category, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createChartCategory(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createChartCategory(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createChartCategory(Async)");
        }
        // verify the required parameter 'category' is set
        if (category == null) {
            throw new ApiException("Missing the required parameter 'category' when calling createChartCategory(Async)");
        }
        Object postBody = category;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/categories"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Add a new category to a chart.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param category Category DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Chart
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Chart createChartCategory(String name, Integer slideIndex, Integer shapeIndex, ChartCategory category, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Chart> resp = createChartCategoryWithHttpInfo(name, slideIndex, shapeIndex, category, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Chart> resp = createChartCategoryWithHttpInfo(name, slideIndex, shapeIndex, category, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Add a new category to a chart.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param category Category DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Chart&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Chart> createChartCategoryWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, ChartCategory category, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createChartCategoryCall(name, slideIndex, shapeIndex, category, password, folder, storage, null, null);
        Type returnType = new TypeToken<Chart>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Add a new category to a chart. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param category Category DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createChartCategoryAsync(String name, Integer slideIndex, Integer shapeIndex, ChartCategory category, String password, String folder, String storage, final ApiCallback<Chart> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createChartCategoryCall(name, slideIndex, shapeIndex, category, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Chart>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createChartDataPoint
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param dataPoint Data point DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createChartDataPointCall(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, DataPoint dataPoint, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createChartDataPoint(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createChartDataPoint(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createChartDataPoint(Async)");
        }
        // verify the required parameter 'seriesIndex' is set
        if (seriesIndex == null) {
            throw new ApiException("Missing the required parameter 'seriesIndex' when calling createChartDataPoint(Async)");
        }
        // verify the required parameter 'dataPoint' is set
        if (dataPoint == null) {
            throw new ApiException("Missing the required parameter 'dataPoint' when calling createChartDataPoint(Async)");
        }
        Object postBody = dataPoint;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/series/{seriesIndex}/dataPoints"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "seriesIndex" + "\\}", apiClient.objectToString(seriesIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Add a new data point to a chart series.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param dataPoint Data point DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Chart
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Chart createChartDataPoint(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, DataPoint dataPoint, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Chart> resp = createChartDataPointWithHttpInfo(name, slideIndex, shapeIndex, seriesIndex, dataPoint, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Chart> resp = createChartDataPointWithHttpInfo(name, slideIndex, shapeIndex, seriesIndex, dataPoint, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Add a new data point to a chart series.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param dataPoint Data point DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Chart&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Chart> createChartDataPointWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, DataPoint dataPoint, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createChartDataPointCall(name, slideIndex, shapeIndex, seriesIndex, dataPoint, password, folder, storage, null, null);
        Type returnType = new TypeToken<Chart>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Add a new data point to a chart series. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param dataPoint Data point DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createChartDataPointAsync(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, DataPoint dataPoint, String password, String folder, String storage, final ApiCallback<Chart> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createChartDataPointCall(name, slideIndex, shapeIndex, seriesIndex, dataPoint, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Chart>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createChartSeries
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param series Series DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createChartSeriesCall(String name, Integer slideIndex, Integer shapeIndex, Series series, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createChartSeries(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createChartSeries(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createChartSeries(Async)");
        }
        // verify the required parameter 'series' is set
        if (series == null) {
            throw new ApiException("Missing the required parameter 'series' when calling createChartSeries(Async)");
        }
        Object postBody = series;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/series"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Add a new series to a chart.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param series Series DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Chart
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Chart createChartSeries(String name, Integer slideIndex, Integer shapeIndex, Series series, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Chart> resp = createChartSeriesWithHttpInfo(name, slideIndex, shapeIndex, series, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Chart> resp = createChartSeriesWithHttpInfo(name, slideIndex, shapeIndex, series, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Add a new series to a chart.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param series Series DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Chart&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Chart> createChartSeriesWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Series series, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createChartSeriesCall(name, slideIndex, shapeIndex, series, password, folder, storage, null, null);
        Type returnType = new TypeToken<Chart>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Add a new series to a chart. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param series Series DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createChartSeriesAsync(String name, Integer slideIndex, Integer shapeIndex, Series series, String password, String folder, String storage, final ApiCallback<Chart> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createChartSeriesCall(name, slideIndex, shapeIndex, series, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Chart>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createComment
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Comment DTO. (required)
     * @param shapeIndex Shape index. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createCommentCall(String name, Integer slideIndex, SlideCommentBase dto, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createComment(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createComment(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createComment(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/comments"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapeIndex", shapeIndex);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Adds the comment on the slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Comment DTO. (required)
     * @param shapeIndex Shape index. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideComments
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideComments createComment(String name, Integer slideIndex, SlideCommentBase dto, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideComments> resp = createCommentWithHttpInfo(name, slideIndex, dto, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideComments> resp = createCommentWithHttpInfo(name, slideIndex, dto, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Adds the comment on the slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Comment DTO. (required)
     * @param shapeIndex Shape index. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideComments&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideComments> createCommentWithHttpInfo(String name, Integer slideIndex, SlideCommentBase dto, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createCommentCall(name, slideIndex, dto, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideComments>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Adds the comment on the slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Comment DTO. (required)
     * @param shapeIndex Shape index. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createCommentAsync(String name, Integer slideIndex, SlideCommentBase dto, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<SlideComments> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createCommentCall(name, slideIndex, dto, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideComments>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createCommentOnline
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Comment DTO. (required)
     * @param shapeIndex Shape index. 
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createCommentOnlineCall(byte[] document, Integer slideIndex, SlideCommentBase dto, Integer shapeIndex, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling createCommentOnline(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createCommentOnline(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createCommentOnline(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/slides/{slideIndex}/comments"
            .replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapeIndex", shapeIndex);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Adds the comment on the slide.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Comment DTO. (required)
     * @param shapeIndex Shape index. 
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File createCommentOnline(byte[] document, Integer slideIndex, SlideCommentBase dto, Integer shapeIndex, String password) throws ApiException {
        try {
            ApiResponse<File> resp = createCommentOnlineWithHttpInfo(document, slideIndex, dto, shapeIndex, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = createCommentOnlineWithHttpInfo(document, slideIndex, dto, shapeIndex, password);
            return resp.getData();
        }
    }

    /**
     * Adds the comment on the slide.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Comment DTO. (required)
     * @param shapeIndex Shape index. 
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> createCommentOnlineWithHttpInfo(byte[] document, Integer slideIndex, SlideCommentBase dto, Integer shapeIndex, String password) throws ApiException {
        com.squareup.okhttp.Call call = createCommentOnlineCall(document, slideIndex, dto, shapeIndex, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Adds the comment on the slide. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Comment DTO. (required)
     * @param shapeIndex Shape index. 
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createCommentOnlineAsync(byte[] document, Integer slideIndex, SlideCommentBase dto, Integer shapeIndex, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createCommentOnlineCall(document, slideIndex, dto, shapeIndex, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createFolder
     * @param path Folder path to create e.g. 'folder_1/folder_2/' 
     * @param storageName Storage name 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createFolderCall(String path, String storageName, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/folder/{path}"
            .replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storageName", storageName);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create the folder
     * 
     * @param path Folder path to create e.g. 'folder_1/folder_2/' 
     * @param storageName Storage name 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void createFolder(String path, String storageName) throws ApiException {
        try {
            createFolderWithHttpInfo(path, storageName);
        } catch (NeedRepeatRequestException e) {
            createFolderWithHttpInfo(path, storageName);
        }
    }

    /**
     * Create the folder
     * 
     * @param path Folder path to create e.g. 'folder_1/folder_2/' 
     * @param storageName Storage name 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> createFolderWithHttpInfo(String path, String storageName) throws ApiException {
        com.squareup.okhttp.Call call = createFolderCall(path, storageName, null, null);
        return apiClient.execute(call);
    }

    /**
     * Create the folder (asynchronously)
     * 
     * @param path Folder path to create e.g. 'folder_1/folder_2/' 
     * @param storageName Storage name 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createFolderAsync(String path, String storageName, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createFolderCall(path, storageName, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for createImageWatermark
     * @param name Document name. (required)
     * @param image Image data. 
     * @param pictureFrame PictureFrame DTO 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createImageWatermarkCall(String name, byte[] image, PictureFrame pictureFrame, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createImageWatermark(Async)");
        }
        Object postBody = pictureFrame;

        // create path and map variables
        String methodPath = "/slides/{name}/watermark/image"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (image != null)
        formParams.put("image", image);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Adds an image watermark to each slide of the presentation.  Image can be provided as a part of the form or withing PictureFrame DTO for detailed customization. Both options are applicable simultaneously. 
     * 
     * @param name Document name. (required)
     * @param image Image data. 
     * @param pictureFrame PictureFrame DTO 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void createImageWatermark(String name, byte[] image, PictureFrame pictureFrame, String password, String folder, String storage) throws ApiException {
        try {
            createImageWatermarkWithHttpInfo(name, image, pictureFrame, password, folder, storage);
        } catch (NeedRepeatRequestException e) {
            createImageWatermarkWithHttpInfo(name, image, pictureFrame, password, folder, storage);
        }
    }

    /**
     * Adds an image watermark to each slide of the presentation.  Image can be provided as a part of the form or withing PictureFrame DTO for detailed customization. Both options are applicable simultaneously. 
     * 
     * @param name Document name. (required)
     * @param image Image data. 
     * @param pictureFrame PictureFrame DTO 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> createImageWatermarkWithHttpInfo(String name, byte[] image, PictureFrame pictureFrame, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createImageWatermarkCall(name, image, pictureFrame, password, folder, storage, null, null);
        return apiClient.execute(call);
    }

    /**
     * Adds an image watermark to each slide of the presentation.  Image can be provided as a part of the form or withing PictureFrame DTO for detailed customization. Both options are applicable simultaneously.  (asynchronously)
     * 
     * @param name Document name. (required)
     * @param image Image data. 
     * @param pictureFrame PictureFrame DTO 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createImageWatermarkAsync(String name, byte[] image, PictureFrame pictureFrame, String password, String folder, String storage, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createImageWatermarkCall(name, image, pictureFrame, password, folder, storage, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for createImageWatermarkOnline
     * @param document Document data. (required)
     * @param image Image data. 
     * @param pictureFrame PictureFrame DTO. 
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createImageWatermarkOnlineCall(byte[] document, byte[] image, PictureFrame pictureFrame, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling createImageWatermarkOnline(Async)");
        }
        Object postBody = pictureFrame;

        // create path and map variables
        String methodPath = "/slides/watermark/image"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);
        if (image != null)
        formParams.put("image", image);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Adds an image watermark to each slide of the presentation.  Image can be provided as a part of the form or withing PictureFrame DTO for detailed customization. Both options are applicable simultaneously. 
     * 
     * @param document Document data. (required)
     * @param image Image data. 
     * @param pictureFrame PictureFrame DTO. 
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File createImageWatermarkOnline(byte[] document, byte[] image, PictureFrame pictureFrame, String password) throws ApiException {
        try {
            ApiResponse<File> resp = createImageWatermarkOnlineWithHttpInfo(document, image, pictureFrame, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = createImageWatermarkOnlineWithHttpInfo(document, image, pictureFrame, password);
            return resp.getData();
        }
    }

    /**
     * Adds an image watermark to each slide of the presentation.  Image can be provided as a part of the form or withing PictureFrame DTO for detailed customization. Both options are applicable simultaneously. 
     * 
     * @param document Document data. (required)
     * @param image Image data. 
     * @param pictureFrame PictureFrame DTO. 
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> createImageWatermarkOnlineWithHttpInfo(byte[] document, byte[] image, PictureFrame pictureFrame, String password) throws ApiException {
        com.squareup.okhttp.Call call = createImageWatermarkOnlineCall(document, image, pictureFrame, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Adds an image watermark to each slide of the presentation.  Image can be provided as a part of the form or withing PictureFrame DTO for detailed customization. Both options are applicable simultaneously.  (asynchronously)
     * 
     * @param document Document data. (required)
     * @param image Image data. 
     * @param pictureFrame PictureFrame DTO. 
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createImageWatermarkOnlineAsync(byte[] document, byte[] image, PictureFrame pictureFrame, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createImageWatermarkOnlineCall(document, image, pictureFrame, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createNotesSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto A NotesSlide object with notes slide data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createNotesSlideCall(String name, Integer slideIndex, NotesSlide dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createNotesSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createNotesSlide(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createNotesSlide(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/notesSlide"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Add new notes slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto A NotesSlide object with notes slide data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return NotesSlide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public NotesSlide createNotesSlide(String name, Integer slideIndex, NotesSlide dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<NotesSlide> resp = createNotesSlideWithHttpInfo(name, slideIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<NotesSlide> resp = createNotesSlideWithHttpInfo(name, slideIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Add new notes slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto A NotesSlide object with notes slide data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;NotesSlide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<NotesSlide> createNotesSlideWithHttpInfo(String name, Integer slideIndex, NotesSlide dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createNotesSlideCall(name, slideIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<NotesSlide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Add new notes slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto A NotesSlide object with notes slide data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createNotesSlideAsync(String name, Integer slideIndex, NotesSlide dto, String password, String folder, String storage, final ApiCallback<NotesSlide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createNotesSlideCall(name, slideIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<NotesSlide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createParagraph
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createParagraphCall(String name, Integer slideIndex, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createParagraph(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createParagraph(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Creates new paragraph.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph createParagraph(String name, Integer slideIndex, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = createParagraphWithHttpInfo(name, slideIndex, shapeIndex, dto, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = createParagraphWithHttpInfo(name, slideIndex, shapeIndex, dto, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Creates new paragraph.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> createParagraphWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createParagraphCall(name, slideIndex, shapeIndex, dto, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Creates new paragraph. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createParagraphAsync(String name, Integer slideIndex, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createParagraphCall(name, slideIndex, shapeIndex, dto, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createPortion
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createPortionCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createPortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createPortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createPortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling createPortion(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createPortion(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Creates new portion.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion createPortion(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = createPortionWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, dto, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = createPortionWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, dto, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Creates new portion.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> createPortionWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createPortionCall(name, slideIndex, shapeIndex, paragraphIndex, dto, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Creates new portion. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createPortionAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createPortionCall(name, slideIndex, shapeIndex, paragraphIndex, dto, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createPresentation
     * @param name Document name. (required)
     * @param data Source presentation binary data. 
     * @param inputPassword The password for source presentation. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createPresentationCall(String name, byte[] data, String inputPassword, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createPresentation(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (inputPassword != null)
        headerParams.put("inputPassword", apiClient.parameterToString(inputPassword));
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (data != null)
        formParams.put("data", data);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create a presentation.
     * 
     * @param name Document name. (required)
     * @param data Source presentation binary data. 
     * @param inputPassword The password for source presentation. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Document
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Document createPresentation(String name, byte[] data, String inputPassword, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Document> resp = createPresentationWithHttpInfo(name, data, inputPassword, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Document> resp = createPresentationWithHttpInfo(name, data, inputPassword, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create a presentation.
     * 
     * @param name Document name. (required)
     * @param data Source presentation binary data. 
     * @param inputPassword The password for source presentation. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Document&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Document> createPresentationWithHttpInfo(String name, byte[] data, String inputPassword, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createPresentationCall(name, data, inputPassword, password, folder, storage, null, null);
        Type returnType = new TypeToken<Document>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create a presentation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param data Source presentation binary data. 
     * @param inputPassword The password for source presentation. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createPresentationAsync(String name, byte[] data, String inputPassword, String password, String folder, String storage, final ApiCallback<Document> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createPresentationCall(name, data, inputPassword, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Document>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createPresentationFromSource
     * @param name Document name. (required)
     * @param sourcePath Source file path. 
     * @param sourcePassword Source file password. 
     * @param sourceStorage Source storage name. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createPresentationFromSourceCall(String name, String sourcePath, String sourcePassword, String sourceStorage, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createPresentationFromSource(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/fromSource"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "sourcePath", sourcePath);
        apiClient.addQueryParameter(queryParams, "sourceStorage", sourceStorage);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (sourcePassword != null)
        headerParams.put("sourcePassword", apiClient.parameterToString(sourcePassword));
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create a presentation from an existing source.
     * 
     * @param name Document name. (required)
     * @param sourcePath Source file path. 
     * @param sourcePassword Source file password. 
     * @param sourceStorage Source storage name. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Document
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Document createPresentationFromSource(String name, String sourcePath, String sourcePassword, String sourceStorage, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Document> resp = createPresentationFromSourceWithHttpInfo(name, sourcePath, sourcePassword, sourceStorage, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Document> resp = createPresentationFromSourceWithHttpInfo(name, sourcePath, sourcePassword, sourceStorage, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create a presentation from an existing source.
     * 
     * @param name Document name. (required)
     * @param sourcePath Source file path. 
     * @param sourcePassword Source file password. 
     * @param sourceStorage Source storage name. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Document&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Document> createPresentationFromSourceWithHttpInfo(String name, String sourcePath, String sourcePassword, String sourceStorage, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createPresentationFromSourceCall(name, sourcePath, sourcePassword, sourceStorage, password, folder, storage, null, null);
        Type returnType = new TypeToken<Document>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create a presentation from an existing source. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param sourcePath Source file path. 
     * @param sourcePassword Source file password. 
     * @param sourceStorage Source storage name. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createPresentationFromSourceAsync(String name, String sourcePath, String sourcePassword, String sourceStorage, String password, String folder, String storage, final ApiCallback<Document> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createPresentationFromSourceCall(name, sourcePath, sourcePassword, sourceStorage, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Document>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createPresentationFromTemplate
     * @param name Document name. (required)
     * @param templatePath Template file path. (required)
     * @param data Document input data. 
     * @param templatePassword Template file password. 
     * @param templateStorage Template storage name. 
     * @param isImageDataEmbedded True if image data is embedded. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createPresentationFromTemplateCall(String name, String templatePath, String data, String templatePassword, String templateStorage, Boolean isImageDataEmbedded, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createPresentationFromTemplate(Async)");
        }
        // verify the required parameter 'templatePath' is set
        if (templatePath == null) {
            throw new ApiException("Missing the required parameter 'templatePath' when calling createPresentationFromTemplate(Async)");
        }
        Object postBody = data;

        // create path and map variables
        String methodPath = "/slides/{name}/fromTemplate"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "templatePath", templatePath);
        apiClient.addQueryParameter(queryParams, "templateStorage", templateStorage);
        apiClient.addQueryParameter(queryParams, "isImageDataEmbedded", isImageDataEmbedded);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (templatePassword != null)
        headerParams.put("templatePassword", apiClient.parameterToString(templatePassword));
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create a presentation.
     * 
     * @param name Document name. (required)
     * @param templatePath Template file path. (required)
     * @param data Document input data. 
     * @param templatePassword Template file password. 
     * @param templateStorage Template storage name. 
     * @param isImageDataEmbedded True if image data is embedded. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Document
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Document createPresentationFromTemplate(String name, String templatePath, String data, String templatePassword, String templateStorage, Boolean isImageDataEmbedded, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Document> resp = createPresentationFromTemplateWithHttpInfo(name, templatePath, data, templatePassword, templateStorage, isImageDataEmbedded, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Document> resp = createPresentationFromTemplateWithHttpInfo(name, templatePath, data, templatePassword, templateStorage, isImageDataEmbedded, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create a presentation.
     * 
     * @param name Document name. (required)
     * @param templatePath Template file path. (required)
     * @param data Document input data. 
     * @param templatePassword Template file password. 
     * @param templateStorage Template storage name. 
     * @param isImageDataEmbedded True if image data is embedded. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Document&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Document> createPresentationFromTemplateWithHttpInfo(String name, String templatePath, String data, String templatePassword, String templateStorage, Boolean isImageDataEmbedded, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createPresentationFromTemplateCall(name, templatePath, data, templatePassword, templateStorage, isImageDataEmbedded, password, folder, storage, null, null);
        Type returnType = new TypeToken<Document>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create a presentation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param templatePath Template file path. (required)
     * @param data Document input data. 
     * @param templatePassword Template file password. 
     * @param templateStorage Template storage name. 
     * @param isImageDataEmbedded True if image data is embedded. 
     * @param password The document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createPresentationFromTemplateAsync(String name, String templatePath, String data, String templatePassword, String templateStorage, Boolean isImageDataEmbedded, String password, String folder, String storage, final ApiCallback<Document> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createPresentationFromTemplateCall(name, templatePath, data, templatePassword, templateStorage, isImageDataEmbedded, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Document>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSection
     * @param name Document name. (required)
     * @param sectionName Section name. (required)
     * @param slideIndex Slide index (one-based). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSectionCall(String name, String sectionName, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSection(Async)");
        }
        // verify the required parameter 'sectionName' is set
        if (sectionName == null) {
            throw new ApiException("Missing the required parameter 'sectionName' when calling createSection(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSection(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/sections"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "sectionName", sectionName);
        apiClient.addQueryParameter(queryParams, "slideIndex", slideIndex);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create a section starting at a specified slide index.
     * 
     * @param name Document name. (required)
     * @param sectionName Section name. (required)
     * @param slideIndex Slide index (one-based). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Sections
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Sections createSection(String name, String sectionName, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Sections> resp = createSectionWithHttpInfo(name, sectionName, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Sections> resp = createSectionWithHttpInfo(name, sectionName, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create a section starting at a specified slide index.
     * 
     * @param name Document name. (required)
     * @param sectionName Section name. (required)
     * @param slideIndex Slide index (one-based). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Sections&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Sections> createSectionWithHttpInfo(String name, String sectionName, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSectionCall(name, sectionName, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Sections>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create a section starting at a specified slide index. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param sectionName Section name. (required)
     * @param slideIndex Slide index (one-based). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSectionAsync(String name, String sectionName, Integer slideIndex, String password, String folder, String storage, final ApiCallback<Sections> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSectionCall(name, sectionName, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Sections>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createShape
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createShapeCall(String name, Integer slideIndex, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createShape(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapeToClone", shapeToClone);
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create new shape.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase createShape(String name, Integer slideIndex, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = createShapeWithHttpInfo(name, slideIndex, dto, shapeToClone, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = createShapeWithHttpInfo(name, slideIndex, dto, shapeToClone, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create new shape.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> createShapeWithHttpInfo(String name, Integer slideIndex, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createShapeCall(name, slideIndex, dto, shapeToClone, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create new shape. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createShapeAsync(String name, Integer slideIndex, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createShapeCall(name, slideIndex, dto, shapeToClone, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSlide
     * @param name Document name. (required)
     * @param layoutAlias Alias of layout slide for new slide. Alias may be the type of layout, name of layout slide or index 
     * @param position The target position at which to create the slide. Add to the end by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSlideCall(String name, String layoutAlias, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "layoutAlias", layoutAlias);
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create a slide.
     * 
     * @param name Document name. (required)
     * @param layoutAlias Alias of layout slide for new slide. Alias may be the type of layout, name of layout slide or index 
     * @param position The target position at which to create the slide. Add to the end by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Slides
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Slides createSlide(String name, String layoutAlias, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Slides> resp = createSlideWithHttpInfo(name, layoutAlias, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Slides> resp = createSlideWithHttpInfo(name, layoutAlias, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create a slide.
     * 
     * @param name Document name. (required)
     * @param layoutAlias Alias of layout slide for new slide. Alias may be the type of layout, name of layout slide or index 
     * @param position The target position at which to create the slide. Add to the end by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Slides&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Slides> createSlideWithHttpInfo(String name, String layoutAlias, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSlideCall(name, layoutAlias, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<Slides>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create a slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param layoutAlias Alias of layout slide for new slide. Alias may be the type of layout, name of layout slide or index 
     * @param position The target position at which to create the slide. Add to the end by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSlideAsync(String name, String layoutAlias, Integer position, String password, String folder, String storage, final ApiCallback<Slides> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSlideCall(name, layoutAlias, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Slides>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSpecialSlideAnimationEffect
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideAnimationEffectCall(String name, Integer slideIndex, SpecialSlideType slideType, Effect effect, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSpecialSlideAnimationEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSpecialSlideAnimationEffect(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling createSpecialSlideAnimationEffect(Async)");
        }
        // verify the required parameter 'effect' is set
        if (effect == null) {
            throw new ApiException("Missing the required parameter 'effect' when calling createSpecialSlideAnimationEffect(Async)");
        }
        Object postBody = effect;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation/mainSequence"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Add an effect to special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation createSpecialSlideAnimationEffect(String name, Integer slideIndex, SpecialSlideType slideType, Effect effect, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = createSpecialSlideAnimationEffectWithHttpInfo(name, slideIndex, slideType, effect, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = createSpecialSlideAnimationEffectWithHttpInfo(name, slideIndex, slideType, effect, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Add an effect to special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> createSpecialSlideAnimationEffectWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Effect effect, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSpecialSlideAnimationEffectCall(name, slideIndex, slideType, effect, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Add an effect to special slide (master, layout, notes) animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideAnimationEffectAsync(String name, Integer slideIndex, SpecialSlideType slideType, Effect effect, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSpecialSlideAnimationEffectCall(name, slideIndex, slideType, effect, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSpecialSlideAnimationInteractiveSequence
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequence Animation sequence DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideAnimationInteractiveSequenceCall(String name, Integer slideIndex, SpecialSlideType slideType, InteractiveSequence sequence, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSpecialSlideAnimationInteractiveSequence(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSpecialSlideAnimationInteractiveSequence(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling createSpecialSlideAnimationInteractiveSequence(Async)");
        }
        // verify the required parameter 'sequence' is set
        if (sequence == null) {
            throw new ApiException("Missing the required parameter 'sequence' when calling createSpecialSlideAnimationInteractiveSequence(Async)");
        }
        Object postBody = sequence;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation/interactiveSequences"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequence Animation sequence DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation createSpecialSlideAnimationInteractiveSequence(String name, Integer slideIndex, SpecialSlideType slideType, InteractiveSequence sequence, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = createSpecialSlideAnimationInteractiveSequenceWithHttpInfo(name, slideIndex, slideType, sequence, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = createSpecialSlideAnimationInteractiveSequenceWithHttpInfo(name, slideIndex, slideType, sequence, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequence Animation sequence DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> createSpecialSlideAnimationInteractiveSequenceWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, InteractiveSequence sequence, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSpecialSlideAnimationInteractiveSequenceCall(name, slideIndex, slideType, sequence, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set special slide (master, layout, notes) animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequence Animation sequence DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideAnimationInteractiveSequenceAsync(String name, Integer slideIndex, SpecialSlideType slideType, InteractiveSequence sequence, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSpecialSlideAnimationInteractiveSequenceCall(name, slideIndex, slideType, sequence, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSpecialSlideAnimationInteractiveSequenceEffect
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideAnimationInteractiveSequenceEffectCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Effect effect, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling createSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'sequenceIndex' is set
        if (sequenceIndex == null) {
            throw new ApiException("Missing the required parameter 'sequenceIndex' when calling createSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'effect' is set
        if (effect == null) {
            throw new ApiException("Missing the required parameter 'effect' when calling createSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        Object postBody = effect;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation/interactiveSequences/{sequenceIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "sequenceIndex" + "\\}", apiClient.objectToString(sequenceIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Add an animation effect to a special slide (master, layout, notes) interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation createSpecialSlideAnimationInteractiveSequenceEffect(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = createSpecialSlideAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, slideType, sequenceIndex, effect, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = createSpecialSlideAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, slideType, sequenceIndex, effect, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Add an animation effect to a special slide (master, layout, notes) interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> createSpecialSlideAnimationInteractiveSequenceEffectWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSpecialSlideAnimationInteractiveSequenceEffectCall(name, slideIndex, slideType, sequenceIndex, effect, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Add an animation effect to a special slide (master, layout, notes) interactive sequence. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideAnimationInteractiveSequenceEffectAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Effect effect, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSpecialSlideAnimationInteractiveSequenceEffectCall(name, slideIndex, slideType, sequenceIndex, effect, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSpecialSlideParagraph
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideParagraphCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling createSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createSpecialSlideParagraph(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Creates new paragraph.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph createSpecialSlideParagraph(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = createSpecialSlideParagraphWithHttpInfo(name, slideIndex, slideType, shapeIndex, dto, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = createSpecialSlideParagraphWithHttpInfo(name, slideIndex, slideType, shapeIndex, dto, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Creates new paragraph.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> createSpecialSlideParagraphWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSpecialSlideParagraphCall(name, slideIndex, slideType, shapeIndex, dto, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Creates new paragraph. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideParagraphAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSpecialSlideParagraphCall(name, slideIndex, slideType, shapeIndex, dto, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSpecialSlidePortion
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlidePortionCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling createSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling createSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createSpecialSlidePortion(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Creates new portion.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion createSpecialSlidePortion(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = createSpecialSlidePortionWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, dto, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = createSpecialSlidePortionWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, dto, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Creates new portion.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> createSpecialSlidePortionWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSpecialSlidePortionCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, dto, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Creates new portion. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlidePortionAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSpecialSlidePortionCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, dto, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSpecialSlideShape
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideShapeCall(String name, Integer slideIndex, SpecialSlideType slideType, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling createSpecialSlideShape(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapeToClone", shapeToClone);
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create new shape.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase createSpecialSlideShape(String name, Integer slideIndex, SpecialSlideType slideType, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = createSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, dto, shapeToClone, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = createSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, dto, shapeToClone, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create new shape.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> createSpecialSlideShapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSpecialSlideShapeCall(name, slideIndex, slideType, dto, shapeToClone, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create new shape. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideShapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSpecialSlideShapeCall(name, slideIndex, slideType, dto, shapeToClone, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSpecialSlideSubshape
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideSubshapeCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling createSpecialSlideSubshape(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapeToClone", shapeToClone);
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create new shape (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase createSpecialSlideSubshape(String name, Integer slideIndex, SpecialSlideType slideType, String path, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = createSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, dto, shapeToClone, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = createSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, dto, shapeToClone, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create new shape (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> createSpecialSlideSubshapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSpecialSlideSubshapeCall(name, slideIndex, slideType, path, dto, shapeToClone, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create new shape (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideSubshapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSpecialSlideSubshapeCall(name, slideIndex, slideType, path, dto, shapeToClone, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSpecialSlideSubshapeParagraph
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideSubshapeParagraphCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling createSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createSpecialSlideSubshapeParagraph(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Creates new paragraph (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph createSpecialSlideSubshapeParagraph(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = createSpecialSlideSubshapeParagraphWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, dto, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = createSpecialSlideSubshapeParagraphWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, dto, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Creates new paragraph (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> createSpecialSlideSubshapeParagraphWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSpecialSlideSubshapeParagraphCall(name, slideIndex, slideType, path, shapeIndex, dto, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Creates new paragraph (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideSubshapeParagraphAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSpecialSlideSubshapeParagraphCall(name, slideIndex, slideType, path, shapeIndex, dto, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSpecialSlideSubshapePortion
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideSubshapePortionCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling createSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling createSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createSpecialSlideSubshapePortion(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Creates new portion (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion createSpecialSlideSubshapePortion(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = createSpecialSlideSubshapePortionWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, dto, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = createSpecialSlideSubshapePortionWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, dto, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Creates new portion (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> createSpecialSlideSubshapePortionWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSpecialSlideSubshapePortionCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, dto, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Creates new portion (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSpecialSlideSubshapePortionAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSpecialSlideSubshapePortionCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, dto, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSubshape
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSubshapeCall(String name, Integer slideIndex, String path, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSubshape(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapeToClone", shapeToClone);
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create new shape (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase createSubshape(String name, Integer slideIndex, String path, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = createSubshapeWithHttpInfo(name, slideIndex, path, dto, shapeToClone, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = createSubshapeWithHttpInfo(name, slideIndex, path, dto, shapeToClone, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create new shape (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> createSubshapeWithHttpInfo(String name, Integer slideIndex, String path, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSubshapeCall(name, slideIndex, path, dto, shapeToClone, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create new shape (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param dto Shape DTO. 
     * @param shapeToClone Optional index for clone shape instead of adding a new one. 
     * @param position Position of the new shape in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSubshapeAsync(String name, Integer slideIndex, String path, ShapeBase dto, Integer shapeToClone, Integer position, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSubshapeCall(name, slideIndex, path, dto, shapeToClone, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSubshapeParagraph
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSubshapeParagraphCall(String name, Integer slideIndex, String path, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSubshapeParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createSubshapeParagraph(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createSubshapeParagraph(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Creates new paragraph (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph createSubshapeParagraph(String name, Integer slideIndex, String path, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = createSubshapeParagraphWithHttpInfo(name, slideIndex, path, shapeIndex, dto, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = createSubshapeParagraphWithHttpInfo(name, slideIndex, path, shapeIndex, dto, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Creates new paragraph (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> createSubshapeParagraphWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSubshapeParagraphCall(name, slideIndex, path, shapeIndex, dto, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Creates new paragraph (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Paragraph DTO. (required)
     * @param position Position of the new paragraph in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSubshapeParagraphAsync(String name, Integer slideIndex, String path, Integer shapeIndex, Paragraph dto, Integer position, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSubshapeParagraphCall(name, slideIndex, path, shapeIndex, dto, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createSubshapePortion
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createSubshapePortionCall(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createSubshapePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling createSubshapePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling createSubshapePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling createSubshapePortion(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling createSubshapePortion(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "position", position);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Creates new portion (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion createSubshapePortion(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = createSubshapePortionWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, dto, position, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = createSubshapePortionWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, dto, position, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Creates new portion (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> createSubshapePortionWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createSubshapePortionCall(name, slideIndex, path, shapeIndex, paragraphIndex, dto, position, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Creates new portion (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Portion DTO. (required)
     * @param position Position of the new portion in the list. Default is at the end of the list. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createSubshapePortionAsync(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Portion dto, Integer position, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createSubshapePortionCall(name, slideIndex, path, shapeIndex, paragraphIndex, dto, position, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for createWatermark
     * @param name Document name. (required)
     * @param shape Shape DTO 
     * @param fontHeight Watermark font height. 
     * @param text Watermark text. 
     * @param fontName Watermark font name. 
     * @param fontColor Watermark font color. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createWatermarkCall(String name, Shape shape, Double fontHeight, String text, String fontName, String fontColor, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling createWatermark(Async)");
        }
        Object postBody = shape;

        // create path and map variables
        String methodPath = "/slides/{name}/watermark"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "fontHeight", fontHeight);
        apiClient.addQueryParameter(queryParams, "text", text);
        apiClient.addQueryParameter(queryParams, "fontName", fontName);
        apiClient.addQueryParameter(queryParams, "fontColor", fontColor);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Adds a text watermark to each slide of the presentation. Text watermark can be setup via method arguments or withing Shape DTO for detailed customization. Both options are applicable simultaneously. 
     * 
     * @param name Document name. (required)
     * @param shape Shape DTO 
     * @param fontHeight Watermark font height. 
     * @param text Watermark text. 
     * @param fontName Watermark font name. 
     * @param fontColor Watermark font color. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void createWatermark(String name, Shape shape, Double fontHeight, String text, String fontName, String fontColor, String password, String folder, String storage) throws ApiException {
        try {
            createWatermarkWithHttpInfo(name, shape, fontHeight, text, fontName, fontColor, password, folder, storage);
        } catch (NeedRepeatRequestException e) {
            createWatermarkWithHttpInfo(name, shape, fontHeight, text, fontName, fontColor, password, folder, storage);
        }
    }

    /**
     * Adds a text watermark to each slide of the presentation. Text watermark can be setup via method arguments or withing Shape DTO for detailed customization. Both options are applicable simultaneously. 
     * 
     * @param name Document name. (required)
     * @param shape Shape DTO 
     * @param fontHeight Watermark font height. 
     * @param text Watermark text. 
     * @param fontName Watermark font name. 
     * @param fontColor Watermark font color. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> createWatermarkWithHttpInfo(String name, Shape shape, Double fontHeight, String text, String fontName, String fontColor, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = createWatermarkCall(name, shape, fontHeight, text, fontName, fontColor, password, folder, storage, null, null);
        return apiClient.execute(call);
    }

    /**
     * Adds a text watermark to each slide of the presentation. Text watermark can be setup via method arguments or withing Shape DTO for detailed customization. Both options are applicable simultaneously.  (asynchronously)
     * 
     * @param name Document name. (required)
     * @param shape Shape DTO 
     * @param fontHeight Watermark font height. 
     * @param text Watermark text. 
     * @param fontName Watermark font name. 
     * @param fontColor Watermark font color. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createWatermarkAsync(String name, Shape shape, Double fontHeight, String text, String fontName, String fontColor, String password, String folder, String storage, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createWatermarkCall(name, shape, fontHeight, text, fontName, fontColor, password, folder, storage, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for createWatermarkOnline
     * @param document Document data. (required)
     * @param shape Shape DTO 
     * @param fontHeight Watermark font height. 
     * @param text Watermark text. 
     * @param fontName Watermark font name. 
     * @param fontColor Watermark font color. 
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call createWatermarkOnlineCall(byte[] document, Shape shape, Double fontHeight, String text, String fontName, String fontColor, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling createWatermarkOnline(Async)");
        }
        Object postBody = shape;

        // create path and map variables
        String methodPath = "/slides/watermark"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "fontHeight", fontHeight);
        apiClient.addQueryParameter(queryParams, "text", text);
        apiClient.addQueryParameter(queryParams, "fontName", fontName);
        apiClient.addQueryParameter(queryParams, "fontColor", fontColor);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Adds a text watermark to each slide of the presentation. Text watermark can be setup via method arguments or withing Shape DTO for detailed customization. Both options are applicable simultaneously. 
     * 
     * @param document Document data. (required)
     * @param shape Shape DTO 
     * @param fontHeight Watermark font height. 
     * @param text Watermark text. 
     * @param fontName Watermark font name. 
     * @param fontColor Watermark font color. 
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File createWatermarkOnline(byte[] document, Shape shape, Double fontHeight, String text, String fontName, String fontColor, String password) throws ApiException {
        try {
            ApiResponse<File> resp = createWatermarkOnlineWithHttpInfo(document, shape, fontHeight, text, fontName, fontColor, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = createWatermarkOnlineWithHttpInfo(document, shape, fontHeight, text, fontName, fontColor, password);
            return resp.getData();
        }
    }

    /**
     * Adds a text watermark to each slide of the presentation. Text watermark can be setup via method arguments or withing Shape DTO for detailed customization. Both options are applicable simultaneously. 
     * 
     * @param document Document data. (required)
     * @param shape Shape DTO 
     * @param fontHeight Watermark font height. 
     * @param text Watermark text. 
     * @param fontName Watermark font name. 
     * @param fontColor Watermark font color. 
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> createWatermarkOnlineWithHttpInfo(byte[] document, Shape shape, Double fontHeight, String text, String fontName, String fontColor, String password) throws ApiException {
        com.squareup.okhttp.Call call = createWatermarkOnlineCall(document, shape, fontHeight, text, fontName, fontColor, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Adds a text watermark to each slide of the presentation. Text watermark can be setup via method arguments or withing Shape DTO for detailed customization. Both options are applicable simultaneously.  (asynchronously)
     * 
     * @param document Document data. (required)
     * @param shape Shape DTO 
     * @param fontHeight Watermark font height. 
     * @param text Watermark text. 
     * @param fontName Watermark font name. 
     * @param fontColor Watermark font color. 
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call createWatermarkOnlineAsync(byte[] document, Shape shape, Double fontHeight, String text, String fontName, String fontColor, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = createWatermarkOnlineCall(document, shape, fontHeight, text, fontName, fontColor, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteAnimation
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteAnimation(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteAnimation(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove animation from a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteAnimation(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteAnimationWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteAnimationWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove animation from a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteAnimationWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteAnimationCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove animation from a slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteAnimationCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteAnimationEffect
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationEffectCall(String name, Integer slideIndex, Integer effectIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteAnimationEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteAnimationEffect(Async)");
        }
        // verify the required parameter 'effectIndex' is set
        if (effectIndex == null) {
            throw new ApiException("Missing the required parameter 'effectIndex' when calling deleteAnimationEffect(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation/mainSequence/{effectIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "effectIndex" + "\\}", apiClient.objectToString(effectIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove an effect from slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteAnimationEffect(String name, Integer slideIndex, Integer effectIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteAnimationEffectWithHttpInfo(name, slideIndex, effectIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteAnimationEffectWithHttpInfo(name, slideIndex, effectIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove an effect from slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteAnimationEffectWithHttpInfo(String name, Integer slideIndex, Integer effectIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteAnimationEffectCall(name, slideIndex, effectIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove an effect from slide animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationEffectAsync(String name, Integer slideIndex, Integer effectIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteAnimationEffectCall(name, slideIndex, effectIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteAnimationInteractiveSequence
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The index of an interactive sequence to be deleted. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationInteractiveSequenceCall(String name, Integer slideIndex, Integer sequenceIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteAnimationInteractiveSequence(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteAnimationInteractiveSequence(Async)");
        }
        // verify the required parameter 'sequenceIndex' is set
        if (sequenceIndex == null) {
            throw new ApiException("Missing the required parameter 'sequenceIndex' when calling deleteAnimationInteractiveSequence(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation/interactiveSequences/{sequenceIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "sequenceIndex" + "\\}", apiClient.objectToString(sequenceIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove an interactive sequence from slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The index of an interactive sequence to be deleted. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteAnimationInteractiveSequence(String name, Integer slideIndex, Integer sequenceIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteAnimationInteractiveSequenceWithHttpInfo(name, slideIndex, sequenceIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteAnimationInteractiveSequenceWithHttpInfo(name, slideIndex, sequenceIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove an interactive sequence from slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The index of an interactive sequence to be deleted. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteAnimationInteractiveSequenceWithHttpInfo(String name, Integer slideIndex, Integer sequenceIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteAnimationInteractiveSequenceCall(name, slideIndex, sequenceIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove an interactive sequence from slide animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The index of an interactive sequence to be deleted. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationInteractiveSequenceAsync(String name, Integer slideIndex, Integer sequenceIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteAnimationInteractiveSequenceCall(name, slideIndex, sequenceIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteAnimationInteractiveSequenceEffect
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex Interactive sequence index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationInteractiveSequenceEffectCall(String name, Integer slideIndex, Integer sequenceIndex, Integer effectIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'sequenceIndex' is set
        if (sequenceIndex == null) {
            throw new ApiException("Missing the required parameter 'sequenceIndex' when calling deleteAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'effectIndex' is set
        if (effectIndex == null) {
            throw new ApiException("Missing the required parameter 'effectIndex' when calling deleteAnimationInteractiveSequenceEffect(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation/interactiveSequences/{sequenceIndex}/{effectIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "sequenceIndex" + "\\}", apiClient.objectToString(sequenceIndex)).replaceAll("\\{" + "effectIndex" + "\\}", apiClient.objectToString(effectIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove an effect from slide animation interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex Interactive sequence index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteAnimationInteractiveSequenceEffect(String name, Integer slideIndex, Integer sequenceIndex, Integer effectIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, sequenceIndex, effectIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, sequenceIndex, effectIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove an effect from slide animation interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex Interactive sequence index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteAnimationInteractiveSequenceEffectWithHttpInfo(String name, Integer slideIndex, Integer sequenceIndex, Integer effectIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteAnimationInteractiveSequenceEffectCall(name, slideIndex, sequenceIndex, effectIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove an effect from slide animation interactive sequence. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex Interactive sequence index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationInteractiveSequenceEffectAsync(String name, Integer slideIndex, Integer sequenceIndex, Integer effectIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteAnimationInteractiveSequenceEffectCall(name, slideIndex, sequenceIndex, effectIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteAnimationInteractiveSequences
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationInteractiveSequencesCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteAnimationInteractiveSequences(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteAnimationInteractiveSequences(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation/interactiveSequences"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Clear all interactive sequences from slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteAnimationInteractiveSequences(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteAnimationInteractiveSequencesWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteAnimationInteractiveSequencesWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Clear all interactive sequences from slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteAnimationInteractiveSequencesWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteAnimationInteractiveSequencesCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Clear all interactive sequences from slide animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationInteractiveSequencesAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteAnimationInteractiveSequencesCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteAnimationMainSequence
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationMainSequenceCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteAnimationMainSequence(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteAnimationMainSequence(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation/mainSequence"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Clear main sequence in slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteAnimationMainSequence(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteAnimationMainSequenceWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteAnimationMainSequenceWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Clear main sequence in slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteAnimationMainSequenceWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteAnimationMainSequenceCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Clear main sequence in slide animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteAnimationMainSequenceAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteAnimationMainSequenceCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteBackground
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteBackgroundCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteBackground(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteBackground(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/background"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove background from a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideBackground
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideBackground deleteBackground(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideBackground> resp = deleteBackgroundWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideBackground> resp = deleteBackgroundWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove background from a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideBackground&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideBackground> deleteBackgroundWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteBackgroundCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideBackground>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove background from a slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteBackgroundAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<SlideBackground> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteBackgroundCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideBackground>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteChartCategory
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param categoryIndex Category index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteChartCategoryCall(String name, Integer slideIndex, Integer shapeIndex, Integer categoryIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteChartCategory(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteChartCategory(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteChartCategory(Async)");
        }
        // verify the required parameter 'categoryIndex' is set
        if (categoryIndex == null) {
            throw new ApiException("Missing the required parameter 'categoryIndex' when calling deleteChartCategory(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/categories/{categoryIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "categoryIndex" + "\\}", apiClient.objectToString(categoryIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Delete a category from a chart.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param categoryIndex Category index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Chart
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Chart deleteChartCategory(String name, Integer slideIndex, Integer shapeIndex, Integer categoryIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Chart> resp = deleteChartCategoryWithHttpInfo(name, slideIndex, shapeIndex, categoryIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Chart> resp = deleteChartCategoryWithHttpInfo(name, slideIndex, shapeIndex, categoryIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Delete a category from a chart.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param categoryIndex Category index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Chart&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Chart> deleteChartCategoryWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer categoryIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteChartCategoryCall(name, slideIndex, shapeIndex, categoryIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Chart>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Delete a category from a chart. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param categoryIndex Category index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteChartCategoryAsync(String name, Integer slideIndex, Integer shapeIndex, Integer categoryIndex, String password, String folder, String storage, final ApiCallback<Chart> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteChartCategoryCall(name, slideIndex, shapeIndex, categoryIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Chart>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteChartDataPoint
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param pointIndex Data point index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteChartDataPointCall(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Integer pointIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteChartDataPoint(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteChartDataPoint(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteChartDataPoint(Async)");
        }
        // verify the required parameter 'seriesIndex' is set
        if (seriesIndex == null) {
            throw new ApiException("Missing the required parameter 'seriesIndex' when calling deleteChartDataPoint(Async)");
        }
        // verify the required parameter 'pointIndex' is set
        if (pointIndex == null) {
            throw new ApiException("Missing the required parameter 'pointIndex' when calling deleteChartDataPoint(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/series/{seriesIndex}/dataPoints/{pointIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "seriesIndex" + "\\}", apiClient.objectToString(seriesIndex)).replaceAll("\\{" + "pointIndex" + "\\}", apiClient.objectToString(pointIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Delete a data point from a chart series.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param pointIndex Data point index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Chart
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Chart deleteChartDataPoint(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Integer pointIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Chart> resp = deleteChartDataPointWithHttpInfo(name, slideIndex, shapeIndex, seriesIndex, pointIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Chart> resp = deleteChartDataPointWithHttpInfo(name, slideIndex, shapeIndex, seriesIndex, pointIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Delete a data point from a chart series.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param pointIndex Data point index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Chart&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Chart> deleteChartDataPointWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Integer pointIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteChartDataPointCall(name, slideIndex, shapeIndex, seriesIndex, pointIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Chart>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Delete a data point from a chart series. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param pointIndex Data point index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteChartDataPointAsync(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Integer pointIndex, String password, String folder, String storage, final ApiCallback<Chart> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteChartDataPointCall(name, slideIndex, shapeIndex, seriesIndex, pointIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Chart>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteChartSeries
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param seriesIndex Series index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteChartSeriesCall(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteChartSeries(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteChartSeries(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteChartSeries(Async)");
        }
        // verify the required parameter 'seriesIndex' is set
        if (seriesIndex == null) {
            throw new ApiException("Missing the required parameter 'seriesIndex' when calling deleteChartSeries(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/series/{seriesIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "seriesIndex" + "\\}", apiClient.objectToString(seriesIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Delete a series from a chart.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param seriesIndex Series index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Chart
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Chart deleteChartSeries(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Chart> resp = deleteChartSeriesWithHttpInfo(name, slideIndex, shapeIndex, seriesIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Chart> resp = deleteChartSeriesWithHttpInfo(name, slideIndex, shapeIndex, seriesIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Delete a series from a chart.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param seriesIndex Series index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Chart&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Chart> deleteChartSeriesWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteChartSeriesCall(name, slideIndex, shapeIndex, seriesIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Chart>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Delete a series from a chart. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param seriesIndex Series index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteChartSeriesAsync(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, String password, String folder, String storage, final ApiCallback<Chart> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteChartSeriesCall(name, slideIndex, shapeIndex, seriesIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Chart>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteComments
     * @param name Document name. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteCommentsCall(String name, String author, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteComments(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/comments"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "author", author);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Removes comments of the specified author from the presentation. If author value is not provided all comments will be removed. 
     * 
     * @param name Document name. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void deleteComments(String name, String author, String password, String folder, String storage) throws ApiException {
        try {
            deleteCommentsWithHttpInfo(name, author, password, folder, storage);
        } catch (NeedRepeatRequestException e) {
            deleteCommentsWithHttpInfo(name, author, password, folder, storage);
        }
    }

    /**
     * Removes comments of the specified author from the presentation. If author value is not provided all comments will be removed. 
     * 
     * @param name Document name. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> deleteCommentsWithHttpInfo(String name, String author, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteCommentsCall(name, author, password, folder, storage, null, null);
        return apiClient.execute(call);
    }

    /**
     * Removes comments of the specified author from the presentation. If author value is not provided all comments will be removed.  (asynchronously)
     * 
     * @param name Document name. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteCommentsAsync(String name, String author, String password, String folder, String storage, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteCommentsCall(name, author, password, folder, storage, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for deleteCommentsOnline
     * @param document Document data. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteCommentsOnlineCall(byte[] document, String author, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling deleteCommentsOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/comments/delete"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "author", author);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Removes comments of the specified author from the presentation. If author value is not provided all comments will be removed. 
     * 
     * @param document Document data. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File deleteCommentsOnline(byte[] document, String author, String password) throws ApiException {
        try {
            ApiResponse<File> resp = deleteCommentsOnlineWithHttpInfo(document, author, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = deleteCommentsOnlineWithHttpInfo(document, author, password);
            return resp.getData();
        }
    }

    /**
     * Removes comments of the specified author from the presentation. If author value is not provided all comments will be removed. 
     * 
     * @param document Document data. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> deleteCommentsOnlineWithHttpInfo(byte[] document, String author, String password) throws ApiException {
        com.squareup.okhttp.Call call = deleteCommentsOnlineCall(document, author, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Removes comments of the specified author from the presentation. If author value is not provided all comments will be removed.  (asynchronously)
     * 
     * @param document Document data. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteCommentsOnlineAsync(byte[] document, String author, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteCommentsOnlineCall(document, author, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteDocumentProperties
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteDocumentPropertiesCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteDocumentProperties(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/documentproperties"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Clean document properties.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return DocumentProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public DocumentProperties deleteDocumentProperties(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<DocumentProperties> resp = deleteDocumentPropertiesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<DocumentProperties> resp = deleteDocumentPropertiesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Clean document properties.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;DocumentProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<DocumentProperties> deleteDocumentPropertiesWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteDocumentPropertiesCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<DocumentProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Clean document properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteDocumentPropertiesAsync(String name, String password, String folder, String storage, final ApiCallback<DocumentProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteDocumentPropertiesCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<DocumentProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteDocumentProperty
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteDocumentPropertyCall(String name, String propertyName, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteDocumentProperty(Async)");
        }
        // verify the required parameter 'propertyName' is set
        if (propertyName == null) {
            throw new ApiException("Missing the required parameter 'propertyName' when calling deleteDocumentProperty(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/documentproperties/{propertyName}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "propertyName" + "\\}", apiClient.objectToString(propertyName));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Delete document property.
     * 
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return DocumentProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public DocumentProperties deleteDocumentProperty(String name, String propertyName, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<DocumentProperties> resp = deleteDocumentPropertyWithHttpInfo(name, propertyName, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<DocumentProperties> resp = deleteDocumentPropertyWithHttpInfo(name, propertyName, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Delete document property.
     * 
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;DocumentProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<DocumentProperties> deleteDocumentPropertyWithHttpInfo(String name, String propertyName, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteDocumentPropertyCall(name, propertyName, password, folder, storage, null, null);
        Type returnType = new TypeToken<DocumentProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Delete document property. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteDocumentPropertyAsync(String name, String propertyName, String password, String folder, String storage, final ApiCallback<DocumentProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteDocumentPropertyCall(name, propertyName, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<DocumentProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteFile
     * @param path File path e.g. '/folder/file.ext' 
     * @param storageName Storage name 
     * @param versionId File version ID to delete 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteFileCall(String path, String storageName, String versionId, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/file/{path}"
            .replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storageName", storageName);
        apiClient.addQueryParameter(queryParams, "versionId", versionId);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Delete file
     * 
     * @param path File path e.g. '/folder/file.ext' 
     * @param storageName Storage name 
     * @param versionId File version ID to delete 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void deleteFile(String path, String storageName, String versionId) throws ApiException {
        try {
            deleteFileWithHttpInfo(path, storageName, versionId);
        } catch (NeedRepeatRequestException e) {
            deleteFileWithHttpInfo(path, storageName, versionId);
        }
    }

    /**
     * Delete file
     * 
     * @param path File path e.g. '/folder/file.ext' 
     * @param storageName Storage name 
     * @param versionId File version ID to delete 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> deleteFileWithHttpInfo(String path, String storageName, String versionId) throws ApiException {
        com.squareup.okhttp.Call call = deleteFileCall(path, storageName, versionId, null, null);
        return apiClient.execute(call);
    }

    /**
     * Delete file (asynchronously)
     * 
     * @param path File path e.g. '/folder/file.ext' 
     * @param storageName Storage name 
     * @param versionId File version ID to delete 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteFileAsync(String path, String storageName, String versionId, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteFileCall(path, storageName, versionId, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for deleteFolder
     * @param path Folder path e.g. '/folder' 
     * @param storageName Storage name 
     * @param recursive Enable to delete folders, subfolders and files 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteFolderCall(String path, String storageName, Boolean recursive, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/folder/{path}"
            .replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storageName", storageName);
        apiClient.addQueryParameter(queryParams, "recursive", recursive);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Delete folder
     * 
     * @param path Folder path e.g. '/folder' 
     * @param storageName Storage name 
     * @param recursive Enable to delete folders, subfolders and files 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void deleteFolder(String path, String storageName, Boolean recursive) throws ApiException {
        try {
            deleteFolderWithHttpInfo(path, storageName, recursive);
        } catch (NeedRepeatRequestException e) {
            deleteFolderWithHttpInfo(path, storageName, recursive);
        }
    }

    /**
     * Delete folder
     * 
     * @param path Folder path e.g. '/folder' 
     * @param storageName Storage name 
     * @param recursive Enable to delete folders, subfolders and files 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> deleteFolderWithHttpInfo(String path, String storageName, Boolean recursive) throws ApiException {
        com.squareup.okhttp.Call call = deleteFolderCall(path, storageName, recursive, null, null);
        return apiClient.execute(call);
    }

    /**
     * Delete folder (asynchronously)
     * 
     * @param path Folder path e.g. '/folder' 
     * @param storageName Storage name 
     * @param recursive Enable to delete folders, subfolders and files 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteFolderAsync(String path, String storageName, Boolean recursive, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteFolderCall(path, storageName, recursive, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for deleteNotesSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteNotesSlideCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteNotesSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteNotesSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/notesSlide"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove notes slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Slide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Slide deleteNotesSlide(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Slide> resp = deleteNotesSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Slide> resp = deleteNotesSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove notes slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Slide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Slide> deleteNotesSlideWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteNotesSlideCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Slide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove notes slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteNotesSlideAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<Slide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteNotesSlideCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Slide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteParagraph
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteParagraphCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deleteParagraph(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a paragraph.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs deleteParagraph(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = deleteParagraphWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = deleteParagraphWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a paragraph.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> deleteParagraphWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteParagraphCall(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a paragraph. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteParagraphAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteParagraphCall(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteParagraphs
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the paragraphs to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteParagraphsCall(String name, Integer slideIndex, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteParagraphs(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteParagraphs(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteParagraphs(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "paragraphs", paragraphs);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of paragraphs.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the paragraphs to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs deleteParagraphs(String name, Integer slideIndex, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = deleteParagraphsWithHttpInfo(name, slideIndex, shapeIndex, paragraphs, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = deleteParagraphsWithHttpInfo(name, slideIndex, shapeIndex, paragraphs, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of paragraphs.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the paragraphs to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> deleteParagraphsWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteParagraphsCall(name, slideIndex, shapeIndex, paragraphs, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of paragraphs. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the paragraphs to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteParagraphsAsync(String name, Integer slideIndex, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteParagraphsCall(name, slideIndex, shapeIndex, paragraphs, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deletePortion
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deletePortionCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deletePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deletePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deletePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deletePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling deletePortion(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a portion.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions deletePortion(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = deletePortionWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = deletePortionWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a portion.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> deletePortionWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deletePortionCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a portion. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deletePortionAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deletePortionCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deletePortions
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the portions to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deletePortionsCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deletePortions(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deletePortions(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deletePortions(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deletePortions(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "portions", portions);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of portions.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the portions to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions deletePortions(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = deletePortionsWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portions, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = deletePortionsWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portions, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of portions.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the portions to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> deletePortionsWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deletePortionsCall(name, slideIndex, shapeIndex, paragraphIndex, portions, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of portions. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the portions to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deletePortionsAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deletePortionsCall(name, slideIndex, shapeIndex, paragraphIndex, portions, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteProtection
     * @param name Document name. (required)
     * @param password Presentation password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteProtectionCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteProtection(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/protection"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Resets all presentation protection settings. 
     * 
     * @param name Document name. (required)
     * @param password Presentation password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ProtectionProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ProtectionProperties deleteProtection(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ProtectionProperties> resp = deleteProtectionWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ProtectionProperties> resp = deleteProtectionWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Resets all presentation protection settings. 
     * 
     * @param name Document name. (required)
     * @param password Presentation password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ProtectionProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ProtectionProperties> deleteProtectionWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteProtectionCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<ProtectionProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Resets all presentation protection settings.  (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Presentation password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteProtectionAsync(String name, String password, String folder, String storage, final ApiCallback<ProtectionProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteProtectionCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ProtectionProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteProtectionOnline
     * @param document Document data. (required)
     * @param password Presentation password. (required)
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteProtectionOnlineCall(byte[] document, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling deleteProtectionOnline(Async)");
        }
        // verify the required parameter 'password' is set
        if (password == null) {
            throw new ApiException("Missing the required parameter 'password' when calling deleteProtectionOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/protection/delete"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Resets all presentation protection settings. 
     * 
     * @param document Document data. (required)
     * @param password Presentation password. (required)
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File deleteProtectionOnline(byte[] document, String password) throws ApiException {
        try {
            ApiResponse<File> resp = deleteProtectionOnlineWithHttpInfo(document, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = deleteProtectionOnlineWithHttpInfo(document, password);
            return resp.getData();
        }
    }

    /**
     * Resets all presentation protection settings. 
     * 
     * @param document Document data. (required)
     * @param password Presentation password. (required)
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> deleteProtectionOnlineWithHttpInfo(byte[] document, String password) throws ApiException {
        com.squareup.okhttp.Call call = deleteProtectionOnlineCall(document, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Resets all presentation protection settings.  (asynchronously)
     * 
     * @param document Document data. (required)
     * @param password Presentation password. (required)
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteProtectionOnlineAsync(byte[] document, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteProtectionOnlineCall(document, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSection
     * @param name Document name. (required)
     * @param sectionIndex Section index. (required)
     * @param withSlides True to delete the slides related to the deleted section; move them to the remaining sections otherwise. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSectionCall(String name, Integer sectionIndex, Boolean withSlides, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSection(Async)");
        }
        // verify the required parameter 'sectionIndex' is set
        if (sectionIndex == null) {
            throw new ApiException("Missing the required parameter 'sectionIndex' when calling deleteSection(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/sections/{sectionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "sectionIndex" + "\\}", apiClient.objectToString(sectionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "withSlides", withSlides);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Delete a presentation section.
     * 
     * @param name Document name. (required)
     * @param sectionIndex Section index. (required)
     * @param withSlides True to delete the slides related to the deleted section; move them to the remaining sections otherwise. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Sections
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Sections deleteSection(String name, Integer sectionIndex, Boolean withSlides, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Sections> resp = deleteSectionWithHttpInfo(name, sectionIndex, withSlides, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Sections> resp = deleteSectionWithHttpInfo(name, sectionIndex, withSlides, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Delete a presentation section.
     * 
     * @param name Document name. (required)
     * @param sectionIndex Section index. (required)
     * @param withSlides True to delete the slides related to the deleted section; move them to the remaining sections otherwise. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Sections&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Sections> deleteSectionWithHttpInfo(String name, Integer sectionIndex, Boolean withSlides, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSectionCall(name, sectionIndex, withSlides, password, folder, storage, null, null);
        Type returnType = new TypeToken<Sections>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Delete a presentation section. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param sectionIndex Section index. (required)
     * @param withSlides True to delete the slides related to the deleted section; move them to the remaining sections otherwise. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSectionAsync(String name, Integer sectionIndex, Boolean withSlides, String password, String folder, String storage, final ApiCallback<Sections> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSectionCall(name, sectionIndex, withSlides, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Sections>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSections
     * @param name Document name. (required)
     * @param sections The indices of the sections to be deleted; delete all by default. 
     * @param withSlides True to delete the slides related to the deleted sections; move them to the remaining sections otherwise. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSectionsCall(String name, List<Integer> sections, Boolean withSlides, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSections(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/sections"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "sections", sections);
        apiClient.addQueryParameter(queryParams, "withSlides", withSlides);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Delete presentation sections.
     * 
     * @param name Document name. (required)
     * @param sections The indices of the sections to be deleted; delete all by default. 
     * @param withSlides True to delete the slides related to the deleted sections; move them to the remaining sections otherwise. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Sections
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Sections deleteSections(String name, List<Integer> sections, Boolean withSlides, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Sections> resp = deleteSectionsWithHttpInfo(name, sections, withSlides, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Sections> resp = deleteSectionsWithHttpInfo(name, sections, withSlides, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Delete presentation sections.
     * 
     * @param name Document name. (required)
     * @param sections The indices of the sections to be deleted; delete all by default. 
     * @param withSlides True to delete the slides related to the deleted sections; move them to the remaining sections otherwise. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Sections&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Sections> deleteSectionsWithHttpInfo(String name, List<Integer> sections, Boolean withSlides, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSectionsCall(name, sections, withSlides, password, folder, storage, null, null);
        Type returnType = new TypeToken<Sections>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Delete presentation sections. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param sections The indices of the sections to be deleted; delete all by default. 
     * @param withSlides True to delete the slides related to the deleted sections; move them to the remaining sections otherwise. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSectionsAsync(String name, List<Integer> sections, Boolean withSlides, String password, String folder, String storage, final ApiCallback<Sections> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSectionsCall(name, sections, withSlides, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Sections>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteShape
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteShapeCall(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteShape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteShape(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a shape.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes deleteShape(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = deleteShapeWithHttpInfo(name, slideIndex, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = deleteShapeWithHttpInfo(name, slideIndex, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a shape.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> deleteShapeWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteShapeCall(name, slideIndex, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a shape. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteShapeAsync(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteShapeCall(name, slideIndex, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteShapes
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteShapesCall(String name, Integer slideIndex, List<Integer> shapes, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteShapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteShapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapes", shapes);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of shapes.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes deleteShapes(String name, Integer slideIndex, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = deleteShapesWithHttpInfo(name, slideIndex, shapes, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = deleteShapesWithHttpInfo(name, slideIndex, shapes, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of shapes.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> deleteShapesWithHttpInfo(String name, Integer slideIndex, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteShapesCall(name, slideIndex, shapes, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of shapes. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteShapesAsync(String name, Integer slideIndex, List<Integer> shapes, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteShapesCall(name, slideIndex, shapes, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSlideCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Delete a presentation slide by index.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Slides
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Slides deleteSlide(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Slides> resp = deleteSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Slides> resp = deleteSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Delete a presentation slide by index.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Slides&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Slides> deleteSlideWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSlideCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Slides>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Delete a presentation slide by index. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSlideAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<Slides> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSlideCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Slides>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSlideComments
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSlideCommentsCall(String name, Integer slideIndex, String author, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSlideComments(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSlideComments(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/comments"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "author", author);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Removes comments of the specified author from the slide. If author value is not provided all comments will be removed. 
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideComments
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideComments deleteSlideComments(String name, Integer slideIndex, String author, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideComments> resp = deleteSlideCommentsWithHttpInfo(name, slideIndex, author, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideComments> resp = deleteSlideCommentsWithHttpInfo(name, slideIndex, author, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Removes comments of the specified author from the slide. If author value is not provided all comments will be removed. 
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideComments&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideComments> deleteSlideCommentsWithHttpInfo(String name, Integer slideIndex, String author, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSlideCommentsCall(name, slideIndex, author, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideComments>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Removes comments of the specified author from the slide. If author value is not provided all comments will be removed.  (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSlideCommentsAsync(String name, Integer slideIndex, String author, String password, String folder, String storage, final ApiCallback<SlideComments> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSlideCommentsCall(name, slideIndex, author, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideComments>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSlideCommentsOnline
     * @param document Document data. (required)
     * @param slideIndex  (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSlideCommentsOnlineCall(byte[] document, Integer slideIndex, String author, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling deleteSlideCommentsOnline(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSlideCommentsOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/slides/{slideIndex}/comments/delete"
            .replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "author", author);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Removes comments of the specified author from the slide. If author value is not provided all comments will be removed.              
     * 
     * @param document Document data. (required)
     * @param slideIndex  (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File deleteSlideCommentsOnline(byte[] document, Integer slideIndex, String author, String password) throws ApiException {
        try {
            ApiResponse<File> resp = deleteSlideCommentsOnlineWithHttpInfo(document, slideIndex, author, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = deleteSlideCommentsOnlineWithHttpInfo(document, slideIndex, author, password);
            return resp.getData();
        }
    }

    /**
     * Removes comments of the specified author from the slide. If author value is not provided all comments will be removed.              
     * 
     * @param document Document data. (required)
     * @param slideIndex  (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> deleteSlideCommentsOnlineWithHttpInfo(byte[] document, Integer slideIndex, String author, String password) throws ApiException {
        com.squareup.okhttp.Call call = deleteSlideCommentsOnlineCall(document, slideIndex, author, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Removes comments of the specified author from the slide. If author value is not provided all comments will be removed.               (asynchronously)
     * 
     * @param document Document data. (required)
     * @param slideIndex  (required)
     * @param author Author of comments. 
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSlideCommentsOnlineAsync(byte[] document, Integer slideIndex, String author, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSlideCommentsOnlineCall(document, slideIndex, author, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSlides
     * @param name Document name. (required)
     * @param slides The indices of the slides to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSlidesCall(String name, List<Integer> slides, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSlides(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "slides", slides);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Delete presentation slides.
     * 
     * @param name Document name. (required)
     * @param slides The indices of the slides to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Slides
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Slides deleteSlides(String name, List<Integer> slides, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Slides> resp = deleteSlidesWithHttpInfo(name, slides, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Slides> resp = deleteSlidesWithHttpInfo(name, slides, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Delete presentation slides.
     * 
     * @param name Document name. (required)
     * @param slides The indices of the slides to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Slides&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Slides> deleteSlidesWithHttpInfo(String name, List<Integer> slides, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSlidesCall(name, slides, password, folder, storage, null, null);
        Type returnType = new TypeToken<Slides>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Delete presentation slides. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slides The indices of the slides to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSlidesAsync(String name, List<Integer> slides, String password, String folder, String storage, final ApiCallback<Slides> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSlidesCall(name, slides, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Slides>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideAnimation
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationCall(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideAnimation(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideAnimation(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideAnimation(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove animation from a special slide (master, layout, notes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteSpecialSlideAnimation(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationWithHttpInfo(name, slideIndex, slideType, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationWithHttpInfo(name, slideIndex, slideType, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove animation from a special slide (master, layout, notes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteSpecialSlideAnimationWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationCall(name, slideIndex, slideType, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove animation from a special slide (master, layout, notes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationAsync(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationCall(name, slideIndex, slideType, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideAnimationEffect
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationEffectCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer effectIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideAnimationEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideAnimationEffect(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideAnimationEffect(Async)");
        }
        // verify the required parameter 'effectIndex' is set
        if (effectIndex == null) {
            throw new ApiException("Missing the required parameter 'effectIndex' when calling deleteSpecialSlideAnimationEffect(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation/mainSequence/{effectIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "effectIndex" + "\\}", apiClient.objectToString(effectIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove an effect from special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteSpecialSlideAnimationEffect(String name, Integer slideIndex, SpecialSlideType slideType, Integer effectIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationEffectWithHttpInfo(name, slideIndex, slideType, effectIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationEffectWithHttpInfo(name, slideIndex, slideType, effectIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove an effect from special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteSpecialSlideAnimationEffectWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer effectIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationEffectCall(name, slideIndex, slideType, effectIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove an effect from special slide (master, layout, notes) animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationEffectAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer effectIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationEffectCall(name, slideIndex, slideType, effectIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideAnimationInteractiveSequence
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The index of an interactive sequence to be deleted. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationInteractiveSequenceCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideAnimationInteractiveSequence(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideAnimationInteractiveSequence(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideAnimationInteractiveSequence(Async)");
        }
        // verify the required parameter 'sequenceIndex' is set
        if (sequenceIndex == null) {
            throw new ApiException("Missing the required parameter 'sequenceIndex' when calling deleteSpecialSlideAnimationInteractiveSequence(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation/interactiveSequences/{sequenceIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "sequenceIndex" + "\\}", apiClient.objectToString(sequenceIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove an interactive sequence from special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The index of an interactive sequence to be deleted. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteSpecialSlideAnimationInteractiveSequence(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationInteractiveSequenceWithHttpInfo(name, slideIndex, slideType, sequenceIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationInteractiveSequenceWithHttpInfo(name, slideIndex, slideType, sequenceIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove an interactive sequence from special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The index of an interactive sequence to be deleted. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteSpecialSlideAnimationInteractiveSequenceWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationInteractiveSequenceCall(name, slideIndex, slideType, sequenceIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove an interactive sequence from special slide (master, layout, notes) animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The index of an interactive sequence to be deleted. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationInteractiveSequenceAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationInteractiveSequenceCall(name, slideIndex, slideType, sequenceIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideAnimationInteractiveSequenceEffect
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex Interactive sequence index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationInteractiveSequenceEffectCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Integer effectIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'sequenceIndex' is set
        if (sequenceIndex == null) {
            throw new ApiException("Missing the required parameter 'sequenceIndex' when calling deleteSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'effectIndex' is set
        if (effectIndex == null) {
            throw new ApiException("Missing the required parameter 'effectIndex' when calling deleteSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation/interactiveSequences/{sequenceIndex}/{effectIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "sequenceIndex" + "\\}", apiClient.objectToString(sequenceIndex)).replaceAll("\\{" + "effectIndex" + "\\}", apiClient.objectToString(effectIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove an effect from special slide (master, layout, notes) animation interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex Interactive sequence index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteSpecialSlideAnimationInteractiveSequenceEffect(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Integer effectIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, slideType, sequenceIndex, effectIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, slideType, sequenceIndex, effectIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove an effect from special slide (master, layout, notes) animation interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex Interactive sequence index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteSpecialSlideAnimationInteractiveSequenceEffectWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Integer effectIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationInteractiveSequenceEffectCall(name, slideIndex, slideType, sequenceIndex, effectIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove an effect from special slide (master, layout, notes) animation interactive sequence. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex Interactive sequence index. (required)
     * @param effectIndex Index of the effect to be removed. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationInteractiveSequenceEffectAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Integer effectIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationInteractiveSequenceEffectCall(name, slideIndex, slideType, sequenceIndex, effectIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideAnimationInteractiveSequences
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationInteractiveSequencesCall(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideAnimationInteractiveSequences(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideAnimationInteractiveSequences(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideAnimationInteractiveSequences(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation/interactiveSequences"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Clear all interactive sequences from special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteSpecialSlideAnimationInteractiveSequences(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationInteractiveSequencesWithHttpInfo(name, slideIndex, slideType, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationInteractiveSequencesWithHttpInfo(name, slideIndex, slideType, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Clear all interactive sequences from special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteSpecialSlideAnimationInteractiveSequencesWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationInteractiveSequencesCall(name, slideIndex, slideType, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Clear all interactive sequences from special slide (master, layout, notes) animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationInteractiveSequencesAsync(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationInteractiveSequencesCall(name, slideIndex, slideType, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideAnimationMainSequence
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationMainSequenceCall(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideAnimationMainSequence(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideAnimationMainSequence(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideAnimationMainSequence(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation/mainSequence"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Clear main sequence in special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation deleteSpecialSlideAnimationMainSequence(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationMainSequenceWithHttpInfo(name, slideIndex, slideType, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = deleteSpecialSlideAnimationMainSequenceWithHttpInfo(name, slideIndex, slideType, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Clear main sequence in special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> deleteSpecialSlideAnimationMainSequenceWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationMainSequenceCall(name, slideIndex, slideType, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Clear main sequence in special slide (master, layout, notes) animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideAnimationMainSequenceAsync(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideAnimationMainSequenceCall(name, slideIndex, slideType, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideParagraph
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideParagraphCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deleteSpecialSlideParagraph(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a paragraph.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs deleteSpecialSlideParagraph(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = deleteSpecialSlideParagraphWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = deleteSpecialSlideParagraphWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a paragraph.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> deleteSpecialSlideParagraphWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideParagraphCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a paragraph. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideParagraphAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideParagraphCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideParagraphs
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideParagraphsCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideParagraphs(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideParagraphs(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideParagraphs(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSpecialSlideParagraphs(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "paragraphs", paragraphs);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of paragraphs.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs deleteSpecialSlideParagraphs(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = deleteSpecialSlideParagraphsWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphs, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = deleteSpecialSlideParagraphsWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphs, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of paragraphs.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> deleteSpecialSlideParagraphsWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideParagraphsCall(name, slideIndex, slideType, shapeIndex, paragraphs, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of paragraphs. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideParagraphsAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideParagraphsCall(name, slideIndex, slideType, shapeIndex, paragraphs, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlidePortion
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlidePortionCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deleteSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling deleteSpecialSlidePortion(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a portion.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions deleteSpecialSlidePortion(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = deleteSpecialSlidePortionWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = deleteSpecialSlidePortionWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a portion.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> deleteSpecialSlidePortionWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlidePortionCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a portion. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlidePortionAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlidePortionCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlidePortions
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlidePortionsCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlidePortions(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlidePortions(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlidePortions(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSpecialSlidePortions(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deleteSpecialSlidePortions(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "portions", portions);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of portions.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions deleteSpecialSlidePortions(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = deleteSpecialSlidePortionsWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, portions, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = deleteSpecialSlidePortionsWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, portions, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of portions.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> deleteSpecialSlidePortionsWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlidePortionsCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, portions, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of portions. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlidePortionsAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlidePortionsCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, portions, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideShape
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideShapeCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideShape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSpecialSlideShape(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a shape.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes deleteSpecialSlideShape(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = deleteSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = deleteSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a shape.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> deleteSpecialSlideShapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideShapeCall(name, slideIndex, slideType, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a shape. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideShapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideShapeCall(name, slideIndex, slideType, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideShapes
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideShapesCall(String name, Integer slideIndex, SpecialSlideType slideType, List<Integer> shapes, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideShapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideShapes(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideShapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapes", shapes);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of shapes.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes deleteSpecialSlideShapes(String name, Integer slideIndex, SpecialSlideType slideType, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = deleteSpecialSlideShapesWithHttpInfo(name, slideIndex, slideType, shapes, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = deleteSpecialSlideShapesWithHttpInfo(name, slideIndex, slideType, shapes, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of shapes.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> deleteSpecialSlideShapesWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideShapesCall(name, slideIndex, slideType, shapes, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of shapes. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideShapesAsync(String name, Integer slideIndex, SpecialSlideType slideType, List<Integer> shapes, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideShapesCall(name, slideIndex, slideType, shapes, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideSubshape
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapeCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSpecialSlideSubshape(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a shape (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes deleteSpecialSlideSubshape(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = deleteSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = deleteSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a shape (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> deleteSpecialSlideSubshapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapeCall(name, slideIndex, slideType, path, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a shape (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapeCall(name, slideIndex, slideType, path, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideSubshapeParagraph
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapeParagraphCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deleteSpecialSlideSubshapeParagraph(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a paragraph (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs deleteSpecialSlideSubshapeParagraph(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = deleteSpecialSlideSubshapeParagraphWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = deleteSpecialSlideSubshapeParagraphWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a paragraph (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> deleteSpecialSlideSubshapeParagraphWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapeParagraphCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a paragraph (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapeParagraphAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapeParagraphCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideSubshapeParagraphs
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapeParagraphsCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideSubshapeParagraphs(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideSubshapeParagraphs(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideSubshapeParagraphs(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSpecialSlideSubshapeParagraphs(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "paragraphs", paragraphs);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of paragraphs (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs deleteSpecialSlideSubshapeParagraphs(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = deleteSpecialSlideSubshapeParagraphsWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphs, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = deleteSpecialSlideSubshapeParagraphsWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphs, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of paragraphs (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> deleteSpecialSlideSubshapeParagraphsWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapeParagraphsCall(name, slideIndex, slideType, path, shapeIndex, paragraphs, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of paragraphs (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapeParagraphsAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapeParagraphsCall(name, slideIndex, slideType, path, shapeIndex, paragraphs, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideSubshapePortion
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapePortionCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deleteSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling deleteSpecialSlideSubshapePortion(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a portion (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions deleteSpecialSlideSubshapePortion(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = deleteSpecialSlideSubshapePortionWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = deleteSpecialSlideSubshapePortionWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a portion (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> deleteSpecialSlideSubshapePortionWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapePortionCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a portion (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapePortionAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapePortionCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideSubshapePortions
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapePortionsCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideSubshapePortions(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideSubshapePortions(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideSubshapePortions(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSpecialSlideSubshapePortions(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deleteSpecialSlideSubshapePortions(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "portions", portions);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of portions (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions deleteSpecialSlideSubshapePortions(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = deleteSpecialSlideSubshapePortionsWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portions, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = deleteSpecialSlideSubshapePortionsWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portions, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of portions (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> deleteSpecialSlideSubshapePortionsWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapePortionsCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portions, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of portions (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapePortionsAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapePortionsCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portions, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSpecialSlideSubshapes
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapesCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, List<Integer> shapes, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSpecialSlideSubshapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSpecialSlideSubshapes(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling deleteSpecialSlideSubshapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapes", shapes);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of shapes (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes deleteSpecialSlideSubshapes(String name, Integer slideIndex, SpecialSlideType slideType, String path, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = deleteSpecialSlideSubshapesWithHttpInfo(name, slideIndex, slideType, path, shapes, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = deleteSpecialSlideSubshapesWithHttpInfo(name, slideIndex, slideType, path, shapes, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of shapes (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> deleteSpecialSlideSubshapesWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapesCall(name, slideIndex, slideType, path, shapes, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of shapes (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSpecialSlideSubshapesAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, List<Integer> shapes, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSpecialSlideSubshapesCall(name, slideIndex, slideType, path, shapes, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSubshape
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapeCall(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSubshape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSubshape(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a shape (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes deleteSubshape(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = deleteSubshapeWithHttpInfo(name, slideIndex, path, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = deleteSubshapeWithHttpInfo(name, slideIndex, path, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a shape (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> deleteSubshapeWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSubshapeCall(name, slideIndex, path, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a shape (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapeAsync(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSubshapeCall(name, slideIndex, path, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSubshapeParagraph
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapeParagraphCall(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSubshapeParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSubshapeParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deleteSubshapeParagraph(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a paragraph (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs deleteSubshapeParagraph(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = deleteSubshapeParagraphWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = deleteSubshapeParagraphWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a paragraph (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> deleteSubshapeParagraphWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSubshapeParagraphCall(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a paragraph (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapeParagraphAsync(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSubshapeParagraphCall(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSubshapeParagraphs
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the paragraphs to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapeParagraphsCall(String name, Integer slideIndex, String path, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSubshapeParagraphs(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSubshapeParagraphs(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSubshapeParagraphs(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "paragraphs", paragraphs);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of paragraphs (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the paragraphs to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs deleteSubshapeParagraphs(String name, Integer slideIndex, String path, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = deleteSubshapeParagraphsWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphs, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = deleteSubshapeParagraphsWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphs, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of paragraphs (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the paragraphs to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> deleteSubshapeParagraphsWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSubshapeParagraphsCall(name, slideIndex, path, shapeIndex, paragraphs, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of paragraphs (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphs The indices of the paragraphs to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapeParagraphsAsync(String name, Integer slideIndex, String path, Integer shapeIndex, List<Integer> paragraphs, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSubshapeParagraphsCall(name, slideIndex, path, shapeIndex, paragraphs, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSubshapePortion
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapePortionCall(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSubshapePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSubshapePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSubshapePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deleteSubshapePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling deleteSubshapePortion(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a portion (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions deleteSubshapePortion(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = deleteSubshapePortionWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = deleteSubshapePortionWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a portion (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> deleteSubshapePortionWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSubshapePortionCall(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a portion (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapePortionAsync(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSubshapePortionCall(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSubshapePortions
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the portions to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapePortionsCall(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSubshapePortions(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSubshapePortions(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling deleteSubshapePortions(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling deleteSubshapePortions(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "portions", portions);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of portions (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the portions to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions deleteSubshapePortions(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = deleteSubshapePortionsWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, portions, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = deleteSubshapePortionsWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, portions, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of portions (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the portions to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> deleteSubshapePortionsWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSubshapePortionsCall(name, slideIndex, path, shapeIndex, paragraphIndex, portions, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of portions (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portions The indices of the portions to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapePortionsAsync(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, List<Integer> portions, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSubshapePortionsCall(name, slideIndex, path, shapeIndex, paragraphIndex, portions, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteSubshapes
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapesCall(String name, Integer slideIndex, String path, List<Integer> shapes, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteSubshapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling deleteSubshapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapes", shapes);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Remove a range of shapes (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes deleteSubshapes(String name, Integer slideIndex, String path, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = deleteSubshapesWithHttpInfo(name, slideIndex, path, shapes, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = deleteSubshapesWithHttpInfo(name, slideIndex, path, shapes, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Remove a range of shapes (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> deleteSubshapesWithHttpInfo(String name, Integer slideIndex, String path, List<Integer> shapes, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteSubshapesCall(name, slideIndex, path, shapes, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Remove a range of shapes (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapes The indices of the shapes to be deleted; delete all by default. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteSubshapesAsync(String name, Integer slideIndex, String path, List<Integer> shapes, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteSubshapesCall(name, slideIndex, path, shapes, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteUnusedLayoutSlides
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteUnusedLayoutSlidesCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteUnusedLayoutSlides(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/layoutSlides"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Removes unused layout slides.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return LayoutSlides
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public LayoutSlides deleteUnusedLayoutSlides(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<LayoutSlides> resp = deleteUnusedLayoutSlidesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<LayoutSlides> resp = deleteUnusedLayoutSlidesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Removes unused layout slides.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;LayoutSlides&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<LayoutSlides> deleteUnusedLayoutSlidesWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteUnusedLayoutSlidesCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<LayoutSlides>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Removes unused layout slides. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteUnusedLayoutSlidesAsync(String name, String password, String folder, String storage, final ApiCallback<LayoutSlides> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteUnusedLayoutSlidesCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<LayoutSlides>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteUnusedLayoutSlidesOnline
     * @param document Document data (required)
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteUnusedLayoutSlidesOnlineCall(byte[] document, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling deleteUnusedLayoutSlidesOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/layoutSlides/delete"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Removes unused layout slides.
     * 
     * @param document Document data (required)
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File deleteUnusedLayoutSlidesOnline(byte[] document, String password) throws ApiException {
        try {
            ApiResponse<File> resp = deleteUnusedLayoutSlidesOnlineWithHttpInfo(document, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = deleteUnusedLayoutSlidesOnlineWithHttpInfo(document, password);
            return resp.getData();
        }
    }

    /**
     * Removes unused layout slides.
     * 
     * @param document Document data (required)
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> deleteUnusedLayoutSlidesOnlineWithHttpInfo(byte[] document, String password) throws ApiException {
        com.squareup.okhttp.Call call = deleteUnusedLayoutSlidesOnlineCall(document, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Removes unused layout slides. (asynchronously)
     * 
     * @param document Document data (required)
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteUnusedLayoutSlidesOnlineAsync(byte[] document, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteUnusedLayoutSlidesOnlineCall(document, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for deleteWatermark
     * @param name Document name. (required)
     * @param shapeName Name of the watermark shape. If null, default value \"watermark\"is used. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteWatermarkCall(String name, String shapeName, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling deleteWatermark(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/watermark/delete"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapeName", shapeName);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "DELETE", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Removes shapes with name \&quot;watermark\&quot; from the presentation.
     * 
     * @param name Document name. (required)
     * @param shapeName Name of the watermark shape. If null, default value \"watermark\"is used. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void deleteWatermark(String name, String shapeName, String password, String folder, String storage) throws ApiException {
        try {
            deleteWatermarkWithHttpInfo(name, shapeName, password, folder, storage);
        } catch (NeedRepeatRequestException e) {
            deleteWatermarkWithHttpInfo(name, shapeName, password, folder, storage);
        }
    }

    /**
     * Removes shapes with name \&quot;watermark\&quot; from the presentation.
     * 
     * @param name Document name. (required)
     * @param shapeName Name of the watermark shape. If null, default value \"watermark\"is used. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> deleteWatermarkWithHttpInfo(String name, String shapeName, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = deleteWatermarkCall(name, shapeName, password, folder, storage, null, null);
        return apiClient.execute(call);
    }

    /**
     * Removes shapes with name \&quot;watermark\&quot; from the presentation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param shapeName Name of the watermark shape. If null, default value \"watermark\"is used. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteWatermarkAsync(String name, String shapeName, String password, String folder, String storage, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteWatermarkCall(name, shapeName, password, folder, storage, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for deleteWatermarkOnline
     * @param document Document data. (required)
     * @param shapeName Name of the watermark shape. If null, default value \"watermark\"is used. 
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call deleteWatermarkOnlineCall(byte[] document, String shapeName, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling deleteWatermarkOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/watermark/delete"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapeName", shapeName);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Removes shapes with name \&quot;watermark\&quot; from the presentation.
     * 
     * @param document Document data. (required)
     * @param shapeName Name of the watermark shape. If null, default value \"watermark\"is used. 
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File deleteWatermarkOnline(byte[] document, String shapeName, String password) throws ApiException {
        try {
            ApiResponse<File> resp = deleteWatermarkOnlineWithHttpInfo(document, shapeName, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = deleteWatermarkOnlineWithHttpInfo(document, shapeName, password);
            return resp.getData();
        }
    }

    /**
     * Removes shapes with name \&quot;watermark\&quot; from the presentation.
     * 
     * @param document Document data. (required)
     * @param shapeName Name of the watermark shape. If null, default value \"watermark\"is used. 
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> deleteWatermarkOnlineWithHttpInfo(byte[] document, String shapeName, String password) throws ApiException {
        com.squareup.okhttp.Call call = deleteWatermarkOnlineCall(document, shapeName, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Removes shapes with name \&quot;watermark\&quot; from the presentation. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param shapeName Name of the watermark shape. If null, default value \"watermark\"is used. 
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call deleteWatermarkOnlineAsync(byte[] document, String shapeName, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = deleteWatermarkOnlineCall(document, shapeName, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadFile
     * @param path File path e.g. '/folder/file.ext' 
     * @param storageName Storage name 
     * @param versionId File version ID to download 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadFileCall(String path, String storageName, String versionId, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/file/{path}"
            .replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storageName", storageName);
        apiClient.addQueryParameter(queryParams, "versionId", versionId);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Download file
     * 
     * @param path File path e.g. '/folder/file.ext' 
     * @param storageName Storage name 
     * @param versionId File version ID to download 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadFile(String path, String storageName, String versionId) throws ApiException {
        try {
            ApiResponse<File> resp = downloadFileWithHttpInfo(path, storageName, versionId);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadFileWithHttpInfo(path, storageName, versionId);
            return resp.getData();
        }
    }

    /**
     * Download file
     * 
     * @param path File path e.g. '/folder/file.ext' 
     * @param storageName Storage name 
     * @param versionId File version ID to download 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadFileWithHttpInfo(String path, String storageName, String versionId) throws ApiException {
        com.squareup.okhttp.Call call = downloadFileCall(path, storageName, versionId, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Download file (asynchronously)
     * 
     * @param path File path e.g. '/folder/file.ext' 
     * @param storageName Storage name 
     * @param versionId File version ID to download 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadFileAsync(String path, String storageName, String versionId, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadFileCall(path, storageName, versionId, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadImage
     * @param name Document name. (required)
     * @param index Image index. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadImageCall(String name, Integer index, ImageExportFormat format, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadImage(Async)");
        }
        // verify the required parameter 'index' is set
        if (index == null) {
            throw new ApiException("Missing the required parameter 'index' when calling downloadImage(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadImage(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/images/{index}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "index" + "\\}", apiClient.objectToString(index)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get image in specified format.
     * 
     * @param name Document name. (required)
     * @param index Image index. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadImage(String name, Integer index, ImageExportFormat format, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<File> resp = downloadImageWithHttpInfo(name, index, format, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadImageWithHttpInfo(name, index, format, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Get image in specified format.
     * 
     * @param name Document name. (required)
     * @param index Image index. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadImageWithHttpInfo(String name, Integer index, ImageExportFormat format, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = downloadImageCall(name, index, format, password, folder, storage, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get image in specified format. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param index Image index. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadImageAsync(String name, Integer index, ImageExportFormat format, String password, String folder, String storage, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadImageCall(name, index, format, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadImageDefaultFormat
     * @param name Document name. (required)
     * @param index Image index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadImageDefaultFormatCall(String name, Integer index, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadImageDefaultFormat(Async)");
        }
        // verify the required parameter 'index' is set
        if (index == null) {
            throw new ApiException("Missing the required parameter 'index' when calling downloadImageDefaultFormat(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/images/{index}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "index" + "\\}", apiClient.objectToString(index));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get image binary data.
     * 
     * @param name Document name. (required)
     * @param index Image index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadImageDefaultFormat(String name, Integer index, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<File> resp = downloadImageDefaultFormatWithHttpInfo(name, index, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadImageDefaultFormatWithHttpInfo(name, index, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Get image binary data.
     * 
     * @param name Document name. (required)
     * @param index Image index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadImageDefaultFormatWithHttpInfo(String name, Integer index, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = downloadImageDefaultFormatCall(name, index, password, folder, storage, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get image binary data. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param index Image index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadImageDefaultFormatAsync(String name, Integer index, String password, String folder, String storage, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadImageDefaultFormatCall(name, index, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadImageDefaultFormatOnline
     * @param document Document data. (required)
     * @param index Image index. (required)
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadImageDefaultFormatOnlineCall(byte[] document, Integer index, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling downloadImageDefaultFormatOnline(Async)");
        }
        // verify the required parameter 'index' is set
        if (index == null) {
            throw new ApiException("Missing the required parameter 'index' when calling downloadImageDefaultFormatOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/images/{index}"
            .replaceAll("\\{" + "index" + "\\}", apiClient.objectToString(index));

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get image binary data.
     * 
     * @param document Document data. (required)
     * @param index Image index. (required)
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadImageDefaultFormatOnline(byte[] document, Integer index, String password) throws ApiException {
        try {
            ApiResponse<File> resp = downloadImageDefaultFormatOnlineWithHttpInfo(document, index, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadImageDefaultFormatOnlineWithHttpInfo(document, index, password);
            return resp.getData();
        }
    }

    /**
     * Get image binary data.
     * 
     * @param document Document data. (required)
     * @param index Image index. (required)
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadImageDefaultFormatOnlineWithHttpInfo(byte[] document, Integer index, String password) throws ApiException {
        com.squareup.okhttp.Call call = downloadImageDefaultFormatOnlineCall(document, index, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get image binary data. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param index Image index. (required)
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadImageDefaultFormatOnlineAsync(byte[] document, Integer index, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadImageDefaultFormatOnlineCall(document, index, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadImageOnline
     * @param document Document data. (required)
     * @param index Image index. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadImageOnlineCall(byte[] document, Integer index, ImageExportFormat format, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling downloadImageOnline(Async)");
        }
        // verify the required parameter 'index' is set
        if (index == null) {
            throw new ApiException("Missing the required parameter 'index' when calling downloadImageOnline(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadImageOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/images/{index}/{format}"
            .replaceAll("\\{" + "index" + "\\}", apiClient.objectToString(index)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get image in specified format.
     * 
     * @param document Document data. (required)
     * @param index Image index. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadImageOnline(byte[] document, Integer index, ImageExportFormat format, String password) throws ApiException {
        try {
            ApiResponse<File> resp = downloadImageOnlineWithHttpInfo(document, index, format, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadImageOnlineWithHttpInfo(document, index, format, password);
            return resp.getData();
        }
    }

    /**
     * Get image in specified format.
     * 
     * @param document Document data. (required)
     * @param index Image index. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadImageOnlineWithHttpInfo(byte[] document, Integer index, ImageExportFormat format, String password) throws ApiException {
        com.squareup.okhttp.Call call = downloadImageOnlineCall(document, index, format, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get image in specified format. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param index Image index. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadImageOnlineAsync(byte[] document, Integer index, ImageExportFormat format, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadImageOnlineCall(document, index, format, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadImages
     * @param name  (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadImagesCall(String name, ImageExportFormat format, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadImages(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadImages(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/images/download/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get all presentation images in specified format.
     * 
     * @param name  (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadImages(String name, ImageExportFormat format, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<File> resp = downloadImagesWithHttpInfo(name, format, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadImagesWithHttpInfo(name, format, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Get all presentation images in specified format.
     * 
     * @param name  (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadImagesWithHttpInfo(String name, ImageExportFormat format, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = downloadImagesCall(name, format, password, folder, storage, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get all presentation images in specified format. (asynchronously)
     * 
     * @param name  (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadImagesAsync(String name, ImageExportFormat format, String password, String folder, String storage, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadImagesCall(name, format, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadImagesDefaultFormat
     * @param name  (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadImagesDefaultFormatCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadImagesDefaultFormat(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/images/download"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get all presentation images.
     * 
     * @param name  (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadImagesDefaultFormat(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<File> resp = downloadImagesDefaultFormatWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadImagesDefaultFormatWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Get all presentation images.
     * 
     * @param name  (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadImagesDefaultFormatWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = downloadImagesDefaultFormatCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get all presentation images. (asynchronously)
     * 
     * @param name  (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadImagesDefaultFormatAsync(String name, String password, String folder, String storage, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadImagesDefaultFormatCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadImagesDefaultFormatOnline
     * @param document Document data. (required)
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadImagesDefaultFormatOnlineCall(byte[] document, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling downloadImagesDefaultFormatOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/images/download"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get all presentation images.
     * 
     * @param document Document data. (required)
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadImagesDefaultFormatOnline(byte[] document, String password) throws ApiException {
        try {
            ApiResponse<File> resp = downloadImagesDefaultFormatOnlineWithHttpInfo(document, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadImagesDefaultFormatOnlineWithHttpInfo(document, password);
            return resp.getData();
        }
    }

    /**
     * Get all presentation images.
     * 
     * @param document Document data. (required)
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadImagesDefaultFormatOnlineWithHttpInfo(byte[] document, String password) throws ApiException {
        com.squareup.okhttp.Call call = downloadImagesDefaultFormatOnlineCall(document, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get all presentation images. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadImagesDefaultFormatOnlineAsync(byte[] document, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadImagesDefaultFormatOnlineCall(document, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadImagesOnline
     * @param document Document data. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadImagesOnlineCall(byte[] document, ImageExportFormat format, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling downloadImagesOnline(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadImagesOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/images/download/{format}"
            .replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get all presentation images in specified format. 
     * 
     * @param document Document data. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadImagesOnline(byte[] document, ImageExportFormat format, String password) throws ApiException {
        try {
            ApiResponse<File> resp = downloadImagesOnlineWithHttpInfo(document, format, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadImagesOnlineWithHttpInfo(document, format, password);
            return resp.getData();
        }
    }

    /**
     * Get all presentation images in specified format. 
     * 
     * @param document Document data. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadImagesOnlineWithHttpInfo(byte[] document, ImageExportFormat format, String password) throws ApiException {
        com.squareup.okhttp.Call call = downloadImagesOnlineCall(document, format, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get all presentation images in specified format.  (asynchronously)
     * 
     * @param document Document data. (required)
     * @param format Export format (png, jpg, gif). (required)
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadImagesOnlineAsync(byte[] document, ImageExportFormat format, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadImagesOnlineCall(document, format, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadNotesSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width. 
     * @param height Output file height. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadNotesSlideCall(String name, Integer slideIndex, NotesSlideExportFormat format, Integer width, Integer height, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadNotesSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling downloadNotesSlide(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadNotesSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/notesSlide/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "width", width);
        apiClient.addQueryParameter(queryParams, "height", height);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Convert notes slide to the specified image format.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width. 
     * @param height Output file height. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadNotesSlide(String name, Integer slideIndex, NotesSlideExportFormat format, Integer width, Integer height, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            ApiResponse<File> resp = downloadNotesSlideWithHttpInfo(name, slideIndex, format, width, height, password, folder, storage, fontsFolder);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadNotesSlideWithHttpInfo(name, slideIndex, format, width, height, password, folder, storage, fontsFolder);
            return resp.getData();
        }
    }

    /**
     * Convert notes slide to the specified image format.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width. 
     * @param height Output file height. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadNotesSlideWithHttpInfo(String name, Integer slideIndex, NotesSlideExportFormat format, Integer width, Integer height, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = downloadNotesSlideCall(name, slideIndex, format, width, height, password, folder, storage, fontsFolder, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Convert notes slide to the specified image format. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width. 
     * @param height Output file height. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadNotesSlideAsync(String name, Integer slideIndex, NotesSlideExportFormat format, Integer width, Integer height, String password, String folder, String storage, String fontsFolder, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadNotesSlideCall(name, slideIndex, format, width, height, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadNotesSlideOnline
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width. 
     * @param height Output file height. 
     * @param password Document password. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadNotesSlideOnlineCall(byte[] document, Integer slideIndex, NotesSlideExportFormat format, Integer width, Integer height, String password, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling downloadNotesSlideOnline(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling downloadNotesSlideOnline(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadNotesSlideOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/slides/{slideIndex}/notesSlide/{format}"
            .replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "width", width);
        apiClient.addQueryParameter(queryParams, "height", height);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Convert notes slide to the specified image format.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width. 
     * @param height Output file height. 
     * @param password Document password. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadNotesSlideOnline(byte[] document, Integer slideIndex, NotesSlideExportFormat format, Integer width, Integer height, String password, String fontsFolder) throws ApiException {
        try {
            ApiResponse<File> resp = downloadNotesSlideOnlineWithHttpInfo(document, slideIndex, format, width, height, password, fontsFolder);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadNotesSlideOnlineWithHttpInfo(document, slideIndex, format, width, height, password, fontsFolder);
            return resp.getData();
        }
    }

    /**
     * Convert notes slide to the specified image format.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width. 
     * @param height Output file height. 
     * @param password Document password. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadNotesSlideOnlineWithHttpInfo(byte[] document, Integer slideIndex, NotesSlideExportFormat format, Integer width, Integer height, String password, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = downloadNotesSlideOnlineCall(document, slideIndex, format, width, height, password, fontsFolder, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Convert notes slide to the specified image format. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width. 
     * @param height Output file height. 
     * @param password Document password. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadNotesSlideOnlineAsync(byte[] document, Integer slideIndex, NotesSlideExportFormat format, Integer width, Integer height, String password, String fontsFolder, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadNotesSlideOnlineCall(document, slideIndex, format, width, height, password, fontsFolder, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadPortionAsMathMl
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadPortionAsMathMlCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadPortionAsMathMl(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling downloadPortionAsMathMl(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling downloadPortionAsMathMl(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling downloadPortionAsMathMl(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling downloadPortionAsMathMl(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}/mathml"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Convert Mathematical Text to MathML Format
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadPortionAsMathMl(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<File> resp = downloadPortionAsMathMlWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadPortionAsMathMlWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Convert Mathematical Text to MathML Format
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadPortionAsMathMlWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = downloadPortionAsMathMlCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Convert Mathematical Text to MathML Format (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadPortionAsMathMlAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadPortionAsMathMlCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadPresentation
     * @param name Document name. (required)
     * @param format Export format. (required)
     * @param options Export options. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be saved. If not specified, all slides are saved by default. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadPresentationCall(String name, ExportFormat format, ExportOptions options, String password, String folder, String storage, String fontsFolder, List<Integer> slides, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadPresentation(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadPresentation(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);
        apiClient.addQueryParameter(queryParams, "slides", slides);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Save a presentation to a specified format.
     * 
     * @param name Document name. (required)
     * @param format Export format. (required)
     * @param options Export options. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be saved. If not specified, all slides are saved by default. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadPresentation(String name, ExportFormat format, ExportOptions options, String password, String folder, String storage, String fontsFolder, List<Integer> slides) throws ApiException {
        try {
            ApiResponse<File> resp = downloadPresentationWithHttpInfo(name, format, options, password, folder, storage, fontsFolder, slides);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadPresentationWithHttpInfo(name, format, options, password, folder, storage, fontsFolder, slides);
            return resp.getData();
        }
    }

    /**
     * Save a presentation to a specified format.
     * 
     * @param name Document name. (required)
     * @param format Export format. (required)
     * @param options Export options. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be saved. If not specified, all slides are saved by default. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadPresentationWithHttpInfo(String name, ExportFormat format, ExportOptions options, String password, String folder, String storage, String fontsFolder, List<Integer> slides) throws ApiException {
        com.squareup.okhttp.Call call = downloadPresentationCall(name, format, options, password, folder, storage, fontsFolder, slides, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Save a presentation to a specified format. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param format Export format. (required)
     * @param options Export options. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be saved. If not specified, all slides are saved by default. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadPresentationAsync(String name, ExportFormat format, ExportOptions options, String password, String folder, String storage, String fontsFolder, List<Integer> slides, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadPresentationCall(name, format, options, password, folder, storage, fontsFolder, slides, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadShape
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadShapeCall(String name, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling downloadShape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling downloadShape(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadShape(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "scaleX", scaleX);
        apiClient.addQueryParameter(queryParams, "scaleY", scaleY);
        apiClient.addQueryParameter(queryParams, "bounds", bounds);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadShape(String name, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            ApiResponse<File> resp = downloadShapeWithHttpInfo(name, slideIndex, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadShapeWithHttpInfo(name, slideIndex, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
            return resp.getData();
        }
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadShapeWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = downloadShapeCall(name, slideIndex, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Render shape to specified picture format. (asynchronously)
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadShapeAsync(String name, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadShapeCall(name, slideIndex, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadShapeOnline
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Fonts folder. 
     * @param options Export options. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadShapeOnlineCall(byte[] document, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String storage, String fontsFolder, IShapeExportOptions options, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling downloadShapeOnline(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling downloadShapeOnline(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling downloadShapeOnline(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadShapeOnline(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/slides/{slideIndex}/shapes/{shapeIndex}/{format}"
            .replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "scaleX", scaleX);
        apiClient.addQueryParameter(queryParams, "scaleY", scaleY);
        apiClient.addQueryParameter(queryParams, "bounds", bounds);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Fonts folder. 
     * @param options Export options. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadShapeOnline(byte[] document, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String storage, String fontsFolder, IShapeExportOptions options) throws ApiException {
        try {
            ApiResponse<File> resp = downloadShapeOnlineWithHttpInfo(document, slideIndex, shapeIndex, format, scaleX, scaleY, bounds, password, storage, fontsFolder, options);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadShapeOnlineWithHttpInfo(document, slideIndex, shapeIndex, format, scaleX, scaleY, bounds, password, storage, fontsFolder, options);
            return resp.getData();
        }
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Fonts folder. 
     * @param options Export options. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadShapeOnlineWithHttpInfo(byte[] document, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String storage, String fontsFolder, IShapeExportOptions options) throws ApiException {
        com.squareup.okhttp.Call call = downloadShapeOnlineCall(document, slideIndex, shapeIndex, format, scaleX, scaleY, bounds, password, storage, fontsFolder, options, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Render shape to specified picture format. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Fonts folder. 
     * @param options Export options. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadShapeOnlineAsync(byte[] document, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String storage, String fontsFolder, IShapeExportOptions options, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadShapeOnlineCall(document, slideIndex, shapeIndex, format, scaleX, scaleY, bounds, password, storage, fontsFolder, options, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param options Export options. 
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadSlideCall(String name, Integer slideIndex, SlideExportFormat format, ExportOptions options, Integer width, Integer height, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling downloadSlide(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadSlide(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "width", width);
        apiClient.addQueryParameter(queryParams, "height", height);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Save a slide to a specified format.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param options Export options. 
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadSlide(String name, Integer slideIndex, SlideExportFormat format, ExportOptions options, Integer width, Integer height, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            ApiResponse<File> resp = downloadSlideWithHttpInfo(name, slideIndex, format, options, width, height, password, folder, storage, fontsFolder);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadSlideWithHttpInfo(name, slideIndex, format, options, width, height, password, folder, storage, fontsFolder);
            return resp.getData();
        }
    }

    /**
     * Save a slide to a specified format.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param options Export options. 
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadSlideWithHttpInfo(String name, Integer slideIndex, SlideExportFormat format, ExportOptions options, Integer width, Integer height, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = downloadSlideCall(name, slideIndex, format, options, width, height, password, folder, storage, fontsFolder, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Save a slide to a specified format. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param options Export options. 
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadSlideAsync(String name, Integer slideIndex, SlideExportFormat format, ExportOptions options, Integer width, Integer height, String password, String folder, String storage, String fontsFolder, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadSlideCall(name, slideIndex, format, options, width, height, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadSlideOnline
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param options Export options. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadSlideOnlineCall(byte[] document, Integer slideIndex, SlideExportFormat format, Integer width, Integer height, String password, String storage, String fontsFolder, ExportOptions options, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling downloadSlideOnline(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling downloadSlideOnline(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadSlideOnline(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/slides/{slideIndex}/{format}"
            .replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "width", width);
        apiClient.addQueryParameter(queryParams, "height", height);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Save a slide to a specified format.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param options Export options. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadSlideOnline(byte[] document, Integer slideIndex, SlideExportFormat format, Integer width, Integer height, String password, String storage, String fontsFolder, ExportOptions options) throws ApiException {
        try {
            ApiResponse<File> resp = downloadSlideOnlineWithHttpInfo(document, slideIndex, format, width, height, password, storage, fontsFolder, options);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadSlideOnlineWithHttpInfo(document, slideIndex, format, width, height, password, storage, fontsFolder, options);
            return resp.getData();
        }
    }

    /**
     * Save a slide to a specified format.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param options Export options. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadSlideOnlineWithHttpInfo(byte[] document, Integer slideIndex, SlideExportFormat format, Integer width, Integer height, String password, String storage, String fontsFolder, ExportOptions options) throws ApiException {
        com.squareup.okhttp.Call call = downloadSlideOnlineCall(document, slideIndex, format, width, height, password, storage, fontsFolder, options, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Save a slide to a specified format. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param options Export options. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadSlideOnlineAsync(byte[] document, Integer slideIndex, SlideExportFormat format, Integer width, Integer height, String password, String storage, String fontsFolder, ExportOptions options, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadSlideOnlineCall(document, slideIndex, format, width, height, password, storage, fontsFolder, options, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadSpecialSlideShape
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options Export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadSpecialSlideShapeCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling downloadSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling downloadSpecialSlideShape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling downloadSpecialSlideShape(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadSpecialSlideShape(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "scaleX", scaleX);
        apiClient.addQueryParameter(queryParams, "scaleY", scaleY);
        apiClient.addQueryParameter(queryParams, "bounds", bounds);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options Export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadSpecialSlideShape(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            ApiResponse<File> resp = downloadSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
            return resp.getData();
        }
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options Export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadSpecialSlideShapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = downloadSpecialSlideShapeCall(name, slideIndex, slideType, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Render shape to specified picture format. (asynchronously)
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options Export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadSpecialSlideShapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadSpecialSlideShapeCall(name, slideIndex, slideType, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadSpecialSlideSubshape
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadSpecialSlideSubshapeCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling downloadSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling downloadSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling downloadSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadSpecialSlideSubshape(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "scaleX", scaleX);
        apiClient.addQueryParameter(queryParams, "scaleY", scaleY);
        apiClient.addQueryParameter(queryParams, "bounds", bounds);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Render shape to specified picture format (for smart art and group shapes).
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadSpecialSlideSubshape(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            ApiResponse<File> resp = downloadSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
            return resp.getData();
        }
    }

    /**
     * Render shape to specified picture format (for smart art and group shapes).
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadSpecialSlideSubshapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = downloadSpecialSlideSubshapeCall(name, slideIndex, slideType, path, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Render shape to specified picture format (for smart art and group shapes). (asynchronously)
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadSpecialSlideSubshapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadSpecialSlideSubshapeCall(name, slideIndex, slideType, path, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for downloadSubshape
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call downloadSubshapeCall(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling downloadSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling downloadSubshape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling downloadSubshape(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling downloadSubshape(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "scaleX", scaleX);
        apiClient.addQueryParameter(queryParams, "scaleY", scaleY);
        apiClient.addQueryParameter(queryParams, "bounds", bounds);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Render shape to specified picture format (for smart art and group shapes).
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File downloadSubshape(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            ApiResponse<File> resp = downloadSubshapeWithHttpInfo(name, slideIndex, path, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = downloadSubshapeWithHttpInfo(name, slideIndex, path, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
            return resp.getData();
        }
    }

    /**
     * Render shape to specified picture format (for smart art and group shapes).
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> downloadSubshapeWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = downloadSubshapeCall(name, slideIndex, path, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Render shape to specified picture format (for smart art and group shapes). (asynchronously)
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call downloadSubshapeAsync(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeExportFormat format, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = downloadSubshapeCall(name, slideIndex, path, shapeIndex, format, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getAnimation
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. If specified, only effects related to that shape are returned. 
     * @param paragraphIndex Paragraph index. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getAnimationCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getAnimation(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getAnimation(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapeIndex", shapeIndex);
        apiClient.addQueryParameter(queryParams, "paragraphIndex", paragraphIndex);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide animation effects.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. If specified, only effects related to that shape are returned. 
     * @param paragraphIndex Paragraph index. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation getAnimation(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = getAnimationWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = getAnimationWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide animation effects.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. If specified, only effects related to that shape are returned. 
     * @param paragraphIndex Paragraph index. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> getAnimationWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getAnimationCall(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide animation effects. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. If specified, only effects related to that shape are returned. 
     * @param paragraphIndex Paragraph index. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getAnimationAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getAnimationCall(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getApiInfo
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getApiInfoCall(final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/info"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get API info.
     * 
     * @return ApiInfo
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiInfo getApiInfo() throws ApiException {
        try {
            ApiResponse<ApiInfo> resp = getApiInfoWithHttpInfo();
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ApiInfo> resp = getApiInfoWithHttpInfo();
            return resp.getData();
        }
    }

    /**
     * Get API info.
     * 
     * @return ApiResponse&lt;ApiInfo&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ApiInfo> getApiInfoWithHttpInfo() throws ApiException {
        com.squareup.okhttp.Call call = getApiInfoCall(null, null);
        Type returnType = new TypeToken<ApiInfo>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get API info. (asynchronously)
     * 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getApiInfoAsync(final ApiCallback<ApiInfo> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getApiInfoCall(progressListener, progressRequestListener);
        Type returnType = new TypeToken<ApiInfo>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getBackground
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getBackgroundCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getBackground(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getBackground(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/background"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide background info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideBackground
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideBackground getBackground(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideBackground> resp = getBackgroundWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideBackground> resp = getBackgroundWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide background info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideBackground&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideBackground> getBackgroundWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getBackgroundCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideBackground>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide background info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getBackgroundAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<SlideBackground> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getBackgroundCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideBackground>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getColorScheme
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getColorSchemeCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getColorScheme(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getColorScheme(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/theme/colorScheme"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide theme color scheme info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ColorScheme
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ColorScheme getColorScheme(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ColorScheme> resp = getColorSchemeWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ColorScheme> resp = getColorSchemeWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide theme color scheme info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ColorScheme&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ColorScheme> getColorSchemeWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getColorSchemeCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<ColorScheme>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide theme color scheme info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getColorSchemeAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<ColorScheme> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getColorSchemeCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ColorScheme>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getDiscUsage
     * @param storageName Storage name 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getDiscUsageCall(String storageName, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/disc"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storageName", storageName);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get disc usage
     * 
     * @param storageName Storage name 
     * @return DiscUsage
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public DiscUsage getDiscUsage(String storageName) throws ApiException {
        try {
            ApiResponse<DiscUsage> resp = getDiscUsageWithHttpInfo(storageName);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<DiscUsage> resp = getDiscUsageWithHttpInfo(storageName);
            return resp.getData();
        }
    }

    /**
     * Get disc usage
     * 
     * @param storageName Storage name 
     * @return ApiResponse&lt;DiscUsage&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<DiscUsage> getDiscUsageWithHttpInfo(String storageName) throws ApiException {
        com.squareup.okhttp.Call call = getDiscUsageCall(storageName, null, null);
        Type returnType = new TypeToken<DiscUsage>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get disc usage (asynchronously)
     * 
     * @param storageName Storage name 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getDiscUsageAsync(String storageName, final ApiCallback<DiscUsage> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getDiscUsageCall(storageName, progressListener, progressRequestListener);
        Type returnType = new TypeToken<DiscUsage>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getDocumentProperties
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getDocumentPropertiesCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getDocumentProperties(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/documentproperties"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation document properties.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return DocumentProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public DocumentProperties getDocumentProperties(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<DocumentProperties> resp = getDocumentPropertiesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<DocumentProperties> resp = getDocumentPropertiesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation document properties.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;DocumentProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<DocumentProperties> getDocumentPropertiesWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getDocumentPropertiesCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<DocumentProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation document properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getDocumentPropertiesAsync(String name, String password, String folder, String storage, final ApiCallback<DocumentProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getDocumentPropertiesCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<DocumentProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getDocumentProperty
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getDocumentPropertyCall(String name, String propertyName, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getDocumentProperty(Async)");
        }
        // verify the required parameter 'propertyName' is set
        if (propertyName == null) {
            throw new ApiException("Missing the required parameter 'propertyName' when calling getDocumentProperty(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/documentproperties/{propertyName}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "propertyName" + "\\}", apiClient.objectToString(propertyName));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation document property.
     * 
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return DocumentProperty
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public DocumentProperty getDocumentProperty(String name, String propertyName, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<DocumentProperty> resp = getDocumentPropertyWithHttpInfo(name, propertyName, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<DocumentProperty> resp = getDocumentPropertyWithHttpInfo(name, propertyName, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation document property.
     * 
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;DocumentProperty&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<DocumentProperty> getDocumentPropertyWithHttpInfo(String name, String propertyName, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getDocumentPropertyCall(name, propertyName, password, folder, storage, null, null);
        Type returnType = new TypeToken<DocumentProperty>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation document property. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getDocumentPropertyAsync(String name, String propertyName, String password, String folder, String storage, final ApiCallback<DocumentProperty> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getDocumentPropertyCall(name, propertyName, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<DocumentProperty>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getFileVersions
     * @param path File path e.g. '/file.ext' 
     * @param storageName Storage name 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getFileVersionsCall(String path, String storageName, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/version/{path}"
            .replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storageName", storageName);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get file versions
     * 
     * @param path File path e.g. '/file.ext' 
     * @param storageName Storage name 
     * @return FileVersions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public FileVersions getFileVersions(String path, String storageName) throws ApiException {
        try {
            ApiResponse<FileVersions> resp = getFileVersionsWithHttpInfo(path, storageName);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<FileVersions> resp = getFileVersionsWithHttpInfo(path, storageName);
            return resp.getData();
        }
    }

    /**
     * Get file versions
     * 
     * @param path File path e.g. '/file.ext' 
     * @param storageName Storage name 
     * @return ApiResponse&lt;FileVersions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<FileVersions> getFileVersionsWithHttpInfo(String path, String storageName) throws ApiException {
        com.squareup.okhttp.Call call = getFileVersionsCall(path, storageName, null, null);
        Type returnType = new TypeToken<FileVersions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get file versions (asynchronously)
     * 
     * @param path File path e.g. '/file.ext' 
     * @param storageName Storage name 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getFileVersionsAsync(String path, String storageName, final ApiCallback<FileVersions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getFileVersionsCall(path, storageName, progressListener, progressRequestListener);
        Type returnType = new TypeToken<FileVersions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getFilesList
     * @param path Folder path e.g. '/folder' 
     * @param storageName Storage name 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getFilesListCall(String path, String storageName, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/folder/{path}"
            .replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storageName", storageName);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get all files and folders within a folder
     * 
     * @param path Folder path e.g. '/folder' 
     * @param storageName Storage name 
     * @return FilesList
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public FilesList getFilesList(String path, String storageName) throws ApiException {
        try {
            ApiResponse<FilesList> resp = getFilesListWithHttpInfo(path, storageName);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<FilesList> resp = getFilesListWithHttpInfo(path, storageName);
            return resp.getData();
        }
    }

    /**
     * Get all files and folders within a folder
     * 
     * @param path Folder path e.g. '/folder' 
     * @param storageName Storage name 
     * @return ApiResponse&lt;FilesList&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<FilesList> getFilesListWithHttpInfo(String path, String storageName) throws ApiException {
        com.squareup.okhttp.Call call = getFilesListCall(path, storageName, null, null);
        Type returnType = new TypeToken<FilesList>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get all files and folders within a folder (asynchronously)
     * 
     * @param path Folder path e.g. '/folder' 
     * @param storageName Storage name 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getFilesListAsync(String path, String storageName, final ApiCallback<FilesList> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getFilesListCall(path, storageName, progressListener, progressRequestListener);
        Type returnType = new TypeToken<FilesList>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getFontScheme
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getFontSchemeCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getFontScheme(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getFontScheme(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/theme/fontScheme"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide theme font scheme info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return FontScheme
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public FontScheme getFontScheme(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<FontScheme> resp = getFontSchemeWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<FontScheme> resp = getFontSchemeWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide theme font scheme info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;FontScheme&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<FontScheme> getFontSchemeWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getFontSchemeCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<FontScheme>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide theme font scheme info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getFontSchemeAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<FontScheme> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getFontSchemeCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<FontScheme>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getFormatScheme
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getFormatSchemeCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getFormatScheme(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getFormatScheme(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/theme/formatScheme"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide theme format scheme info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return FormatScheme
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public FormatScheme getFormatScheme(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<FormatScheme> resp = getFormatSchemeWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<FormatScheme> resp = getFormatSchemeWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide theme format scheme info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;FormatScheme&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<FormatScheme> getFormatSchemeWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getFormatSchemeCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<FormatScheme>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide theme format scheme info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getFormatSchemeAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<FormatScheme> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getFormatSchemeCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<FormatScheme>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getLayoutSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getLayoutSlideCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getLayoutSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getLayoutSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/layoutSlides/{slideIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation layoutSlide info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return LayoutSlide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public LayoutSlide getLayoutSlide(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<LayoutSlide> resp = getLayoutSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<LayoutSlide> resp = getLayoutSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation layoutSlide info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;LayoutSlide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<LayoutSlide> getLayoutSlideWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getLayoutSlideCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<LayoutSlide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation layoutSlide info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getLayoutSlideAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<LayoutSlide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getLayoutSlideCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<LayoutSlide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getLayoutSlides
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getLayoutSlidesCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getLayoutSlides(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/layoutSlides"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation layoutSlides info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return LayoutSlides
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public LayoutSlides getLayoutSlides(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<LayoutSlides> resp = getLayoutSlidesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<LayoutSlides> resp = getLayoutSlidesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation layoutSlides info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;LayoutSlides&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<LayoutSlides> getLayoutSlidesWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getLayoutSlidesCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<LayoutSlides>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation layoutSlides info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getLayoutSlidesAsync(String name, String password, String folder, String storage, final ApiCallback<LayoutSlides> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getLayoutSlidesCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<LayoutSlides>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getMasterSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getMasterSlideCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getMasterSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getMasterSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/masterSlides/{slideIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation masterSlide info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return MasterSlide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public MasterSlide getMasterSlide(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<MasterSlide> resp = getMasterSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<MasterSlide> resp = getMasterSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation masterSlide info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;MasterSlide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<MasterSlide> getMasterSlideWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getMasterSlideCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<MasterSlide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation masterSlide info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getMasterSlideAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<MasterSlide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getMasterSlideCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<MasterSlide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getMasterSlides
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getMasterSlidesCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getMasterSlides(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/masterSlides"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation masterSlides info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return MasterSlides
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public MasterSlides getMasterSlides(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<MasterSlides> resp = getMasterSlidesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<MasterSlides> resp = getMasterSlidesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation masterSlides info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;MasterSlides&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<MasterSlides> getMasterSlidesWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getMasterSlidesCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<MasterSlides>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation masterSlides info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getMasterSlidesAsync(String name, String password, String folder, String storage, final ApiCallback<MasterSlides> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getMasterSlidesCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<MasterSlides>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getNotesSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getNotesSlideCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getNotesSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getNotesSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/notesSlide"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read notes slide info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return NotesSlide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public NotesSlide getNotesSlide(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<NotesSlide> resp = getNotesSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<NotesSlide> resp = getNotesSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read notes slide info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;NotesSlide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<NotesSlide> getNotesSlideWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getNotesSlideCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<NotesSlide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read notes slide info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getNotesSlideAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<NotesSlide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getNotesSlideCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<NotesSlide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getNotesSlideHeaderFooter
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getNotesSlideHeaderFooterCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getNotesSlideHeaderFooter(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getNotesSlideHeaderFooter(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/notesSlide/headerFooter"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get header/footer info for the notes slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return NotesSlideHeaderFooter
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public NotesSlideHeaderFooter getNotesSlideHeaderFooter(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<NotesSlideHeaderFooter> resp = getNotesSlideHeaderFooterWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<NotesSlideHeaderFooter> resp = getNotesSlideHeaderFooterWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Get header/footer info for the notes slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;NotesSlideHeaderFooter&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<NotesSlideHeaderFooter> getNotesSlideHeaderFooterWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getNotesSlideHeaderFooterCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<NotesSlideHeaderFooter>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get header/footer info for the notes slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getNotesSlideHeaderFooterAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<NotesSlideHeaderFooter> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getNotesSlideHeaderFooterCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<NotesSlideHeaderFooter>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getNotesSlideOnline
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getNotesSlideOnlineCall(byte[] document, Integer slideIndex, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling getNotesSlideOnline(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getNotesSlideOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/slides/{slideIndex}/notesSlide"
            .replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read notes slide info.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @return NotesSlide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public NotesSlide getNotesSlideOnline(byte[] document, Integer slideIndex, String password) throws ApiException {
        try {
            ApiResponse<NotesSlide> resp = getNotesSlideOnlineWithHttpInfo(document, slideIndex, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<NotesSlide> resp = getNotesSlideOnlineWithHttpInfo(document, slideIndex, password);
            return resp.getData();
        }
    }

    /**
     * Read notes slide info.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @return ApiResponse&lt;NotesSlide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<NotesSlide> getNotesSlideOnlineWithHttpInfo(byte[] document, Integer slideIndex, String password) throws ApiException {
        com.squareup.okhttp.Call call = getNotesSlideOnlineCall(document, slideIndex, password, null, null);
        Type returnType = new TypeToken<NotesSlide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read notes slide info. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getNotesSlideOnlineAsync(byte[] document, Integer slideIndex, String password, final ApiCallback<NotesSlide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getNotesSlideOnlineCall(document, slideIndex, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<NotesSlide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getParagraph
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getParagraphCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getParagraph(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read shape paragraph info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph getParagraph(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = getParagraphWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = getParagraphWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read shape paragraph info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> getParagraphWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getParagraphCall(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read shape paragraph info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getParagraphAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getParagraphCall(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getParagraphRectangle
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getParagraphRectangleCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getParagraphRectangle(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getParagraphRectangle(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getParagraphRectangle(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getParagraphRectangle(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/bounds"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Return coordinates of rect that bounds paragraph. The rect includes all the lines of text in paragraph, including empty ones.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return TextBounds
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public TextBounds getParagraphRectangle(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<TextBounds> resp = getParagraphRectangleWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<TextBounds> resp = getParagraphRectangleWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Return coordinates of rect that bounds paragraph. The rect includes all the lines of text in paragraph, including empty ones.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;TextBounds&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<TextBounds> getParagraphRectangleWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getParagraphRectangleCall(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<TextBounds>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Return coordinates of rect that bounds paragraph. The rect includes all the lines of text in paragraph, including empty ones. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getParagraphRectangleAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<TextBounds> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getParagraphRectangleCall(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<TextBounds>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getParagraphs
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getParagraphsCall(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getParagraphs(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getParagraphs(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getParagraphs(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read shape paragraphs info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs getParagraphs(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = getParagraphsWithHttpInfo(name, slideIndex, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = getParagraphsWithHttpInfo(name, slideIndex, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read shape paragraphs info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> getParagraphsWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getParagraphsCall(name, slideIndex, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read shape paragraphs info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getParagraphsAsync(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getParagraphsCall(name, slideIndex, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getPlaceholder
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param placeholderIndex Placeholder index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getPlaceholderCall(String name, Integer slideIndex, Integer placeholderIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getPlaceholder(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getPlaceholder(Async)");
        }
        // verify the required parameter 'placeholderIndex' is set
        if (placeholderIndex == null) {
            throw new ApiException("Missing the required parameter 'placeholderIndex' when calling getPlaceholder(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/placeholders/{placeholderIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "placeholderIndex" + "\\}", apiClient.objectToString(placeholderIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide placeholder info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param placeholderIndex Placeholder index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Placeholder
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Placeholder getPlaceholder(String name, Integer slideIndex, Integer placeholderIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Placeholder> resp = getPlaceholderWithHttpInfo(name, slideIndex, placeholderIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Placeholder> resp = getPlaceholderWithHttpInfo(name, slideIndex, placeholderIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide placeholder info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param placeholderIndex Placeholder index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Placeholder&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Placeholder> getPlaceholderWithHttpInfo(String name, Integer slideIndex, Integer placeholderIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getPlaceholderCall(name, slideIndex, placeholderIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Placeholder>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide placeholder info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param placeholderIndex Placeholder index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getPlaceholderAsync(String name, Integer slideIndex, Integer placeholderIndex, String password, String folder, String storage, final ApiCallback<Placeholder> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getPlaceholderCall(name, slideIndex, placeholderIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Placeholder>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getPlaceholders
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getPlaceholdersCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getPlaceholders(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getPlaceholders(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/placeholders"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide placeholders info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Placeholders
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Placeholders getPlaceholders(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Placeholders> resp = getPlaceholdersWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Placeholders> resp = getPlaceholdersWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide placeholders info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Placeholders&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Placeholders> getPlaceholdersWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getPlaceholdersCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Placeholders>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide placeholders info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getPlaceholdersAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<Placeholders> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getPlaceholdersCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Placeholders>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getPortion
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getPortionCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getPortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getPortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getPortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getPortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling getPortion(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read paragraph portion info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion getPortion(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = getPortionWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = getPortionWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read paragraph portion info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> getPortionWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getPortionCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read paragraph portion info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getPortionAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getPortionCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getPortionRectangle
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getPortionRectangleCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getPortionRectangle(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getPortionRectangle(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getPortionRectangle(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getPortionRectangle(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling getPortionRectangle(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}/bounds"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Return coordinates of rect that bounds paragraph. The rect includes all the lines of text in paragraph, including empty ones.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return TextBounds
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public TextBounds getPortionRectangle(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<TextBounds> resp = getPortionRectangleWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<TextBounds> resp = getPortionRectangleWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Return coordinates of rect that bounds paragraph. The rect includes all the lines of text in paragraph, including empty ones.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;TextBounds&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<TextBounds> getPortionRectangleWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getPortionRectangleCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<TextBounds>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Return coordinates of rect that bounds paragraph. The rect includes all the lines of text in paragraph, including empty ones. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getPortionRectangleAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ApiCallback<TextBounds> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getPortionRectangleCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<TextBounds>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getPortions
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getPortionsCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getPortions(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getPortions(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getPortions(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getPortions(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read paragraph portions info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions getPortions(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = getPortionsWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = getPortionsWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read paragraph portions info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> getPortionsWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getPortionsCall(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read paragraph portions info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getPortionsAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getPortionsCall(name, slideIndex, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getPresentation
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getPresentationCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getPresentation(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Document
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Document getPresentation(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Document> resp = getPresentationWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Document> resp = getPresentationWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Document&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Document> getPresentationWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getPresentationCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<Document>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getPresentationAsync(String name, String password, String folder, String storage, final ApiCallback<Document> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getPresentationCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Document>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getPresentationImages
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getPresentationImagesCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getPresentationImages(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/images"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation images info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Images
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Images getPresentationImages(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Images> resp = getPresentationImagesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Images> resp = getPresentationImagesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation images info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Images&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Images> getPresentationImagesWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getPresentationImagesCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<Images>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation images info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getPresentationImagesAsync(String name, String password, String folder, String storage, final ApiCallback<Images> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getPresentationImagesCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Images>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getPresentationTextItems
     * @param name Document name. (required)
     * @param withEmpty True to incude empty items. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getPresentationTextItemsCall(String name, Boolean withEmpty, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getPresentationTextItems(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/textItems"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "withEmpty", withEmpty);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Extract presentation text items.
     * 
     * @param name Document name. (required)
     * @param withEmpty True to incude empty items. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return TextItems
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public TextItems getPresentationTextItems(String name, Boolean withEmpty, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<TextItems> resp = getPresentationTextItemsWithHttpInfo(name, withEmpty, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<TextItems> resp = getPresentationTextItemsWithHttpInfo(name, withEmpty, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Extract presentation text items.
     * 
     * @param name Document name. (required)
     * @param withEmpty True to incude empty items. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;TextItems&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<TextItems> getPresentationTextItemsWithHttpInfo(String name, Boolean withEmpty, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getPresentationTextItemsCall(name, withEmpty, password, folder, storage, null, null);
        Type returnType = new TypeToken<TextItems>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Extract presentation text items. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param withEmpty True to incude empty items. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getPresentationTextItemsAsync(String name, Boolean withEmpty, String password, String folder, String storage, final ApiCallback<TextItems> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getPresentationTextItemsCall(name, withEmpty, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<TextItems>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getProtectionProperties
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getProtectionPropertiesCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getProtectionProperties(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/protection"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation protection properties.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ProtectionProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ProtectionProperties getProtectionProperties(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ProtectionProperties> resp = getProtectionPropertiesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ProtectionProperties> resp = getProtectionPropertiesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation protection properties.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ProtectionProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ProtectionProperties> getProtectionPropertiesWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getProtectionPropertiesCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<ProtectionProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation protection properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getProtectionPropertiesAsync(String name, String password, String folder, String storage, final ApiCallback<ProtectionProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getProtectionPropertiesCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ProtectionProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSections
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSectionsCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSections(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/sections"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation sections info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Sections
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Sections getSections(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Sections> resp = getSectionsWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Sections> resp = getSectionsWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation sections info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Sections&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Sections> getSectionsWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSectionsCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<Sections>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation sections info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSectionsAsync(String name, String password, String folder, String storage, final ApiCallback<Sections> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSectionsCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Sections>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getShape
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getShapeCall(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getShape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getShape(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide shape info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase getShape(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = getShapeWithHttpInfo(name, slideIndex, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = getShapeWithHttpInfo(name, slideIndex, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide shape info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> getShapeWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getShapeCall(name, slideIndex, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide shape info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getShapeAsync(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getShapeCall(name, slideIndex, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getShapeGeometryPath
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getShapeGeometryPathCall(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getShapeGeometryPath(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getShapeGeometryPath(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getShapeGeometryPath(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/geometryPath"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Returns geometry path of the shape
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return GeometryPaths
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public GeometryPaths getShapeGeometryPath(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<GeometryPaths> resp = getShapeGeometryPathWithHttpInfo(name, slideIndex, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<GeometryPaths> resp = getShapeGeometryPathWithHttpInfo(name, slideIndex, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Returns geometry path of the shape
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;GeometryPaths&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<GeometryPaths> getShapeGeometryPathWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getShapeGeometryPathCall(name, slideIndex, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<GeometryPaths>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Returns geometry path of the shape (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getShapeGeometryPathAsync(String name, Integer slideIndex, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<GeometryPaths> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getShapeGeometryPathCall(name, slideIndex, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<GeometryPaths>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getShapes
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param shapeType Shape type. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getShapesCall(String name, Integer slideIndex, String password, String folder, String storage, ShapeType shapeType, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getShapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getShapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "shapeType", shapeType);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide shapes info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param shapeType Shape type. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes getShapes(String name, Integer slideIndex, String password, String folder, String storage, ShapeType shapeType) throws ApiException {
        try {
            ApiResponse<Shapes> resp = getShapesWithHttpInfo(name, slideIndex, password, folder, storage, shapeType);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = getShapesWithHttpInfo(name, slideIndex, password, folder, storage, shapeType);
            return resp.getData();
        }
    }

    /**
     * Read slide shapes info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param shapeType Shape type. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> getShapesWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage, ShapeType shapeType) throws ApiException {
        com.squareup.okhttp.Call call = getShapesCall(name, slideIndex, password, folder, storage, shapeType, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide shapes info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param shapeType Shape type. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getShapesAsync(String name, Integer slideIndex, String password, String folder, String storage, ShapeType shapeType, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getShapesCall(name, slideIndex, password, folder, storage, shapeType, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSlideCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation slide info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Slide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Slide getSlide(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Slide> resp = getSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Slide> resp = getSlideWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation slide info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Slide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Slide> getSlideWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSlideCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Slide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation slide info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSlideAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<Slide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSlideCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Slide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSlideComments
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSlideCommentsCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSlideComments(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSlideComments(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/comments"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation slide comments.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideComments
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideComments getSlideComments(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideComments> resp = getSlideCommentsWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideComments> resp = getSlideCommentsWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation slide comments.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideComments&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideComments> getSlideCommentsWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSlideCommentsCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideComments>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation slide comments. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSlideCommentsAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<SlideComments> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSlideCommentsCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideComments>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSlideHeaderFooter
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSlideHeaderFooterCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSlideHeaderFooter(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSlideHeaderFooter(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/headerFooter"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get footer info for the slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return HeaderFooter
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public HeaderFooter getSlideHeaderFooter(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<HeaderFooter> resp = getSlideHeaderFooterWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<HeaderFooter> resp = getSlideHeaderFooterWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Get footer info for the slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;HeaderFooter&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<HeaderFooter> getSlideHeaderFooterWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSlideHeaderFooterCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<HeaderFooter>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get footer info for the slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSlideHeaderFooterAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<HeaderFooter> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSlideHeaderFooterCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<HeaderFooter>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSlideImages
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSlideImagesCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSlideImages(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSlideImages(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/images"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide images info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Images
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Images getSlideImages(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Images> resp = getSlideImagesWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Images> resp = getSlideImagesWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide images info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Images&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Images> getSlideImagesWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSlideImagesCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Images>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide images info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSlideImagesAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<Images> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSlideImagesCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Images>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSlideProperties
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSlidePropertiesCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSlideProperties(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slideProperties"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation slide properties.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideProperties getSlideProperties(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideProperties> resp = getSlidePropertiesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideProperties> resp = getSlidePropertiesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation slide properties.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideProperties> getSlidePropertiesWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSlidePropertiesCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation slide properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSlidePropertiesAsync(String name, String password, String folder, String storage, final ApiCallback<SlideProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSlidePropertiesCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSlideTextItems
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param withEmpty True to include empty items. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSlideTextItemsCall(String name, Integer slideIndex, Boolean withEmpty, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSlideTextItems(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSlideTextItems(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/textItems"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "withEmpty", withEmpty);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Extract slide text items.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param withEmpty True to include empty items. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return TextItems
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public TextItems getSlideTextItems(String name, Integer slideIndex, Boolean withEmpty, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<TextItems> resp = getSlideTextItemsWithHttpInfo(name, slideIndex, withEmpty, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<TextItems> resp = getSlideTextItemsWithHttpInfo(name, slideIndex, withEmpty, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Extract slide text items.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param withEmpty True to include empty items. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;TextItems&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<TextItems> getSlideTextItemsWithHttpInfo(String name, Integer slideIndex, Boolean withEmpty, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSlideTextItemsCall(name, slideIndex, withEmpty, password, folder, storage, null, null);
        Type returnType = new TypeToken<TextItems>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Extract slide text items. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param withEmpty True to include empty items. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSlideTextItemsAsync(String name, Integer slideIndex, Boolean withEmpty, String password, String folder, String storage, final ApiCallback<TextItems> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSlideTextItemsCall(name, slideIndex, withEmpty, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<TextItems>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSlides
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSlidesCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSlides(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation slides info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Slides
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Slides getSlides(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Slides> resp = getSlidesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Slides> resp = getSlidesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation slides info.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Slides&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Slides> getSlidesWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSlidesCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<Slides>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation slides info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSlidesAsync(String name, String password, String folder, String storage, final ApiCallback<Slides> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSlidesCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Slides>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideAnimation
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. If specified, only effects related to that shape are returned. 
     * @param paragraphIndex Paragraph index. If specified, only effects related to that paragraph are returned. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideAnimationCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideAnimation(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideAnimation(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideAnimation(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "shapeIndex", shapeIndex);
        apiClient.addQueryParameter(queryParams, "paragraphIndex", paragraphIndex);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read special slide (master, layout, notes) animation effects.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. If specified, only effects related to that shape are returned. 
     * @param paragraphIndex Paragraph index. If specified, only effects related to that paragraph are returned. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation getSpecialSlideAnimation(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = getSpecialSlideAnimationWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = getSpecialSlideAnimationWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read special slide (master, layout, notes) animation effects.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. If specified, only effects related to that shape are returned. 
     * @param paragraphIndex Paragraph index. If specified, only effects related to that paragraph are returned. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> getSpecialSlideAnimationWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideAnimationCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read special slide (master, layout, notes) animation effects. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. If specified, only effects related to that shape are returned. 
     * @param paragraphIndex Paragraph index. If specified, only effects related to that paragraph are returned. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideAnimationAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideAnimationCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideParagraph
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideParagraphCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getSpecialSlideParagraph(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read shape paragraph info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph getSpecialSlideParagraph(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = getSpecialSlideParagraphWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = getSpecialSlideParagraphWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read shape paragraph info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> getSpecialSlideParagraphWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideParagraphCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read shape paragraph info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideParagraphAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideParagraphCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideParagraphs
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideParagraphsCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideParagraphs(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideParagraphs(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideParagraphs(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSpecialSlideParagraphs(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read special shape paragraphs info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs getSpecialSlideParagraphs(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = getSpecialSlideParagraphsWithHttpInfo(name, slideIndex, slideType, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = getSpecialSlideParagraphsWithHttpInfo(name, slideIndex, slideType, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read special shape paragraphs info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> getSpecialSlideParagraphsWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideParagraphsCall(name, slideIndex, slideType, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read special shape paragraphs info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideParagraphsAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideParagraphsCall(name, slideIndex, slideType, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlidePortion
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlidePortionCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling getSpecialSlidePortion(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read paragraph portion info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion getSpecialSlidePortion(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = getSpecialSlidePortionWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = getSpecialSlidePortionWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read paragraph portion info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> getSpecialSlidePortionWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlidePortionCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read paragraph portion info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlidePortionAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlidePortionCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlidePortions
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlidePortionsCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlidePortions(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlidePortions(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlidePortions(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSpecialSlidePortions(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getSpecialSlidePortions(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read paragraph portions info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions getSpecialSlidePortions(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = getSpecialSlidePortionsWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = getSpecialSlidePortionsWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read paragraph portions info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> getSpecialSlidePortionsWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlidePortionsCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read paragraph portions info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlidePortionsAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlidePortionsCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideShape
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideShapeCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideShape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSpecialSlideShape(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read special slide shape info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase getSpecialSlideShape(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = getSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = getSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read special slide shape info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> getSpecialSlideShapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideShapeCall(name, slideIndex, slideType, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read special slide shape info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideShapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideShapeCall(name, slideIndex, slideType, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideShapes
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideShapesCall(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideShapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideShapes(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideShapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read special slide shapes info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes getSpecialSlideShapes(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = getSpecialSlideShapesWithHttpInfo(name, slideIndex, slideType, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = getSpecialSlideShapesWithHttpInfo(name, slideIndex, slideType, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read special slide shapes info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> getSpecialSlideShapesWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideShapesCall(name, slideIndex, slideType, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read special slide shapes info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideShapesAsync(String name, Integer slideIndex, SpecialSlideType slideType, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideShapesCall(name, slideIndex, slideType, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideSubshape
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapeCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSpecialSlideSubshape(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read special slide shape info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase getSpecialSlideSubshape(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = getSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = getSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read special slide shape info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> getSpecialSlideSubshapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideSubshapeCall(name, slideIndex, slideType, path, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read special slide shape info (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideSubshapeCall(name, slideIndex, slideType, path, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideSubshapeParagraph
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapeParagraphCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getSpecialSlideSubshapeParagraph(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read shape paragraph info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph getSpecialSlideSubshapeParagraph(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = getSpecialSlideSubshapeParagraphWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = getSpecialSlideSubshapeParagraphWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read shape paragraph info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> getSpecialSlideSubshapeParagraphWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideSubshapeParagraphCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read shape paragraph info (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapeParagraphAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideSubshapeParagraphCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideSubshapeParagraphs
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapeParagraphsCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideSubshapeParagraphs(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideSubshapeParagraphs(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideSubshapeParagraphs(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSpecialSlideSubshapeParagraphs(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read shape paragraphs info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs getSpecialSlideSubshapeParagraphs(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = getSpecialSlideSubshapeParagraphsWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = getSpecialSlideSubshapeParagraphsWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read shape paragraphs info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> getSpecialSlideSubshapeParagraphsWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideSubshapeParagraphsCall(name, slideIndex, slideType, path, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read shape paragraphs info (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapeParagraphsAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideSubshapeParagraphsCall(name, slideIndex, slideType, path, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideSubshapePortion
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapePortionCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling getSpecialSlideSubshapePortion(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read paragraph portion info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion getSpecialSlideSubshapePortion(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = getSpecialSlideSubshapePortionWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = getSpecialSlideSubshapePortionWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read paragraph portion info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> getSpecialSlideSubshapePortionWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideSubshapePortionCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read paragraph portion info (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapePortionAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideSubshapePortionCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideSubshapePortions
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapePortionsCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideSubshapePortions(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideSubshapePortions(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideSubshapePortions(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSpecialSlideSubshapePortions(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getSpecialSlideSubshapePortions(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read paragraph portions info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions getSpecialSlideSubshapePortions(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = getSpecialSlideSubshapePortionsWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = getSpecialSlideSubshapePortionsWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read paragraph portions info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> getSpecialSlideSubshapePortionsWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideSubshapePortionsCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read paragraph portions info (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapePortionsAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideSubshapePortionsCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSpecialSlideSubshapes
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapesCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSpecialSlideSubshapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSpecialSlideSubshapes(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling getSpecialSlideSubshapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read special slide shapes info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes getSpecialSlideSubshapes(String name, Integer slideIndex, SpecialSlideType slideType, String path, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = getSpecialSlideSubshapesWithHttpInfo(name, slideIndex, slideType, path, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = getSpecialSlideSubshapesWithHttpInfo(name, slideIndex, slideType, path, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read special slide shapes info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> getSpecialSlideSubshapesWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSpecialSlideSubshapesCall(name, slideIndex, slideType, path, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read special slide shapes info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSpecialSlideSubshapesAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSpecialSlideSubshapesCall(name, slideIndex, slideType, path, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSubshape
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSubshapeCall(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSubshape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSubshape(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide shape info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase getSubshape(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = getSubshapeWithHttpInfo(name, slideIndex, path, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = getSubshapeWithHttpInfo(name, slideIndex, path, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide shape info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> getSubshapeWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSubshapeCall(name, slideIndex, path, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide shape info (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSubshapeAsync(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSubshapeCall(name, slideIndex, path, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSubshapeParagraph
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSubshapeParagraphCall(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSubshapeParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSubshapeParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getSubshapeParagraph(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read shape paragraph info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph getSubshapeParagraph(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = getSubshapeParagraphWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = getSubshapeParagraphWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read shape paragraph info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> getSubshapeParagraphWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSubshapeParagraphCall(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read shape paragraph info (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSubshapeParagraphAsync(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSubshapeParagraphCall(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSubshapeParagraphs
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSubshapeParagraphsCall(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSubshapeParagraphs(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSubshapeParagraphs(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSubshapeParagraphs(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read shape paragraphs info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraphs
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraphs getSubshapeParagraphs(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraphs> resp = getSubshapeParagraphsWithHttpInfo(name, slideIndex, path, shapeIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraphs> resp = getSubshapeParagraphsWithHttpInfo(name, slideIndex, path, shapeIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read shape paragraphs info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraphs&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraphs> getSubshapeParagraphsWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSubshapeParagraphsCall(name, slideIndex, path, shapeIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read shape paragraphs info (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSubshapeParagraphsAsync(String name, Integer slideIndex, String path, Integer shapeIndex, String password, String folder, String storage, final ApiCallback<Paragraphs> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSubshapeParagraphsCall(name, slideIndex, path, shapeIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraphs>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSubshapePortion
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSubshapePortionCall(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSubshapePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSubshapePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSubshapePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getSubshapePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling getSubshapePortion(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read paragraph portion info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion getSubshapePortion(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = getSubshapePortionWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = getSubshapePortionWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read paragraph portion info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> getSubshapePortionWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSubshapePortionCall(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read paragraph portion info (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSubshapePortionAsync(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSubshapePortionCall(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSubshapePortions
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSubshapePortionsCall(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSubshapePortions(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSubshapePortions(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling getSubshapePortions(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling getSubshapePortions(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read paragraph portions info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portions
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portions getSubshapePortions(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portions> resp = getSubshapePortionsWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portions> resp = getSubshapePortionsWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read paragraph portions info (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portions&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portions> getSubshapePortionsWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSubshapePortionsCall(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portions>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read paragraph portions info (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSubshapePortionsAsync(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, String password, String folder, String storage, final ApiCallback<Portions> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSubshapePortionsCall(name, slideIndex, path, shapeIndex, paragraphIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portions>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getSubshapes
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getSubshapesCall(String name, Integer slideIndex, String path, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getSubshapes(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getSubshapes(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide shapes info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shapes
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shapes getSubshapes(String name, Integer slideIndex, String path, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shapes> resp = getSubshapesWithHttpInfo(name, slideIndex, path, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shapes> resp = getSubshapesWithHttpInfo(name, slideIndex, path, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide shapes info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shapes&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shapes> getSubshapesWithHttpInfo(String name, Integer slideIndex, String path, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getSubshapesCall(name, slideIndex, path, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide shapes info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getSubshapesAsync(String name, Integer slideIndex, String path, String password, String folder, String storage, final ApiCallback<Shapes> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getSubshapesCall(name, slideIndex, path, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shapes>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getTheme
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getThemeCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getTheme(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling getTheme(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/theme"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read slide theme info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Theme
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Theme getTheme(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Theme> resp = getThemeWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Theme> resp = getThemeWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read slide theme info.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Theme&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Theme> getThemeWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getThemeCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<Theme>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read slide theme info. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getThemeAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<Theme> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getThemeCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Theme>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for getViewProperties
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call getViewPropertiesCall(String name, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling getViewProperties(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/viewProperties"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Read presentation document properties.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ViewProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ViewProperties getViewProperties(String name, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ViewProperties> resp = getViewPropertiesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ViewProperties> resp = getViewPropertiesWithHttpInfo(name, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Read presentation document properties.
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ViewProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ViewProperties> getViewPropertiesWithHttpInfo(String name, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = getViewPropertiesCall(name, password, folder, storage, null, null);
        Type returnType = new TypeToken<ViewProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Read presentation document properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call getViewPropertiesAsync(String name, String password, String folder, String storage, final ApiCallback<ViewProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = getViewPropertiesCall(name, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ViewProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for highlightShapeRegex
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param regex Regular expression. (required)
     * @param color Highlighting color. (required)
     * @param wholeWordsOnly Match only whole words. 
     * @param ignoreCase True to search ignoring char case. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call highlightShapeRegexCall(String name, Integer slideIndex, Integer shapeIndex, String regex, String color, Boolean wholeWordsOnly, Boolean ignoreCase, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling highlightShapeRegex(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling highlightShapeRegex(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling highlightShapeRegex(Async)");
        }
        // verify the required parameter 'regex' is set
        if (regex == null) {
            throw new ApiException("Missing the required parameter 'regex' when calling highlightShapeRegex(Async)");
        }
        // verify the required parameter 'color' is set
        if (color == null) {
            throw new ApiException("Missing the required parameter 'color' when calling highlightShapeRegex(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/highlightRegex"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "regex", regex);
        apiClient.addQueryParameter(queryParams, "color", color);
        apiClient.addQueryParameter(queryParams, "wholeWordsOnly", wholeWordsOnly);
        apiClient.addQueryParameter(queryParams, "ignoreCase", ignoreCase);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Highlight all matches of sample in text frame text using specified color.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param regex Regular expression. (required)
     * @param color Highlighting color. (required)
     * @param wholeWordsOnly Match only whole words. 
     * @param ignoreCase True to search ignoring char case. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shape
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shape highlightShapeRegex(String name, Integer slideIndex, Integer shapeIndex, String regex, String color, Boolean wholeWordsOnly, Boolean ignoreCase, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shape> resp = highlightShapeRegexWithHttpInfo(name, slideIndex, shapeIndex, regex, color, wholeWordsOnly, ignoreCase, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shape> resp = highlightShapeRegexWithHttpInfo(name, slideIndex, shapeIndex, regex, color, wholeWordsOnly, ignoreCase, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Highlight all matches of sample in text frame text using specified color.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param regex Regular expression. (required)
     * @param color Highlighting color. (required)
     * @param wholeWordsOnly Match only whole words. 
     * @param ignoreCase True to search ignoring char case. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shape&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shape> highlightShapeRegexWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, String regex, String color, Boolean wholeWordsOnly, Boolean ignoreCase, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = highlightShapeRegexCall(name, slideIndex, shapeIndex, regex, color, wholeWordsOnly, ignoreCase, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shape>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Highlight all matches of sample in text frame text using specified color. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param regex Regular expression. (required)
     * @param color Highlighting color. (required)
     * @param wholeWordsOnly Match only whole words. 
     * @param ignoreCase True to search ignoring char case. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call highlightShapeRegexAsync(String name, Integer slideIndex, Integer shapeIndex, String regex, String color, Boolean wholeWordsOnly, Boolean ignoreCase, String password, String folder, String storage, final ApiCallback<Shape> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = highlightShapeRegexCall(name, slideIndex, shapeIndex, regex, color, wholeWordsOnly, ignoreCase, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shape>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for highlightShapeText
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param text Text sample to highlight. (required)
     * @param color Highlighting color. (required)
     * @param wholeWordsOnly Match only whole words. 
     * @param ignoreCase True to search ignoring char case. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call highlightShapeTextCall(String name, Integer slideIndex, Integer shapeIndex, String text, String color, Boolean wholeWordsOnly, Boolean ignoreCase, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling highlightShapeText(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling highlightShapeText(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling highlightShapeText(Async)");
        }
        // verify the required parameter 'text' is set
        if (text == null) {
            throw new ApiException("Missing the required parameter 'text' when calling highlightShapeText(Async)");
        }
        // verify the required parameter 'color' is set
        if (color == null) {
            throw new ApiException("Missing the required parameter 'color' when calling highlightShapeText(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/highlightText"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "text", text);
        apiClient.addQueryParameter(queryParams, "color", color);
        apiClient.addQueryParameter(queryParams, "wholeWordsOnly", wholeWordsOnly);
        apiClient.addQueryParameter(queryParams, "ignoreCase", ignoreCase);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Highlight all matches of sample in text frame text using specified color.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param text Text sample to highlight. (required)
     * @param color Highlighting color. (required)
     * @param wholeWordsOnly Match only whole words. 
     * @param ignoreCase True to search ignoring char case. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Shape
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Shape highlightShapeText(String name, Integer slideIndex, Integer shapeIndex, String text, String color, Boolean wholeWordsOnly, Boolean ignoreCase, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Shape> resp = highlightShapeTextWithHttpInfo(name, slideIndex, shapeIndex, text, color, wholeWordsOnly, ignoreCase, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Shape> resp = highlightShapeTextWithHttpInfo(name, slideIndex, shapeIndex, text, color, wholeWordsOnly, ignoreCase, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Highlight all matches of sample in text frame text using specified color.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param text Text sample to highlight. (required)
     * @param color Highlighting color. (required)
     * @param wholeWordsOnly Match only whole words. 
     * @param ignoreCase True to search ignoring char case. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Shape&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Shape> highlightShapeTextWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, String text, String color, Boolean wholeWordsOnly, Boolean ignoreCase, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = highlightShapeTextCall(name, slideIndex, shapeIndex, text, color, wholeWordsOnly, ignoreCase, password, folder, storage, null, null);
        Type returnType = new TypeToken<Shape>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Highlight all matches of sample in text frame text using specified color. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param text Text sample to highlight. (required)
     * @param color Highlighting color. (required)
     * @param wholeWordsOnly Match only whole words. 
     * @param ignoreCase True to search ignoring char case. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call highlightShapeTextAsync(String name, Integer slideIndex, Integer shapeIndex, String text, String color, Boolean wholeWordsOnly, Boolean ignoreCase, String password, String folder, String storage, final ApiCallback<Shape> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = highlightShapeTextCall(name, slideIndex, shapeIndex, text, color, wholeWordsOnly, ignoreCase, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Shape>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for importFromHtml
     * @param name Document name. (required)
     * @param html HTML data. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call importFromHtmlCall(String name, String html, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling importFromHtml(Async)");
        }
        Object postBody = html;

        // create path and map variables
        String methodPath = "/slides/{name}/fromHtml"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create presentation document from html.
     * 
     * @param name Document name. (required)
     * @param html HTML data. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Document
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Document importFromHtml(String name, String html, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Document> resp = importFromHtmlWithHttpInfo(name, html, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Document> resp = importFromHtmlWithHttpInfo(name, html, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create presentation document from html.
     * 
     * @param name Document name. (required)
     * @param html HTML data. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Document&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Document> importFromHtmlWithHttpInfo(String name, String html, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = importFromHtmlCall(name, html, password, folder, storage, null, null);
        Type returnType = new TypeToken<Document>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create presentation document from html. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param html HTML data. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call importFromHtmlAsync(String name, String html, String password, String folder, String storage, final ApiCallback<Document> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = importFromHtmlCall(name, html, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Document>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for importFromPdf
     * @param name Document name. (required)
     * @param pdf PDF data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call importFromPdfCall(String name, byte[] pdf, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling importFromPdf(Async)");
        }
        // verify the required parameter 'pdf' is set
        if (pdf == null) {
            throw new ApiException("Missing the required parameter 'pdf' when calling importFromPdf(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/fromPdf"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (pdf != null)
        formParams.put("pdf", pdf);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Create presentation document from pdf or append pdf to an existing presentation.
     * 
     * @param name Document name. (required)
     * @param pdf PDF data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Document
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Document importFromPdf(String name, byte[] pdf, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Document> resp = importFromPdfWithHttpInfo(name, pdf, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Document> resp = importFromPdfWithHttpInfo(name, pdf, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Create presentation document from pdf or append pdf to an existing presentation.
     * 
     * @param name Document name. (required)
     * @param pdf PDF data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Document&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Document> importFromPdfWithHttpInfo(String name, byte[] pdf, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = importFromPdfCall(name, pdf, password, folder, storage, null, null);
        Type returnType = new TypeToken<Document>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Create presentation document from pdf or append pdf to an existing presentation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param pdf PDF data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call importFromPdfAsync(String name, byte[] pdf, String password, String folder, String storage, final ApiCallback<Document> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = importFromPdfCall(name, pdf, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Document>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for merge
     * @param name Document name. (required)
     * @param request PresentationsMergeRequest with a list of presentations to merge. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call mergeCall(String name, PresentationsMergeRequest request, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling merge(Async)");
        }
        // verify the required parameter 'request' is set
        if (request == null) {
            throw new ApiException("Missing the required parameter 'request' when calling merge(Async)");
        }
        Object postBody = request;

        // create path and map variables
        String methodPath = "/slides/{name}/merge"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Merge the presentation with other presentations specified in the request parameter.
     * 
     * @param name Document name. (required)
     * @param request PresentationsMergeRequest with a list of presentations to merge. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Document
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Document merge(String name, PresentationsMergeRequest request, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Document> resp = mergeWithHttpInfo(name, request, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Document> resp = mergeWithHttpInfo(name, request, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Merge the presentation with other presentations specified in the request parameter.
     * 
     * @param name Document name. (required)
     * @param request PresentationsMergeRequest with a list of presentations to merge. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Document&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Document> mergeWithHttpInfo(String name, PresentationsMergeRequest request, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = mergeCall(name, request, password, folder, storage, null, null);
        Type returnType = new TypeToken<Document>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Merge the presentation with other presentations specified in the request parameter. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param request PresentationsMergeRequest with a list of presentations to merge. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call mergeAsync(String name, PresentationsMergeRequest request, String password, String folder, String storage, final ApiCallback<Document> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = mergeCall(name, request, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Document>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for mergeAndSaveOnline
     * @param outPath Path to save result. (required)
     * @param files Files to merge 
     * @param request Merge request. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call mergeAndSaveOnlineCall(String outPath, List<FileInfo> files, OrderedMergeRequest request, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling mergeAndSaveOnline(Async)");
        }
        Object postBody = request;

        // create path and map variables
        String methodPath = "/slides/merge"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (files != null)
        formParams.put("files", files);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Merges presentations or some of their slides specified in the request parameter. Result will be save in the storage.
     * 
     * @param outPath Path to save result. (required)
     * @param files Files to merge 
     * @param request Merge request. 
     * @param storage Document storage. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void mergeAndSaveOnline(String outPath, List<FileInfo> files, OrderedMergeRequest request, String storage) throws ApiException {
        try {
            mergeAndSaveOnlineWithHttpInfo(outPath, files, request, storage);
        } catch (NeedRepeatRequestException e) {
            mergeAndSaveOnlineWithHttpInfo(outPath, files, request, storage);
        }
    }

    /**
     * Merges presentations or some of their slides specified in the request parameter. Result will be save in the storage.
     * 
     * @param outPath Path to save result. (required)
     * @param files Files to merge 
     * @param request Merge request. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> mergeAndSaveOnlineWithHttpInfo(String outPath, List<FileInfo> files, OrderedMergeRequest request, String storage) throws ApiException {
        com.squareup.okhttp.Call call = mergeAndSaveOnlineCall(outPath, files, request, storage, null, null);
        return apiClient.execute(call);
    }

    /**
     * Merges presentations or some of their slides specified in the request parameter. Result will be save in the storage. (asynchronously)
     * 
     * @param outPath Path to save result. (required)
     * @param files Files to merge 
     * @param request Merge request. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call mergeAndSaveOnlineAsync(String outPath, List<FileInfo> files, OrderedMergeRequest request, String storage, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = mergeAndSaveOnlineCall(outPath, files, request, storage, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for mergeOnline
     * @param files Files to merge 
     * @param request Merge request. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call mergeOnlineCall(List<FileInfo> files, OrderedMergeRequest request, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        Object postBody = request;

        // create path and map variables
        String methodPath = "/slides/merge"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (files != null)
        formParams.put("files", files);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Merges presentations or some of their slides specified in the request parameter. Returns result file in the response. 
     * 
     * @param files Files to merge 
     * @param request Merge request. 
     * @param storage Document storage. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File mergeOnline(List<FileInfo> files, OrderedMergeRequest request, String storage) throws ApiException {
        try {
            ApiResponse<File> resp = mergeOnlineWithHttpInfo(files, request, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = mergeOnlineWithHttpInfo(files, request, storage);
            return resp.getData();
        }
    }

    /**
     * Merges presentations or some of their slides specified in the request parameter. Returns result file in the response. 
     * 
     * @param files Files to merge 
     * @param request Merge request. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> mergeOnlineWithHttpInfo(List<FileInfo> files, OrderedMergeRequest request, String storage) throws ApiException {
        com.squareup.okhttp.Call call = mergeOnlineCall(files, request, storage, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Merges presentations or some of their slides specified in the request parameter. Returns result file in the response.  (asynchronously)
     * 
     * @param files Files to merge 
     * @param request Merge request. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call mergeOnlineAsync(List<FileInfo> files, OrderedMergeRequest request, String storage, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = mergeOnlineCall(files, request, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for moveFile
     * @param srcPath Source file path e.g. '/src.ext' (required)
     * @param destPath Destination file path e.g. '/dest.ext' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param versionId File version ID to move 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call moveFileCall(String srcPath, String destPath, String srcStorageName, String destStorageName, String versionId, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'srcPath' is set
        if (srcPath == null) {
            throw new ApiException("Missing the required parameter 'srcPath' when calling moveFile(Async)");
        }
        // verify the required parameter 'destPath' is set
        if (destPath == null) {
            throw new ApiException("Missing the required parameter 'destPath' when calling moveFile(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/file/move/{srcPath}"
            .replaceAll("\\{" + "srcPath" + "\\}", apiClient.objectToString(srcPath));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "destPath", destPath);
        apiClient.addQueryParameter(queryParams, "srcStorageName", srcStorageName);
        apiClient.addQueryParameter(queryParams, "destStorageName", destStorageName);
        apiClient.addQueryParameter(queryParams, "versionId", versionId);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Move file
     * 
     * @param srcPath Source file path e.g. '/src.ext' (required)
     * @param destPath Destination file path e.g. '/dest.ext' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param versionId File version ID to move 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void moveFile(String srcPath, String destPath, String srcStorageName, String destStorageName, String versionId) throws ApiException {
        try {
            moveFileWithHttpInfo(srcPath, destPath, srcStorageName, destStorageName, versionId);
        } catch (NeedRepeatRequestException e) {
            moveFileWithHttpInfo(srcPath, destPath, srcStorageName, destStorageName, versionId);
        }
    }

    /**
     * Move file
     * 
     * @param srcPath Source file path e.g. '/src.ext' (required)
     * @param destPath Destination file path e.g. '/dest.ext' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param versionId File version ID to move 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> moveFileWithHttpInfo(String srcPath, String destPath, String srcStorageName, String destStorageName, String versionId) throws ApiException {
        com.squareup.okhttp.Call call = moveFileCall(srcPath, destPath, srcStorageName, destStorageName, versionId, null, null);
        return apiClient.execute(call);
    }

    /**
     * Move file (asynchronously)
     * 
     * @param srcPath Source file path e.g. '/src.ext' (required)
     * @param destPath Destination file path e.g. '/dest.ext' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param versionId File version ID to move 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call moveFileAsync(String srcPath, String destPath, String srcStorageName, String destStorageName, String versionId, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = moveFileCall(srcPath, destPath, srcStorageName, destStorageName, versionId, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for moveFolder
     * @param srcPath Folder path to move e.g. '/folder' (required)
     * @param destPath Destination folder path to move to e.g '/dst' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call moveFolderCall(String srcPath, String destPath, String srcStorageName, String destStorageName, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'srcPath' is set
        if (srcPath == null) {
            throw new ApiException("Missing the required parameter 'srcPath' when calling moveFolder(Async)");
        }
        // verify the required parameter 'destPath' is set
        if (destPath == null) {
            throw new ApiException("Missing the required parameter 'destPath' when calling moveFolder(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/folder/move/{srcPath}"
            .replaceAll("\\{" + "srcPath" + "\\}", apiClient.objectToString(srcPath));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "destPath", destPath);
        apiClient.addQueryParameter(queryParams, "srcStorageName", srcStorageName);
        apiClient.addQueryParameter(queryParams, "destStorageName", destStorageName);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Move folder
     * 
     * @param srcPath Folder path to move e.g. '/folder' (required)
     * @param destPath Destination folder path to move to e.g '/dst' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void moveFolder(String srcPath, String destPath, String srcStorageName, String destStorageName) throws ApiException {
        try {
            moveFolderWithHttpInfo(srcPath, destPath, srcStorageName, destStorageName);
        } catch (NeedRepeatRequestException e) {
            moveFolderWithHttpInfo(srcPath, destPath, srcStorageName, destStorageName);
        }
    }

    /**
     * Move folder
     * 
     * @param srcPath Folder path to move e.g. '/folder' (required)
     * @param destPath Destination folder path to move to e.g '/dst' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> moveFolderWithHttpInfo(String srcPath, String destPath, String srcStorageName, String destStorageName) throws ApiException {
        com.squareup.okhttp.Call call = moveFolderCall(srcPath, destPath, srcStorageName, destStorageName, null, null);
        return apiClient.execute(call);
    }

    /**
     * Move folder (asynchronously)
     * 
     * @param srcPath Folder path to move e.g. '/folder' (required)
     * @param destPath Destination folder path to move to e.g '/dst' (required)
     * @param srcStorageName Source storage name 
     * @param destStorageName Destination storage name 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call moveFolderAsync(String srcPath, String destPath, String srcStorageName, String destStorageName, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = moveFolderCall(srcPath, destPath, srcStorageName, destStorageName, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for moveSection
     * @param name Document name. (required)
     * @param sectionIndex The position of the section to be reordered. (required)
     * @param newPosition The new position of the reordered section. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call moveSectionCall(String name, Integer sectionIndex, Integer newPosition, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling moveSection(Async)");
        }
        // verify the required parameter 'sectionIndex' is set
        if (sectionIndex == null) {
            throw new ApiException("Missing the required parameter 'sectionIndex' when calling moveSection(Async)");
        }
        // verify the required parameter 'newPosition' is set
        if (newPosition == null) {
            throw new ApiException("Missing the required parameter 'newPosition' when calling moveSection(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/sections/{sectionIndex}/move"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "sectionIndex" + "\\}", apiClient.objectToString(sectionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "newPosition", newPosition);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Move presentation section to a specified position.
     * 
     * @param name Document name. (required)
     * @param sectionIndex The position of the section to be reordered. (required)
     * @param newPosition The new position of the reordered section. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Sections
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Sections moveSection(String name, Integer sectionIndex, Integer newPosition, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Sections> resp = moveSectionWithHttpInfo(name, sectionIndex, newPosition, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Sections> resp = moveSectionWithHttpInfo(name, sectionIndex, newPosition, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Move presentation section to a specified position.
     * 
     * @param name Document name. (required)
     * @param sectionIndex The position of the section to be reordered. (required)
     * @param newPosition The new position of the reordered section. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Sections&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Sections> moveSectionWithHttpInfo(String name, Integer sectionIndex, Integer newPosition, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = moveSectionCall(name, sectionIndex, newPosition, password, folder, storage, null, null);
        Type returnType = new TypeToken<Sections>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Move presentation section to a specified position. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param sectionIndex The position of the section to be reordered. (required)
     * @param newPosition The new position of the reordered section. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call moveSectionAsync(String name, Integer sectionIndex, Integer newPosition, String password, String folder, String storage, final ApiCallback<Sections> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = moveSectionCall(name, sectionIndex, newPosition, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Sections>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for moveSlide
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param newPosition The new position of the reordered slide. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call moveSlideCall(String name, Integer slideIndex, Integer newPosition, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling moveSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling moveSlide(Async)");
        }
        // verify the required parameter 'newPosition' is set
        if (newPosition == null) {
            throw new ApiException("Missing the required parameter 'newPosition' when calling moveSlide(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/move"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "newPosition", newPosition);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Reorder presentation slide position.
     * 
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param newPosition The new position of the reordered slide. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Slides
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Slides moveSlide(String name, Integer slideIndex, Integer newPosition, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Slides> resp = moveSlideWithHttpInfo(name, slideIndex, newPosition, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Slides> resp = moveSlideWithHttpInfo(name, slideIndex, newPosition, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Reorder presentation slide position.
     * 
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param newPosition The new position of the reordered slide. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Slides&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Slides> moveSlideWithHttpInfo(String name, Integer slideIndex, Integer newPosition, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = moveSlideCall(name, slideIndex, newPosition, password, folder, storage, null, null);
        Type returnType = new TypeToken<Slides>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Reorder presentation slide position. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param newPosition The new position of the reordered slide. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call moveSlideAsync(String name, Integer slideIndex, Integer newPosition, String password, String folder, String storage, final ApiCallback<Slides> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = moveSlideCall(name, slideIndex, newPosition, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Slides>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for notesSlideExists
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call notesSlideExistsCall(String name, Integer slideIndex, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling notesSlideExists(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling notesSlideExists(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/notesSlide/exist"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get info whether a notes slide exists.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return EntityExists
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public EntityExists notesSlideExists(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<EntityExists> resp = notesSlideExistsWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<EntityExists> resp = notesSlideExistsWithHttpInfo(name, slideIndex, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Get info whether a notes slide exists.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;EntityExists&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<EntityExists> notesSlideExistsWithHttpInfo(String name, Integer slideIndex, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = notesSlideExistsCall(name, slideIndex, password, folder, storage, null, null);
        Type returnType = new TypeToken<EntityExists>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get info whether a notes slide exists. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call notesSlideExistsAsync(String name, Integer slideIndex, String password, String folder, String storage, final ApiCallback<EntityExists> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = notesSlideExistsCall(name, slideIndex, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<EntityExists>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for notesSlideExistsOnline
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call notesSlideExistsOnlineCall(byte[] document, Integer slideIndex, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling notesSlideExistsOnline(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling notesSlideExistsOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/slides/{slideIndex}/notesSlide/exist"
            .replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Get info whether a notes slide exists.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @return EntityExists
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public EntityExists notesSlideExistsOnline(byte[] document, Integer slideIndex, String password) throws ApiException {
        try {
            ApiResponse<EntityExists> resp = notesSlideExistsOnlineWithHttpInfo(document, slideIndex, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<EntityExists> resp = notesSlideExistsOnlineWithHttpInfo(document, slideIndex, password);
            return resp.getData();
        }
    }

    /**
     * Get info whether a notes slide exists.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @return ApiResponse&lt;EntityExists&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<EntityExists> notesSlideExistsOnlineWithHttpInfo(byte[] document, Integer slideIndex, String password) throws ApiException {
        com.squareup.okhttp.Call call = notesSlideExistsOnlineCall(document, slideIndex, password, null, null);
        Type returnType = new TypeToken<EntityExists>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Get info whether a notes slide exists. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call notesSlideExistsOnlineAsync(byte[] document, Integer slideIndex, String password, final ApiCallback<EntityExists> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = notesSlideExistsOnlineCall(document, slideIndex, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<EntityExists>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for objectExists
     * @param path File or folder path e.g. '/file.ext' or '/folder' 
     * @param storageName Storage name 
     * @param versionId File version ID 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call objectExistsCall(String path, String storageName, String versionId, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/exist/{path}"
            .replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storageName", storageName);
        apiClient.addQueryParameter(queryParams, "versionId", versionId);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Check if file or folder exists
     * 
     * @param path File or folder path e.g. '/file.ext' or '/folder' 
     * @param storageName Storage name 
     * @param versionId File version ID 
     * @return ObjectExist
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ObjectExist objectExists(String path, String storageName, String versionId) throws ApiException {
        try {
            ApiResponse<ObjectExist> resp = objectExistsWithHttpInfo(path, storageName, versionId);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ObjectExist> resp = objectExistsWithHttpInfo(path, storageName, versionId);
            return resp.getData();
        }
    }

    /**
     * Check if file or folder exists
     * 
     * @param path File or folder path e.g. '/file.ext' or '/folder' 
     * @param storageName Storage name 
     * @param versionId File version ID 
     * @return ApiResponse&lt;ObjectExist&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ObjectExist> objectExistsWithHttpInfo(String path, String storageName, String versionId) throws ApiException {
        com.squareup.okhttp.Call call = objectExistsCall(path, storageName, versionId, null, null);
        Type returnType = new TypeToken<ObjectExist>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Check if file or folder exists (asynchronously)
     * 
     * @param path File or folder path e.g. '/file.ext' or '/folder' 
     * @param storageName Storage name 
     * @param versionId File version ID 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call objectExistsAsync(String path, String storageName, String versionId, final ApiCallback<ObjectExist> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = objectExistsCall(path, storageName, versionId, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ObjectExist>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for orderedMerge
     * @param name Document name. (required)
     * @param request OrderedMergeRequest with a list of presentations and slide indices to merge. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call orderedMergeCall(String name, OrderedMergeRequest request, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling orderedMerge(Async)");
        }
        // verify the required parameter 'request' is set
        if (request == null) {
            throw new ApiException("Missing the required parameter 'request' when calling orderedMerge(Async)");
        }
        Object postBody = request;

        // create path and map variables
        String methodPath = "/slides/{name}/merge"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Merge the presentation with other presentations or some of their slides specified in the request parameter.
     * 
     * @param name Document name. (required)
     * @param request OrderedMergeRequest with a list of presentations and slide indices to merge. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Document
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Document orderedMerge(String name, OrderedMergeRequest request, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Document> resp = orderedMergeWithHttpInfo(name, request, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Document> resp = orderedMergeWithHttpInfo(name, request, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Merge the presentation with other presentations or some of their slides specified in the request parameter.
     * 
     * @param name Document name. (required)
     * @param request OrderedMergeRequest with a list of presentations and slide indices to merge. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Document&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Document> orderedMergeWithHttpInfo(String name, OrderedMergeRequest request, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = orderedMergeCall(name, request, password, folder, storage, null, null);
        Type returnType = new TypeToken<Document>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Merge the presentation with other presentations or some of their slides specified in the request parameter. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param request OrderedMergeRequest with a list of presentations and slide indices to merge. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call orderedMergeAsync(String name, OrderedMergeRequest request, String password, String folder, String storage, final ApiCallback<Document> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = orderedMergeCall(name, request, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Document>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for pipeline
     * @param pipeline A Pipeline object. (required)
     * @param files Files to upload with the pipeline 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call pipelineCall(Pipeline pipeline, List<FileInfo> files, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'pipeline' is set
        if (pipeline == null) {
            throw new ApiException("Missing the required parameter 'pipeline' when calling pipeline(Async)");
        }
        Object postBody = pipeline;

        // create path and map variables
        String methodPath = "/slides/pipeline"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (files != null)
        formParams.put("files", files);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Performs slides pipeline.
     * 
     * @param pipeline A Pipeline object. (required)
     * @param files Files to upload with the pipeline 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File pipeline(Pipeline pipeline, List<FileInfo> files) throws ApiException {
        try {
            ApiResponse<File> resp = pipelineWithHttpInfo(pipeline, files);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = pipelineWithHttpInfo(pipeline, files);
            return resp.getData();
        }
    }

    /**
     * Performs slides pipeline.
     * 
     * @param pipeline A Pipeline object. (required)
     * @param files Files to upload with the pipeline 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> pipelineWithHttpInfo(Pipeline pipeline, List<FileInfo> files) throws ApiException {
        com.squareup.okhttp.Call call = pipelineCall(pipeline, files, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Performs slides pipeline. (asynchronously)
     * 
     * @param pipeline A Pipeline object. (required)
     * @param files Files to upload with the pipeline 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call pipelineAsync(Pipeline pipeline, List<FileInfo> files, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = pipelineCall(pipeline, files, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for reorderSlides
     * @param name Document name. (required)
     * @param oldPositions A comma separated array of positions of slides to be reordered. 
     * @param newPositions A comma separated array of new slide positions. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call reorderSlidesCall(String name, List<Integer> oldPositions, List<Integer> newPositions, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling reorderSlides(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/reorder"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "oldPositions", oldPositions);
        apiClient.addQueryParameter(queryParams, "newPositions", newPositions);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Reorder presentation slides positions.
     * 
     * @param name Document name. (required)
     * @param oldPositions A comma separated array of positions of slides to be reordered. 
     * @param newPositions A comma separated array of new slide positions. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Slides
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Slides reorderSlides(String name, List<Integer> oldPositions, List<Integer> newPositions, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Slides> resp = reorderSlidesWithHttpInfo(name, oldPositions, newPositions, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Slides> resp = reorderSlidesWithHttpInfo(name, oldPositions, newPositions, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Reorder presentation slides positions.
     * 
     * @param name Document name. (required)
     * @param oldPositions A comma separated array of positions of slides to be reordered. 
     * @param newPositions A comma separated array of new slide positions. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Slides&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Slides> reorderSlidesWithHttpInfo(String name, List<Integer> oldPositions, List<Integer> newPositions, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = reorderSlidesCall(name, oldPositions, newPositions, password, folder, storage, null, null);
        Type returnType = new TypeToken<Slides>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Reorder presentation slides positions. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param oldPositions A comma separated array of positions of slides to be reordered. 
     * @param newPositions A comma separated array of new slide positions. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call reorderSlidesAsync(String name, List<Integer> oldPositions, List<Integer> newPositions, String password, String folder, String storage, final ApiCallback<Slides> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = reorderSlidesCall(name, oldPositions, newPositions, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Slides>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for replacePresentationText
     * @param name Document name. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call replacePresentationTextCall(String name, String oldValue, String newValue, Boolean ignoreCase, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling replacePresentationText(Async)");
        }
        // verify the required parameter 'oldValue' is set
        if (oldValue == null) {
            throw new ApiException("Missing the required parameter 'oldValue' when calling replacePresentationText(Async)");
        }
        // verify the required parameter 'newValue' is set
        if (newValue == null) {
            throw new ApiException("Missing the required parameter 'newValue' when calling replacePresentationText(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/replaceText"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "oldValue", oldValue);
        apiClient.addQueryParameter(queryParams, "newValue", newValue);
        apiClient.addQueryParameter(queryParams, "ignoreCase", ignoreCase);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Replace text with a new value.
     * 
     * @param name Document name. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return DocumentReplaceResult
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public DocumentReplaceResult replacePresentationText(String name, String oldValue, String newValue, Boolean ignoreCase, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<DocumentReplaceResult> resp = replacePresentationTextWithHttpInfo(name, oldValue, newValue, ignoreCase, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<DocumentReplaceResult> resp = replacePresentationTextWithHttpInfo(name, oldValue, newValue, ignoreCase, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Replace text with a new value.
     * 
     * @param name Document name. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;DocumentReplaceResult&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<DocumentReplaceResult> replacePresentationTextWithHttpInfo(String name, String oldValue, String newValue, Boolean ignoreCase, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = replacePresentationTextCall(name, oldValue, newValue, ignoreCase, password, folder, storage, null, null);
        Type returnType = new TypeToken<DocumentReplaceResult>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Replace text with a new value. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call replacePresentationTextAsync(String name, String oldValue, String newValue, Boolean ignoreCase, String password, String folder, String storage, final ApiCallback<DocumentReplaceResult> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = replacePresentationTextCall(name, oldValue, newValue, ignoreCase, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<DocumentReplaceResult>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for replacePresentationTextOnline
     * @param document Document data. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call replacePresentationTextOnlineCall(byte[] document, String oldValue, String newValue, Boolean ignoreCase, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling replacePresentationTextOnline(Async)");
        }
        // verify the required parameter 'oldValue' is set
        if (oldValue == null) {
            throw new ApiException("Missing the required parameter 'oldValue' when calling replacePresentationTextOnline(Async)");
        }
        // verify the required parameter 'newValue' is set
        if (newValue == null) {
            throw new ApiException("Missing the required parameter 'newValue' when calling replacePresentationTextOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/replaceText"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "oldValue", oldValue);
        apiClient.addQueryParameter(queryParams, "newValue", newValue);
        apiClient.addQueryParameter(queryParams, "ignoreCase", ignoreCase);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Replace text with a new value.
     * 
     * @param document Document data. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File replacePresentationTextOnline(byte[] document, String oldValue, String newValue, Boolean ignoreCase, String password) throws ApiException {
        try {
            ApiResponse<File> resp = replacePresentationTextOnlineWithHttpInfo(document, oldValue, newValue, ignoreCase, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = replacePresentationTextOnlineWithHttpInfo(document, oldValue, newValue, ignoreCase, password);
            return resp.getData();
        }
    }

    /**
     * Replace text with a new value.
     * 
     * @param document Document data. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> replacePresentationTextOnlineWithHttpInfo(byte[] document, String oldValue, String newValue, Boolean ignoreCase, String password) throws ApiException {
        com.squareup.okhttp.Call call = replacePresentationTextOnlineCall(document, oldValue, newValue, ignoreCase, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Replace text with a new value. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call replacePresentationTextOnlineAsync(byte[] document, String oldValue, String newValue, Boolean ignoreCase, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = replacePresentationTextOnlineCall(document, oldValue, newValue, ignoreCase, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for replaceSlideText
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call replaceSlideTextCall(String name, Integer slideIndex, String oldValue, String newValue, Boolean ignoreCase, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling replaceSlideText(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling replaceSlideText(Async)");
        }
        // verify the required parameter 'oldValue' is set
        if (oldValue == null) {
            throw new ApiException("Missing the required parameter 'oldValue' when calling replaceSlideText(Async)");
        }
        // verify the required parameter 'newValue' is set
        if (newValue == null) {
            throw new ApiException("Missing the required parameter 'newValue' when calling replaceSlideText(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/replaceText"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "oldValue", oldValue);
        apiClient.addQueryParameter(queryParams, "newValue", newValue);
        apiClient.addQueryParameter(queryParams, "ignoreCase", ignoreCase);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Replace text with a new value.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideReplaceResult
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideReplaceResult replaceSlideText(String name, Integer slideIndex, String oldValue, String newValue, Boolean ignoreCase, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideReplaceResult> resp = replaceSlideTextWithHttpInfo(name, slideIndex, oldValue, newValue, ignoreCase, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideReplaceResult> resp = replaceSlideTextWithHttpInfo(name, slideIndex, oldValue, newValue, ignoreCase, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Replace text with a new value.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideReplaceResult&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideReplaceResult> replaceSlideTextWithHttpInfo(String name, Integer slideIndex, String oldValue, String newValue, Boolean ignoreCase, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = replaceSlideTextCall(name, slideIndex, oldValue, newValue, ignoreCase, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideReplaceResult>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Replace text with a new value. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call replaceSlideTextAsync(String name, Integer slideIndex, String oldValue, String newValue, Boolean ignoreCase, String password, String folder, String storage, final ApiCallback<SlideReplaceResult> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = replaceSlideTextCall(name, slideIndex, oldValue, newValue, ignoreCase, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideReplaceResult>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for replaceSlideTextOnline
     * @param document Document data. (required)
     * @param slideIndex Index of target slide. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call replaceSlideTextOnlineCall(byte[] document, Integer slideIndex, String oldValue, String newValue, Boolean ignoreCase, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling replaceSlideTextOnline(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling replaceSlideTextOnline(Async)");
        }
        // verify the required parameter 'oldValue' is set
        if (oldValue == null) {
            throw new ApiException("Missing the required parameter 'oldValue' when calling replaceSlideTextOnline(Async)");
        }
        // verify the required parameter 'newValue' is set
        if (newValue == null) {
            throw new ApiException("Missing the required parameter 'newValue' when calling replaceSlideTextOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/slides/{slideIndex}/replaceText"
            .replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "oldValue", oldValue);
        apiClient.addQueryParameter(queryParams, "newValue", newValue);
        apiClient.addQueryParameter(queryParams, "ignoreCase", ignoreCase);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Replace slide text with a new value.
     * 
     * @param document Document data. (required)
     * @param slideIndex Index of target slide. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File replaceSlideTextOnline(byte[] document, Integer slideIndex, String oldValue, String newValue, Boolean ignoreCase, String password) throws ApiException {
        try {
            ApiResponse<File> resp = replaceSlideTextOnlineWithHttpInfo(document, slideIndex, oldValue, newValue, ignoreCase, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = replaceSlideTextOnlineWithHttpInfo(document, slideIndex, oldValue, newValue, ignoreCase, password);
            return resp.getData();
        }
    }

    /**
     * Replace slide text with a new value.
     * 
     * @param document Document data. (required)
     * @param slideIndex Index of target slide. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> replaceSlideTextOnlineWithHttpInfo(byte[] document, Integer slideIndex, String oldValue, String newValue, Boolean ignoreCase, String password) throws ApiException {
        com.squareup.okhttp.Call call = replaceSlideTextOnlineCall(document, slideIndex, oldValue, newValue, ignoreCase, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Replace slide text with a new value. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param slideIndex Index of target slide. (required)
     * @param oldValue Text value to be replaced. (required)
     * @param newValue Text value to replace with. (required)
     * @param ignoreCase True if character case must be ignored. 
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call replaceSlideTextOnlineAsync(byte[] document, Integer slideIndex, String oldValue, String newValue, Boolean ignoreCase, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = replaceSlideTextOnlineCall(document, slideIndex, oldValue, newValue, ignoreCase, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for savePortionAsMathMl
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param outPath Path to save result. (required)
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call savePortionAsMathMlCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String outPath, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling savePortionAsMathMl(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling savePortionAsMathMl(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling savePortionAsMathMl(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling savePortionAsMathMl(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling savePortionAsMathMl(Async)");
        }
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling savePortionAsMathMl(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}/mathml"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Convert Mathematical Text to MathML Format and saves result to the storage
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param outPath Path to save result. (required)
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void savePortionAsMathMl(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String outPath, String password, String folder, String storage) throws ApiException {
        try {
            savePortionAsMathMlWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, outPath, password, folder, storage);
        } catch (NeedRepeatRequestException e) {
            savePortionAsMathMlWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, outPath, password, folder, storage);
        }
    }

    /**
     * Convert Mathematical Text to MathML Format and saves result to the storage
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param outPath Path to save result. (required)
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> savePortionAsMathMlWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String outPath, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = savePortionAsMathMlCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, outPath, password, folder, storage, null, null);
        return apiClient.execute(call);
    }

    /**
     * Convert Mathematical Text to MathML Format and saves result to the storage (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param outPath Path to save result. (required)
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call savePortionAsMathMlAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, String outPath, String password, String folder, String storage, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = savePortionAsMathMlCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, outPath, password, folder, storage, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for savePresentation
     * @param name Document name. (required)
     * @param format Export format. (required)
     * @param outPath Output path. (required)
     * @param options Export options. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be saved. If not specified, all slides are saved by default. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call savePresentationCall(String name, ExportFormat format, String outPath, ExportOptions options, String password, String folder, String storage, String fontsFolder, List<Integer> slides, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling savePresentation(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling savePresentation(Async)");
        }
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling savePresentation(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);
        apiClient.addQueryParameter(queryParams, "slides", slides);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Save a presentation to a specified format.
     * 
     * @param name Document name. (required)
     * @param format Export format. (required)
     * @param outPath Output path. (required)
     * @param options Export options. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be saved. If not specified, all slides are saved by default. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void savePresentation(String name, ExportFormat format, String outPath, ExportOptions options, String password, String folder, String storage, String fontsFolder, List<Integer> slides) throws ApiException {
        try {
            savePresentationWithHttpInfo(name, format, outPath, options, password, folder, storage, fontsFolder, slides);
        } catch (NeedRepeatRequestException e) {
            savePresentationWithHttpInfo(name, format, outPath, options, password, folder, storage, fontsFolder, slides);
        }
    }

    /**
     * Save a presentation to a specified format.
     * 
     * @param name Document name. (required)
     * @param format Export format. (required)
     * @param outPath Output path. (required)
     * @param options Export options. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be saved. If not specified, all slides are saved by default. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> savePresentationWithHttpInfo(String name, ExportFormat format, String outPath, ExportOptions options, String password, String folder, String storage, String fontsFolder, List<Integer> slides) throws ApiException {
        com.squareup.okhttp.Call call = savePresentationCall(name, format, outPath, options, password, folder, storage, fontsFolder, slides, null, null);
        return apiClient.execute(call);
    }

    /**
     * Save a presentation to a specified format. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param format Export format. (required)
     * @param outPath Output path. (required)
     * @param options Export options. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param slides The indices of the slides to be saved. If not specified, all slides are saved by default. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call savePresentationAsync(String name, ExportFormat format, String outPath, ExportOptions options, String password, String folder, String storage, String fontsFolder, List<Integer> slides, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = savePresentationCall(name, format, outPath, options, password, folder, storage, fontsFolder, slides, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for saveShape
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call saveShapeCall(String name, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling saveShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling saveShape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling saveShape(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling saveShape(Async)");
        }
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling saveShape(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "scaleX", scaleX);
        apiClient.addQueryParameter(queryParams, "scaleY", scaleY);
        apiClient.addQueryParameter(queryParams, "bounds", bounds);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void saveShape(String name, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            saveShapeWithHttpInfo(name, slideIndex, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
        } catch (NeedRepeatRequestException e) {
            saveShapeWithHttpInfo(name, slideIndex, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
        }
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> saveShapeWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = saveShapeCall(name, slideIndex, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, null, null);
        return apiClient.execute(call);
    }

    /**
     * Render shape to specified picture format. (asynchronously)
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call saveShapeAsync(String name, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = saveShapeCall(name, slideIndex, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for saveShapeOnline
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Path to save result. (required)
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Fonts folder. 
     * @param options Export options. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call saveShapeOnlineCall(byte[] document, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, String outPath, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String storage, String fontsFolder, IShapeExportOptions options, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling saveShapeOnline(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling saveShapeOnline(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling saveShapeOnline(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling saveShapeOnline(Async)");
        }
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling saveShapeOnline(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/slides/{slideIndex}/shapes/{shapeIndex}/{format}"
            .replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "scaleX", scaleX);
        apiClient.addQueryParameter(queryParams, "scaleY", scaleY);
        apiClient.addQueryParameter(queryParams, "bounds", bounds);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Path to save result. (required)
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Fonts folder. 
     * @param options Export options. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void saveShapeOnline(byte[] document, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, String outPath, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String storage, String fontsFolder, IShapeExportOptions options) throws ApiException {
        try {
            saveShapeOnlineWithHttpInfo(document, slideIndex, shapeIndex, format, outPath, scaleX, scaleY, bounds, password, storage, fontsFolder, options);
        } catch (NeedRepeatRequestException e) {
            saveShapeOnlineWithHttpInfo(document, slideIndex, shapeIndex, format, outPath, scaleX, scaleY, bounds, password, storage, fontsFolder, options);
        }
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Path to save result. (required)
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Fonts folder. 
     * @param options Export options. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> saveShapeOnlineWithHttpInfo(byte[] document, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, String outPath, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String storage, String fontsFolder, IShapeExportOptions options) throws ApiException {
        com.squareup.okhttp.Call call = saveShapeOnlineCall(document, slideIndex, shapeIndex, format, outPath, scaleX, scaleY, bounds, password, storage, fontsFolder, options, null, null);
        return apiClient.execute(call);
    }

    /**
     * Render shape to specified picture format. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Path to save result. (required)
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Fonts folder. 
     * @param options Export options. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call saveShapeOnlineAsync(byte[] document, Integer slideIndex, Integer shapeIndex, ShapeExportFormat format, String outPath, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String storage, String fontsFolder, IShapeExportOptions options, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = saveShapeOnlineCall(document, slideIndex, shapeIndex, format, outPath, scaleX, scaleY, bounds, password, storage, fontsFolder, options, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for saveSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param outPath Path to upload the output file to. (required)
     * @param options Export options. 
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call saveSlideCall(String name, Integer slideIndex, SlideExportFormat format, String outPath, ExportOptions options, Integer width, Integer height, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling saveSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling saveSlide(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling saveSlide(Async)");
        }
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling saveSlide(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "width", width);
        apiClient.addQueryParameter(queryParams, "height", height);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Save a slide to a specified format.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param outPath Path to upload the output file to. (required)
     * @param options Export options. 
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void saveSlide(String name, Integer slideIndex, SlideExportFormat format, String outPath, ExportOptions options, Integer width, Integer height, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            saveSlideWithHttpInfo(name, slideIndex, format, outPath, options, width, height, password, folder, storage, fontsFolder);
        } catch (NeedRepeatRequestException e) {
            saveSlideWithHttpInfo(name, slideIndex, format, outPath, options, width, height, password, folder, storage, fontsFolder);
        }
    }

    /**
     * Save a slide to a specified format.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param outPath Path to upload the output file to. (required)
     * @param options Export options. 
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> saveSlideWithHttpInfo(String name, Integer slideIndex, SlideExportFormat format, String outPath, ExportOptions options, Integer width, Integer height, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = saveSlideCall(name, slideIndex, format, outPath, options, width, height, password, folder, storage, fontsFolder, null, null);
        return apiClient.execute(call);
    }

    /**
     * Save a slide to a specified format. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param outPath Path to upload the output file to. (required)
     * @param options Export options. 
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call saveSlideAsync(String name, Integer slideIndex, SlideExportFormat format, String outPath, ExportOptions options, Integer width, Integer height, String password, String folder, String storage, String fontsFolder, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = saveSlideCall(name, slideIndex, format, outPath, options, width, height, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for saveSlideOnline
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param outPath Path to save result. (required)
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param options Export options. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call saveSlideOnlineCall(byte[] document, Integer slideIndex, SlideExportFormat format, String outPath, Integer width, Integer height, String password, String storage, String fontsFolder, ExportOptions options, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling saveSlideOnline(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling saveSlideOnline(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling saveSlideOnline(Async)");
        }
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling saveSlideOnline(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/slides/{slideIndex}/{format}"
            .replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "width", width);
        apiClient.addQueryParameter(queryParams, "height", height);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Save a slide to a specified format.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param outPath Path to save result. (required)
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param options Export options. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void saveSlideOnline(byte[] document, Integer slideIndex, SlideExportFormat format, String outPath, Integer width, Integer height, String password, String storage, String fontsFolder, ExportOptions options) throws ApiException {
        try {
            saveSlideOnlineWithHttpInfo(document, slideIndex, format, outPath, width, height, password, storage, fontsFolder, options);
        } catch (NeedRepeatRequestException e) {
            saveSlideOnlineWithHttpInfo(document, slideIndex, format, outPath, width, height, password, storage, fontsFolder, options);
        }
    }

    /**
     * Save a slide to a specified format.
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param outPath Path to save result. (required)
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param options Export options. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> saveSlideOnlineWithHttpInfo(byte[] document, Integer slideIndex, SlideExportFormat format, String outPath, Integer width, Integer height, String password, String storage, String fontsFolder, ExportOptions options) throws ApiException {
        com.squareup.okhttp.Call call = saveSlideOnlineCall(document, slideIndex, format, outPath, width, height, password, storage, fontsFolder, options, null, null);
        return apiClient.execute(call);
    }

    /**
     * Save a slide to a specified format. (asynchronously)
     * 
     * @param document Document data. (required)
     * @param slideIndex Slide index. (required)
     * @param format Output file format. (required)
     * @param outPath Path to save result. (required)
     * @param width Output file width; 0 to not adjust the size. Default is 0. 
     * @param height Output file height; 0 to not adjust the size. Default is 0. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Storage folder containing custom fonts to be used with the document. 
     * @param options Export options. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call saveSlideOnlineAsync(byte[] document, Integer slideIndex, SlideExportFormat format, String outPath, Integer width, Integer height, String password, String storage, String fontsFolder, ExportOptions options, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = saveSlideOnlineCall(document, slideIndex, format, outPath, width, height, password, storage, fontsFolder, options, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for saveSpecialSlideShape
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call saveSpecialSlideShapeCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling saveSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling saveSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling saveSpecialSlideShape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling saveSpecialSlideShape(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling saveSpecialSlideShape(Async)");
        }
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling saveSpecialSlideShape(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "scaleX", scaleX);
        apiClient.addQueryParameter(queryParams, "scaleY", scaleY);
        apiClient.addQueryParameter(queryParams, "bounds", bounds);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void saveSpecialSlideShape(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            saveSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
        } catch (NeedRepeatRequestException e) {
            saveSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
        }
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> saveSpecialSlideShapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = saveSpecialSlideShapeCall(name, slideIndex, slideType, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, null, null);
        return apiClient.execute(call);
    }

    /**
     * Render shape to specified picture format. (asynchronously)
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call saveSpecialSlideShapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = saveSpecialSlideShapeCall(name, slideIndex, slideType, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for saveSpecialSlideSubshape
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call saveSpecialSlideSubshapeCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling saveSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling saveSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling saveSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling saveSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling saveSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling saveSpecialSlideSubshape(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "scaleX", scaleX);
        apiClient.addQueryParameter(queryParams, "scaleY", scaleY);
        apiClient.addQueryParameter(queryParams, "bounds", bounds);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void saveSpecialSlideSubshape(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            saveSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
        } catch (NeedRepeatRequestException e) {
            saveSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
        }
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> saveSpecialSlideSubshapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = saveSpecialSlideSubshapeCall(name, slideIndex, slideType, path, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, null, null);
        return apiClient.execute(call);
    }

    /**
     * Render shape to specified picture format. (asynchronously)
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call saveSpecialSlideSubshapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = saveSpecialSlideSubshapeCall(name, slideIndex, slideType, path, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for saveSubshape
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call saveSubshapeCall(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling saveSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling saveSubshape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling saveSubshape(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling saveSubshape(Async)");
        }
        // verify the required parameter 'outPath' is set
        if (outPath == null) {
            throw new ApiException("Missing the required parameter 'outPath' when calling saveSubshape(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/{format}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "outPath", outPath);
        apiClient.addQueryParameter(queryParams, "scaleX", scaleX);
        apiClient.addQueryParameter(queryParams, "scaleY", scaleY);
        apiClient.addQueryParameter(queryParams, "bounds", bounds);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public void saveSubshape(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            saveSubshapeWithHttpInfo(name, slideIndex, path, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
        } catch (NeedRepeatRequestException e) {
            saveSubshapeWithHttpInfo(name, slideIndex, path, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder);
        }
    }

    /**
     * Render shape to specified picture format.
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @return ApiResponse&lt;Void&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Void> saveSubshapeWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = saveSubshapeCall(name, slideIndex, path, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, null, null);
        return apiClient.execute(call);
    }

    /**
     * Render shape to specified picture format. (asynchronously)
     * 
     * @param name Presentation name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path (for smart art and group shapes). 
     * @param shapeIndex Index of shape starting from 1 (required)
     * @param format Export picture format. (required)
     * @param outPath Output path. (required)
     * @param options export options 
     * @param scaleX X scale ratio. 
     * @param scaleY Y scale ratio. 
     * @param bounds Shape thumbnail bounds type. 
     * @param password Document password. 
     * @param folder Presentation folder. 
     * @param storage Presentation storage. 
     * @param fontsFolder Fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call saveSubshapeAsync(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeExportFormat format, String outPath, IShapeExportOptions options, Double scaleX, Double scaleY, ShapeThumbnailBounds bounds, String password, String folder, String storage, String fontsFolder, final ApiCallback<Void> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = saveSubshapeCall(name, slideIndex, path, shapeIndex, format, outPath, options, scaleX, scaleY, bounds, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        apiClient.executeAsync(call, callback);
        return call;
    }
    /**
     * Build call for setAnimation
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param animation Animation DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setAnimationCall(String name, Integer slideIndex, SlideAnimation animation, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setAnimation(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling setAnimation(Async)");
        }
        // verify the required parameter 'animation' is set
        if (animation == null) {
            throw new ApiException("Missing the required parameter 'animation' when calling setAnimation(Async)");
        }
        Object postBody = animation;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param animation Animation DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation setAnimation(String name, Integer slideIndex, SlideAnimation animation, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = setAnimationWithHttpInfo(name, slideIndex, animation, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = setAnimationWithHttpInfo(name, slideIndex, animation, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set slide animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param animation Animation DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> setAnimationWithHttpInfo(String name, Integer slideIndex, SlideAnimation animation, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setAnimationCall(name, slideIndex, animation, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set slide animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param animation Animation DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setAnimationAsync(String name, Integer slideIndex, SlideAnimation animation, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setAnimationCall(name, slideIndex, animation, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setBackground
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param background Slide background update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setBackgroundCall(String name, Integer slideIndex, SlideBackground background, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setBackground(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling setBackground(Async)");
        }
        // verify the required parameter 'background' is set
        if (background == null) {
            throw new ApiException("Missing the required parameter 'background' when calling setBackground(Async)");
        }
        Object postBody = background;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/background"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set background for a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param background Slide background update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideBackground
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideBackground setBackground(String name, Integer slideIndex, SlideBackground background, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideBackground> resp = setBackgroundWithHttpInfo(name, slideIndex, background, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideBackground> resp = setBackgroundWithHttpInfo(name, slideIndex, background, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set background for a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param background Slide background update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideBackground&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideBackground> setBackgroundWithHttpInfo(String name, Integer slideIndex, SlideBackground background, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setBackgroundCall(name, slideIndex, background, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideBackground>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set background for a slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param background Slide background update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setBackgroundAsync(String name, Integer slideIndex, SlideBackground background, String password, String folder, String storage, final ApiCallback<SlideBackground> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setBackgroundCall(name, slideIndex, background, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideBackground>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setBackgroundColor
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param color Slide background target color in RRGGBB format. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setBackgroundColorCall(String name, Integer slideIndex, String color, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setBackgroundColor(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling setBackgroundColor(Async)");
        }
        // verify the required parameter 'color' is set
        if (color == null) {
            throw new ApiException("Missing the required parameter 'color' when calling setBackgroundColor(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/backgroundColor"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "color", color);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set background color for a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param color Slide background target color in RRGGBB format. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideBackground
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideBackground setBackgroundColor(String name, Integer slideIndex, String color, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideBackground> resp = setBackgroundColorWithHttpInfo(name, slideIndex, color, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideBackground> resp = setBackgroundColorWithHttpInfo(name, slideIndex, color, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set background color for a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param color Slide background target color in RRGGBB format. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideBackground&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideBackground> setBackgroundColorWithHttpInfo(String name, Integer slideIndex, String color, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setBackgroundColorCall(name, slideIndex, color, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideBackground>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set background color for a slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param color Slide background target color in RRGGBB format. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setBackgroundColorAsync(String name, Integer slideIndex, String color, String password, String folder, String storage, final ApiCallback<SlideBackground> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setBackgroundColorCall(name, slideIndex, color, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideBackground>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setDocumentProperties
     * @param name Document name. (required)
     * @param properties New properties. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setDocumentPropertiesCall(String name, DocumentProperties properties, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setDocumentProperties(Async)");
        }
        // verify the required parameter 'properties' is set
        if (properties == null) {
            throw new ApiException("Missing the required parameter 'properties' when calling setDocumentProperties(Async)");
        }
        Object postBody = properties;

        // create path and map variables
        String methodPath = "/slides/{name}/documentproperties"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set document properties.
     * 
     * @param name Document name. (required)
     * @param properties New properties. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return DocumentProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public DocumentProperties setDocumentProperties(String name, DocumentProperties properties, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<DocumentProperties> resp = setDocumentPropertiesWithHttpInfo(name, properties, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<DocumentProperties> resp = setDocumentPropertiesWithHttpInfo(name, properties, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set document properties.
     * 
     * @param name Document name. (required)
     * @param properties New properties. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;DocumentProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<DocumentProperties> setDocumentPropertiesWithHttpInfo(String name, DocumentProperties properties, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setDocumentPropertiesCall(name, properties, password, folder, storage, null, null);
        Type returnType = new TypeToken<DocumentProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set document properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param properties New properties. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setDocumentPropertiesAsync(String name, DocumentProperties properties, String password, String folder, String storage, final ApiCallback<DocumentProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setDocumentPropertiesCall(name, properties, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<DocumentProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setDocumentProperty
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param property Property with the value. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setDocumentPropertyCall(String name, String propertyName, DocumentProperty property, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setDocumentProperty(Async)");
        }
        // verify the required parameter 'propertyName' is set
        if (propertyName == null) {
            throw new ApiException("Missing the required parameter 'propertyName' when calling setDocumentProperty(Async)");
        }
        // verify the required parameter 'property' is set
        if (property == null) {
            throw new ApiException("Missing the required parameter 'property' when calling setDocumentProperty(Async)");
        }
        Object postBody = property;

        // create path and map variables
        String methodPath = "/slides/{name}/documentproperties/{propertyName}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "propertyName" + "\\}", apiClient.objectToString(propertyName));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set document property.
     * 
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param property Property with the value. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return DocumentProperty
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public DocumentProperty setDocumentProperty(String name, String propertyName, DocumentProperty property, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<DocumentProperty> resp = setDocumentPropertyWithHttpInfo(name, propertyName, property, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<DocumentProperty> resp = setDocumentPropertyWithHttpInfo(name, propertyName, property, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set document property.
     * 
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param property Property with the value. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;DocumentProperty&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<DocumentProperty> setDocumentPropertyWithHttpInfo(String name, String propertyName, DocumentProperty property, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setDocumentPropertyCall(name, propertyName, property, password, folder, storage, null, null);
        Type returnType = new TypeToken<DocumentProperty>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set document property. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param propertyName The property name. (required)
     * @param property Property with the value. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setDocumentPropertyAsync(String name, String propertyName, DocumentProperty property, String password, String folder, String storage, final ApiCallback<DocumentProperty> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setDocumentPropertyCall(name, propertyName, property, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<DocumentProperty>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setNotesSlideHeaderFooter
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Header/footer to set. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setNotesSlideHeaderFooterCall(String name, Integer slideIndex, NotesSlideHeaderFooter dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setNotesSlideHeaderFooter(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling setNotesSlideHeaderFooter(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling setNotesSlideHeaderFooter(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/notesSlide/headerFooter"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set header/footer the notes slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Header/footer to set. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return NotesSlideHeaderFooter
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public NotesSlideHeaderFooter setNotesSlideHeaderFooter(String name, Integer slideIndex, NotesSlideHeaderFooter dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<NotesSlideHeaderFooter> resp = setNotesSlideHeaderFooterWithHttpInfo(name, slideIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<NotesSlideHeaderFooter> resp = setNotesSlideHeaderFooterWithHttpInfo(name, slideIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set header/footer the notes slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Header/footer to set. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;NotesSlideHeaderFooter&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<NotesSlideHeaderFooter> setNotesSlideHeaderFooterWithHttpInfo(String name, Integer slideIndex, NotesSlideHeaderFooter dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setNotesSlideHeaderFooterCall(name, slideIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<NotesSlideHeaderFooter>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set header/footer the notes slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto Header/footer to set. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setNotesSlideHeaderFooterAsync(String name, Integer slideIndex, NotesSlideHeaderFooter dto, String password, String folder, String storage, final ApiCallback<NotesSlideHeaderFooter> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setNotesSlideHeaderFooterCall(name, slideIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<NotesSlideHeaderFooter>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setPresentationHeaderFooter
     * @param name Document name. (required)
     * @param dto HeaderFooter instance. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setPresentationHeaderFooterCall(String name, HeaderFooter dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setPresentationHeaderFooter(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling setPresentationHeaderFooter(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/headerFooter"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set footers for all slides in a presentation.
     * 
     * @param name Document name. (required)
     * @param dto HeaderFooter instance. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Document
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Document setPresentationHeaderFooter(String name, HeaderFooter dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Document> resp = setPresentationHeaderFooterWithHttpInfo(name, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Document> resp = setPresentationHeaderFooterWithHttpInfo(name, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set footers for all slides in a presentation.
     * 
     * @param name Document name. (required)
     * @param dto HeaderFooter instance. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Document&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Document> setPresentationHeaderFooterWithHttpInfo(String name, HeaderFooter dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setPresentationHeaderFooterCall(name, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<Document>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set footers for all slides in a presentation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param dto HeaderFooter instance. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setPresentationHeaderFooterAsync(String name, HeaderFooter dto, String password, String folder, String storage, final ApiCallback<Document> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setPresentationHeaderFooterCall(name, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Document>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setProtection
     * @param name Document name. (required)
     * @param dto Protection properties. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setProtectionCall(String name, ProtectionProperties dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setProtection(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling setProtection(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/protection"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Updates presentation protection properties.
     * 
     * @param name Document name. (required)
     * @param dto Protection properties. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ProtectionProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ProtectionProperties setProtection(String name, ProtectionProperties dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ProtectionProperties> resp = setProtectionWithHttpInfo(name, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ProtectionProperties> resp = setProtectionWithHttpInfo(name, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Updates presentation protection properties.
     * 
     * @param name Document name. (required)
     * @param dto Protection properties. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ProtectionProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ProtectionProperties> setProtectionWithHttpInfo(String name, ProtectionProperties dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setProtectionCall(name, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<ProtectionProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Updates presentation protection properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param dto Protection properties. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setProtectionAsync(String name, ProtectionProperties dto, String password, String folder, String storage, final ApiCallback<ProtectionProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setProtectionCall(name, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ProtectionProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setProtectionOnline
     * @param document Document data. (required)
     * @param dto Protection properties. (required)
     * @param password Document password. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setProtectionOnlineCall(byte[] document, ProtectionProperties dto, String password, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling setProtectionOnline(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling setProtectionOnline(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/protection"
            ;

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Sets presentation protection options. 
     * 
     * @param document Document data. (required)
     * @param dto Protection properties. (required)
     * @param password Document password. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File setProtectionOnline(byte[] document, ProtectionProperties dto, String password) throws ApiException {
        try {
            ApiResponse<File> resp = setProtectionOnlineWithHttpInfo(document, dto, password);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = setProtectionOnlineWithHttpInfo(document, dto, password);
            return resp.getData();
        }
    }

    /**
     * Sets presentation protection options. 
     * 
     * @param document Document data. (required)
     * @param dto Protection properties. (required)
     * @param password Document password. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> setProtectionOnlineWithHttpInfo(byte[] document, ProtectionProperties dto, String password) throws ApiException {
        com.squareup.okhttp.Call call = setProtectionOnlineCall(document, dto, password, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Sets presentation protection options.  (asynchronously)
     * 
     * @param document Document data. (required)
     * @param dto Protection properties. (required)
     * @param password Document password. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setProtectionOnlineAsync(byte[] document, ProtectionProperties dto, String password, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setProtectionOnlineCall(document, dto, password, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setSections
     * @param name Document name. (required)
     * @param sections Sections DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setSectionsCall(String name, Sections sections, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setSections(Async)");
        }
        // verify the required parameter 'sections' is set
        if (sections == null) {
            throw new ApiException("Missing the required parameter 'sections' when calling setSections(Async)");
        }
        Object postBody = sections;

        // create path and map variables
        String methodPath = "/slides/{name}/sections"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Replace existing presentation sections with the ones provided in the sections DTO.
     * 
     * @param name Document name. (required)
     * @param sections Sections DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Sections
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Sections setSections(String name, Sections sections, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Sections> resp = setSectionsWithHttpInfo(name, sections, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Sections> resp = setSectionsWithHttpInfo(name, sections, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Replace existing presentation sections with the ones provided in the sections DTO.
     * 
     * @param name Document name. (required)
     * @param sections Sections DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Sections&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Sections> setSectionsWithHttpInfo(String name, Sections sections, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setSectionsCall(name, sections, password, folder, storage, null, null);
        Type returnType = new TypeToken<Sections>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Replace existing presentation sections with the ones provided in the sections DTO. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param sections Sections DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setSectionsAsync(String name, Sections sections, String password, String folder, String storage, final ApiCallback<Sections> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setSectionsCall(name, sections, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Sections>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setShapeGeometryPath
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Geometry paths DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setShapeGeometryPathCall(String name, Integer slideIndex, Integer shapeIndex, GeometryPaths dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setShapeGeometryPath(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling setShapeGeometryPath(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling setShapeGeometryPath(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling setShapeGeometryPath(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/geometryPath"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Sets geometry path to the shape
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Geometry paths DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase setShapeGeometryPath(String name, Integer slideIndex, Integer shapeIndex, GeometryPaths dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = setShapeGeometryPathWithHttpInfo(name, slideIndex, shapeIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = setShapeGeometryPathWithHttpInfo(name, slideIndex, shapeIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Sets geometry path to the shape
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Geometry paths DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> setShapeGeometryPathWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, GeometryPaths dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setShapeGeometryPathCall(name, slideIndex, shapeIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Sets geometry path to the shape (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Geometry paths DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setShapeGeometryPathAsync(String name, Integer slideIndex, Integer shapeIndex, GeometryPaths dto, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setShapeGeometryPathCall(name, slideIndex, shapeIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setSlideHeaderFooter
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param dto Footer to set. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setSlideHeaderFooterCall(String name, Integer slideIndex, HeaderFooter dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setSlideHeaderFooter(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling setSlideHeaderFooter(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling setSlideHeaderFooter(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/headerFooter"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set footer the slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param dto Footer to set. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return HeaderFooter
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public HeaderFooter setSlideHeaderFooter(String name, Integer slideIndex, HeaderFooter dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<HeaderFooter> resp = setSlideHeaderFooterWithHttpInfo(name, slideIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<HeaderFooter> resp = setSlideHeaderFooterWithHttpInfo(name, slideIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set footer the slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param dto Footer to set. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;HeaderFooter&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<HeaderFooter> setSlideHeaderFooterWithHttpInfo(String name, Integer slideIndex, HeaderFooter dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setSlideHeaderFooterCall(name, slideIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<HeaderFooter>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set footer the slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex The position of the slide to be reordered. (required)
     * @param dto Footer to set. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setSlideHeaderFooterAsync(String name, Integer slideIndex, HeaderFooter dto, String password, String folder, String storage, final ApiCallback<HeaderFooter> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setSlideHeaderFooterCall(name, slideIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<HeaderFooter>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setSlideProperties
     * @param name Document name. (required)
     * @param dto The view properties data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setSlidePropertiesCall(String name, SlideProperties dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setSlideProperties(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling setSlideProperties(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slideProperties"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update presentation slide properties.
     * 
     * @param name Document name. (required)
     * @param dto The view properties data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideProperties setSlideProperties(String name, SlideProperties dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideProperties> resp = setSlidePropertiesWithHttpInfo(name, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideProperties> resp = setSlidePropertiesWithHttpInfo(name, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update presentation slide properties.
     * 
     * @param name Document name. (required)
     * @param dto The view properties data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideProperties> setSlidePropertiesWithHttpInfo(String name, SlideProperties dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setSlidePropertiesCall(name, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update presentation slide properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param dto The view properties data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setSlidePropertiesAsync(String name, SlideProperties dto, String password, String folder, String storage, final ApiCallback<SlideProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setSlidePropertiesCall(name, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setSpecialSlideAnimation
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param animation Animation DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setSpecialSlideAnimationCall(String name, Integer slideIndex, SpecialSlideType slideType, SlideAnimation animation, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setSpecialSlideAnimation(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling setSpecialSlideAnimation(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling setSpecialSlideAnimation(Async)");
        }
        // verify the required parameter 'animation' is set
        if (animation == null) {
            throw new ApiException("Missing the required parameter 'animation' when calling setSpecialSlideAnimation(Async)");
        }
        Object postBody = animation;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Set special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param animation Animation DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation setSpecialSlideAnimation(String name, Integer slideIndex, SpecialSlideType slideType, SlideAnimation animation, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = setSpecialSlideAnimationWithHttpInfo(name, slideIndex, slideType, animation, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = setSpecialSlideAnimationWithHttpInfo(name, slideIndex, slideType, animation, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Set special slide (master, layout, notes) animation.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param animation Animation DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> setSpecialSlideAnimationWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, SlideAnimation animation, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setSpecialSlideAnimationCall(name, slideIndex, slideType, animation, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Set special slide (master, layout, notes) animation. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param animation Animation DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setSpecialSlideAnimationAsync(String name, Integer slideIndex, SpecialSlideType slideType, SlideAnimation animation, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setSpecialSlideAnimationCall(name, slideIndex, slideType, animation, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for setViewProperties
     * @param name Document name. (required)
     * @param dto The view properties data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call setViewPropertiesCall(String name, ViewProperties dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling setViewProperties(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling setViewProperties(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/viewProperties"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update presentation document properties.
     * 
     * @param name Document name. (required)
     * @param dto The view properties data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ViewProperties
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ViewProperties setViewProperties(String name, ViewProperties dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ViewProperties> resp = setViewPropertiesWithHttpInfo(name, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ViewProperties> resp = setViewPropertiesWithHttpInfo(name, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update presentation document properties.
     * 
     * @param name Document name. (required)
     * @param dto The view properties data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ViewProperties&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ViewProperties> setViewPropertiesWithHttpInfo(String name, ViewProperties dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = setViewPropertiesCall(name, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<ViewProperties>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update presentation document properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param dto The view properties data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call setViewPropertiesAsync(String name, ViewProperties dto, String password, String folder, String storage, final ApiCallback<ViewProperties> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = setViewPropertiesCall(name, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ViewProperties>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for split
     * @param name Document name. (required)
     * @param options Export options. 
     * @param format Export format. Default value is jpeg. 
     * @param width The width of created images. 
     * @param height The height of created images. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param destFolder Folder on storage where images are going to be uploaded. If not specified then images are uploaded to same folder as presentation. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call splitCall(String name, ExportOptions options, SlideExportFormat format, Integer width, Integer height, Integer from, Integer to, String destFolder, String password, String folder, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling split(Async)");
        }
        Object postBody = options;

        // create path and map variables
        String methodPath = "/slides/{name}/split"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "format", format);
        apiClient.addQueryParameter(queryParams, "width", width);
        apiClient.addQueryParameter(queryParams, "height", height);
        apiClient.addQueryParameter(queryParams, "from", from);
        apiClient.addQueryParameter(queryParams, "to", to);
        apiClient.addQueryParameter(queryParams, "destFolder", destFolder);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Splitting presentations. Create one image per slide.
     * 
     * @param name Document name. (required)
     * @param options Export options. 
     * @param format Export format. Default value is jpeg. 
     * @param width The width of created images. 
     * @param height The height of created images. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param destFolder Folder on storage where images are going to be uploaded. If not specified then images are uploaded to same folder as presentation. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @return SplitDocumentResult
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SplitDocumentResult split(String name, ExportOptions options, SlideExportFormat format, Integer width, Integer height, Integer from, Integer to, String destFolder, String password, String folder, String storage, String fontsFolder) throws ApiException {
        try {
            ApiResponse<SplitDocumentResult> resp = splitWithHttpInfo(name, options, format, width, height, from, to, destFolder, password, folder, storage, fontsFolder);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SplitDocumentResult> resp = splitWithHttpInfo(name, options, format, width, height, from, to, destFolder, password, folder, storage, fontsFolder);
            return resp.getData();
        }
    }

    /**
     * Splitting presentations. Create one image per slide.
     * 
     * @param name Document name. (required)
     * @param options Export options. 
     * @param format Export format. Default value is jpeg. 
     * @param width The width of created images. 
     * @param height The height of created images. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param destFolder Folder on storage where images are going to be uploaded. If not specified then images are uploaded to same folder as presentation. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @return ApiResponse&lt;SplitDocumentResult&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SplitDocumentResult> splitWithHttpInfo(String name, ExportOptions options, SlideExportFormat format, Integer width, Integer height, Integer from, Integer to, String destFolder, String password, String folder, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = splitCall(name, options, format, width, height, from, to, destFolder, password, folder, storage, fontsFolder, null, null);
        Type returnType = new TypeToken<SplitDocumentResult>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Splitting presentations. Create one image per slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param options Export options. 
     * @param format Export format. Default value is jpeg. 
     * @param width The width of created images. 
     * @param height The height of created images. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param destFolder Folder on storage where images are going to be uploaded. If not specified then images are uploaded to same folder as presentation. 
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call splitAsync(String name, ExportOptions options, SlideExportFormat format, Integer width, Integer height, Integer from, Integer to, String destFolder, String password, String folder, String storage, String fontsFolder, final ApiCallback<SplitDocumentResult> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = splitCall(name, options, format, width, height, from, to, destFolder, password, folder, storage, fontsFolder, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SplitDocumentResult>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for splitAndSaveOnline
     * @param document Document data. (required)
     * @param format ExportFormat (required)
     * @param destFolder Folder on storage where images are going to be uploaded. If not specified then images are uploaded to the root folder. 
     * @param width Slide width. 
     * @param height Slide height. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call splitAndSaveOnlineCall(byte[] document, SlideExportFormat format, String destFolder, Integer width, Integer height, Integer from, Integer to, String password, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling splitAndSaveOnline(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling splitAndSaveOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/split/{format}"
            .replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "destFolder", destFolder);
        apiClient.addQueryParameter(queryParams, "width", width);
        apiClient.addQueryParameter(queryParams, "height", height);
        apiClient.addQueryParameter(queryParams, "from", from);
        apiClient.addQueryParameter(queryParams, "to", to);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Splits PowerPoint presentation slides from the specified range into separate files and exports them in the specified file format. If the range is not provided all slides will be processed. 
     * 
     * @param document Document data. (required)
     * @param format ExportFormat (required)
     * @param destFolder Folder on storage where images are going to be uploaded. If not specified then images are uploaded to the root folder. 
     * @param width Slide width. 
     * @param height Slide height. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @return SplitDocumentResult
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SplitDocumentResult splitAndSaveOnline(byte[] document, SlideExportFormat format, String destFolder, Integer width, Integer height, Integer from, Integer to, String password, String storage, String fontsFolder) throws ApiException {
        try {
            ApiResponse<SplitDocumentResult> resp = splitAndSaveOnlineWithHttpInfo(document, format, destFolder, width, height, from, to, password, storage, fontsFolder);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SplitDocumentResult> resp = splitAndSaveOnlineWithHttpInfo(document, format, destFolder, width, height, from, to, password, storage, fontsFolder);
            return resp.getData();
        }
    }

    /**
     * Splits PowerPoint presentation slides from the specified range into separate files and exports them in the specified file format. If the range is not provided all slides will be processed. 
     * 
     * @param document Document data. (required)
     * @param format ExportFormat (required)
     * @param destFolder Folder on storage where images are going to be uploaded. If not specified then images are uploaded to the root folder. 
     * @param width Slide width. 
     * @param height Slide height. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @return ApiResponse&lt;SplitDocumentResult&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SplitDocumentResult> splitAndSaveOnlineWithHttpInfo(byte[] document, SlideExportFormat format, String destFolder, Integer width, Integer height, Integer from, Integer to, String password, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = splitAndSaveOnlineCall(document, format, destFolder, width, height, from, to, password, storage, fontsFolder, null, null);
        Type returnType = new TypeToken<SplitDocumentResult>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Splits PowerPoint presentation slides from the specified range into separate files and exports them in the specified file format. If the range is not provided all slides will be processed.  (asynchronously)
     * 
     * @param document Document data. (required)
     * @param format ExportFormat (required)
     * @param destFolder Folder on storage where images are going to be uploaded. If not specified then images are uploaded to the root folder. 
     * @param width Slide width. 
     * @param height Slide height. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call splitAndSaveOnlineAsync(byte[] document, SlideExportFormat format, String destFolder, Integer width, Integer height, Integer from, Integer to, String password, String storage, String fontsFolder, final ApiCallback<SplitDocumentResult> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = splitAndSaveOnlineCall(document, format, destFolder, width, height, from, to, password, storage, fontsFolder, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SplitDocumentResult>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for splitOnline
     * @param document Document data. (required)
     * @param format ExportFormat (required)
     * @param width Slide width. 
     * @param height Slide height. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call splitOnlineCall(byte[] document, SlideExportFormat format, Integer width, Integer height, Integer from, Integer to, String password, String storage, String fontsFolder, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'document' is set
        if (document == null) {
            throw new ApiException("Missing the required parameter 'document' when calling splitOnline(Async)");
        }
        // verify the required parameter 'format' is set
        if (format == null) {
            throw new ApiException("Missing the required parameter 'format' when calling splitOnline(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/split/{format}"
            .replaceAll("\\{" + "format" + "\\}", apiClient.objectToString(format));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "width", width);
        apiClient.addQueryParameter(queryParams, "height", height);
        apiClient.addQueryParameter(queryParams, "from", from);
        apiClient.addQueryParameter(queryParams, "to", to);
        apiClient.addQueryParameter(queryParams, "storage", storage);
        apiClient.addQueryParameter(queryParams, "fontsFolder", fontsFolder);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (document != null)
        formParams.put("document", document);

        final String[] accepts = {
            "multipart/form-data"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "POST", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Splits PowerPoint presentation slides from the specified range into separate files and exports them in the specified file format. If the range is not provided all slides will be processed. 
     * 
     * @param document Document data. (required)
     * @param format ExportFormat (required)
     * @param width Slide width. 
     * @param height Slide height. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @return File
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public File splitOnline(byte[] document, SlideExportFormat format, Integer width, Integer height, Integer from, Integer to, String password, String storage, String fontsFolder) throws ApiException {
        try {
            ApiResponse<File> resp = splitOnlineWithHttpInfo(document, format, width, height, from, to, password, storage, fontsFolder);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<File> resp = splitOnlineWithHttpInfo(document, format, width, height, from, to, password, storage, fontsFolder);
            return resp.getData();
        }
    }

    /**
     * Splits PowerPoint presentation slides from the specified range into separate files and exports them in the specified file format. If the range is not provided all slides will be processed. 
     * 
     * @param document Document data. (required)
     * @param format ExportFormat (required)
     * @param width Slide width. 
     * @param height Slide height. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @return ApiResponse&lt;File&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<File> splitOnlineWithHttpInfo(byte[] document, SlideExportFormat format, Integer width, Integer height, Integer from, Integer to, String password, String storage, String fontsFolder) throws ApiException {
        com.squareup.okhttp.Call call = splitOnlineCall(document, format, width, height, from, to, password, storage, fontsFolder, null, null);
        Type returnType = new TypeToken<File>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Splits PowerPoint presentation slides from the specified range into separate files and exports them in the specified file format. If the range is not provided all slides will be processed.  (asynchronously)
     * 
     * @param document Document data. (required)
     * @param format ExportFormat (required)
     * @param width Slide width. 
     * @param height Slide height. 
     * @param from The start slide number for splitting, if is not specified splitting starts from the first slide of the presentation. 
     * @param to The last slide number for splitting, if is not specified splitting ends at the last slide of the document. 
     * @param password Document password. 
     * @param storage Document storage. 
     * @param fontsFolder Custom fonts folder. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call splitOnlineAsync(byte[] document, SlideExportFormat format, Integer width, Integer height, Integer from, Integer to, String password, String storage, String fontsFolder, final ApiCallback<File> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = splitOnlineCall(document, format, width, height, from, to, password, storage, fontsFolder, progressListener, progressRequestListener);
        Type returnType = new TypeToken<File>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for storageExists
     * @param storageName Storage name (required)
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call storageExistsCall(String storageName, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'storageName' is set
        if (storageName == null) {
            throw new ApiException("Missing the required parameter 'storageName' when calling storageExists(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/{storageName}/exist"
            .replaceAll("\\{" + "storageName" + "\\}", apiClient.objectToString(storageName));

        List<Pair> queryParams = new ArrayList<Pair>();

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "GET", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Check if storage exists
     * 
     * @param storageName Storage name (required)
     * @return StorageExist
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public StorageExist storageExists(String storageName) throws ApiException {
        try {
            ApiResponse<StorageExist> resp = storageExistsWithHttpInfo(storageName);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<StorageExist> resp = storageExistsWithHttpInfo(storageName);
            return resp.getData();
        }
    }

    /**
     * Check if storage exists
     * 
     * @param storageName Storage name (required)
     * @return ApiResponse&lt;StorageExist&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<StorageExist> storageExistsWithHttpInfo(String storageName) throws ApiException {
        com.squareup.okhttp.Call call = storageExistsCall(storageName, null, null);
        Type returnType = new TypeToken<StorageExist>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Check if storage exists (asynchronously)
     * 
     * @param storageName Storage name (required)
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call storageExistsAsync(String storageName, final ApiCallback<StorageExist> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = storageExistsCall(storageName, progressListener, progressRequestListener);
        Type returnType = new TypeToken<StorageExist>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateAnimationEffect
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateAnimationEffectCall(String name, Integer slideIndex, Integer effectIndex, Effect effect, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateAnimationEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateAnimationEffect(Async)");
        }
        // verify the required parameter 'effectIndex' is set
        if (effectIndex == null) {
            throw new ApiException("Missing the required parameter 'effectIndex' when calling updateAnimationEffect(Async)");
        }
        // verify the required parameter 'effect' is set
        if (effect == null) {
            throw new ApiException("Missing the required parameter 'effect' when calling updateAnimationEffect(Async)");
        }
        Object postBody = effect;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation/mainSequence/{effectIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "effectIndex" + "\\}", apiClient.objectToString(effectIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Modify an animation effect for a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation updateAnimationEffect(String name, Integer slideIndex, Integer effectIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = updateAnimationEffectWithHttpInfo(name, slideIndex, effectIndex, effect, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = updateAnimationEffectWithHttpInfo(name, slideIndex, effectIndex, effect, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Modify an animation effect for a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> updateAnimationEffectWithHttpInfo(String name, Integer slideIndex, Integer effectIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateAnimationEffectCall(name, slideIndex, effectIndex, effect, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Modify an animation effect for a slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateAnimationEffectAsync(String name, Integer slideIndex, Integer effectIndex, Effect effect, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateAnimationEffectCall(name, slideIndex, effectIndex, effect, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateAnimationInteractiveSequenceEffect
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateAnimationInteractiveSequenceEffectCall(String name, Integer slideIndex, Integer sequenceIndex, Integer effectIndex, Effect effect, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'sequenceIndex' is set
        if (sequenceIndex == null) {
            throw new ApiException("Missing the required parameter 'sequenceIndex' when calling updateAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'effectIndex' is set
        if (effectIndex == null) {
            throw new ApiException("Missing the required parameter 'effectIndex' when calling updateAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'effect' is set
        if (effect == null) {
            throw new ApiException("Missing the required parameter 'effect' when calling updateAnimationInteractiveSequenceEffect(Async)");
        }
        Object postBody = effect;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/animation/interactiveSequences/{sequenceIndex}/{effectIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "sequenceIndex" + "\\}", apiClient.objectToString(sequenceIndex)).replaceAll("\\{" + "effectIndex" + "\\}", apiClient.objectToString(effectIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Modify an animation effect for a slide interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation updateAnimationInteractiveSequenceEffect(String name, Integer slideIndex, Integer sequenceIndex, Integer effectIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = updateAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, sequenceIndex, effectIndex, effect, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = updateAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, sequenceIndex, effectIndex, effect, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Modify an animation effect for a slide interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> updateAnimationInteractiveSequenceEffectWithHttpInfo(String name, Integer slideIndex, Integer sequenceIndex, Integer effectIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateAnimationInteractiveSequenceEffectCall(name, slideIndex, sequenceIndex, effectIndex, effect, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Modify an animation effect for a slide interactive sequence. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateAnimationInteractiveSequenceEffectAsync(String name, Integer slideIndex, Integer sequenceIndex, Integer effectIndex, Effect effect, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateAnimationInteractiveSequenceEffectCall(name, slideIndex, sequenceIndex, effectIndex, effect, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateChartCategory
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param categoryIndex Category index. (required)
     * @param category Category DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateChartCategoryCall(String name, Integer slideIndex, Integer shapeIndex, Integer categoryIndex, ChartCategory category, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateChartCategory(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateChartCategory(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateChartCategory(Async)");
        }
        // verify the required parameter 'categoryIndex' is set
        if (categoryIndex == null) {
            throw new ApiException("Missing the required parameter 'categoryIndex' when calling updateChartCategory(Async)");
        }
        // verify the required parameter 'category' is set
        if (category == null) {
            throw new ApiException("Missing the required parameter 'category' when calling updateChartCategory(Async)");
        }
        Object postBody = category;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/categories/{categoryIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "categoryIndex" + "\\}", apiClient.objectToString(categoryIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update a chart category.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param categoryIndex Category index. (required)
     * @param category Category DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Chart
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Chart updateChartCategory(String name, Integer slideIndex, Integer shapeIndex, Integer categoryIndex, ChartCategory category, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Chart> resp = updateChartCategoryWithHttpInfo(name, slideIndex, shapeIndex, categoryIndex, category, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Chart> resp = updateChartCategoryWithHttpInfo(name, slideIndex, shapeIndex, categoryIndex, category, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update a chart category.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param categoryIndex Category index. (required)
     * @param category Category DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Chart&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Chart> updateChartCategoryWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer categoryIndex, ChartCategory category, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateChartCategoryCall(name, slideIndex, shapeIndex, categoryIndex, category, password, folder, storage, null, null);
        Type returnType = new TypeToken<Chart>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update a chart category. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param categoryIndex Category index. (required)
     * @param category Category DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateChartCategoryAsync(String name, Integer slideIndex, Integer shapeIndex, Integer categoryIndex, ChartCategory category, String password, String folder, String storage, final ApiCallback<Chart> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateChartCategoryCall(name, slideIndex, shapeIndex, categoryIndex, category, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Chart>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateChartDataPoint
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param pointIndex Data point index. (required)
     * @param dataPoint Data point DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateChartDataPointCall(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Integer pointIndex, DataPoint dataPoint, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateChartDataPoint(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateChartDataPoint(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateChartDataPoint(Async)");
        }
        // verify the required parameter 'seriesIndex' is set
        if (seriesIndex == null) {
            throw new ApiException("Missing the required parameter 'seriesIndex' when calling updateChartDataPoint(Async)");
        }
        // verify the required parameter 'pointIndex' is set
        if (pointIndex == null) {
            throw new ApiException("Missing the required parameter 'pointIndex' when calling updateChartDataPoint(Async)");
        }
        // verify the required parameter 'dataPoint' is set
        if (dataPoint == null) {
            throw new ApiException("Missing the required parameter 'dataPoint' when calling updateChartDataPoint(Async)");
        }
        Object postBody = dataPoint;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/series/{seriesIndex}/dataPoints/{pointIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "seriesIndex" + "\\}", apiClient.objectToString(seriesIndex)).replaceAll("\\{" + "pointIndex" + "\\}", apiClient.objectToString(pointIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update a data point in a chart series.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param pointIndex Data point index. (required)
     * @param dataPoint Data point DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Chart
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Chart updateChartDataPoint(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Integer pointIndex, DataPoint dataPoint, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Chart> resp = updateChartDataPointWithHttpInfo(name, slideIndex, shapeIndex, seriesIndex, pointIndex, dataPoint, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Chart> resp = updateChartDataPointWithHttpInfo(name, slideIndex, shapeIndex, seriesIndex, pointIndex, dataPoint, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update a data point in a chart series.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param pointIndex Data point index. (required)
     * @param dataPoint Data point DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Chart&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Chart> updateChartDataPointWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Integer pointIndex, DataPoint dataPoint, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateChartDataPointCall(name, slideIndex, shapeIndex, seriesIndex, pointIndex, dataPoint, password, folder, storage, null, null);
        Type returnType = new TypeToken<Chart>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update a data point in a chart series. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param seriesIndex Series index. (required)
     * @param pointIndex Data point index. (required)
     * @param dataPoint Data point DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateChartDataPointAsync(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Integer pointIndex, DataPoint dataPoint, String password, String folder, String storage, final ApiCallback<Chart> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateChartDataPointCall(name, slideIndex, shapeIndex, seriesIndex, pointIndex, dataPoint, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Chart>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateChartSeries
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param seriesIndex Series index. (required)
     * @param series Series DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateChartSeriesCall(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Series series, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateChartSeries(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateChartSeries(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateChartSeries(Async)");
        }
        // verify the required parameter 'seriesIndex' is set
        if (seriesIndex == null) {
            throw new ApiException("Missing the required parameter 'seriesIndex' when calling updateChartSeries(Async)");
        }
        // verify the required parameter 'series' is set
        if (series == null) {
            throw new ApiException("Missing the required parameter 'series' when calling updateChartSeries(Async)");
        }
        Object postBody = series;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/series/{seriesIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "seriesIndex" + "\\}", apiClient.objectToString(seriesIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update a series in a chart.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param seriesIndex Series index. (required)
     * @param series Series DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Chart
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Chart updateChartSeries(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Series series, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Chart> resp = updateChartSeriesWithHttpInfo(name, slideIndex, shapeIndex, seriesIndex, series, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Chart> resp = updateChartSeriesWithHttpInfo(name, slideIndex, shapeIndex, seriesIndex, series, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update a series in a chart.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param seriesIndex Series index. (required)
     * @param series Series DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Chart&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Chart> updateChartSeriesWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Series series, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateChartSeriesCall(name, slideIndex, shapeIndex, seriesIndex, series, password, folder, storage, null, null);
        Type returnType = new TypeToken<Chart>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update a series in a chart. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index (must be a chart). (required)
     * @param seriesIndex Series index. (required)
     * @param series Series DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateChartSeriesAsync(String name, Integer slideIndex, Integer shapeIndex, Integer seriesIndex, Series series, String password, String folder, String storage, final ApiCallback<Chart> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateChartSeriesCall(name, slideIndex, shapeIndex, seriesIndex, series, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Chart>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateLayoutSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param slideDto Slide update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateLayoutSlideCall(String name, Integer slideIndex, LayoutSlide slideDto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateLayoutSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateLayoutSlide(Async)");
        }
        // verify the required parameter 'slideDto' is set
        if (slideDto == null) {
            throw new ApiException("Missing the required parameter 'slideDto' when calling updateLayoutSlide(Async)");
        }
        Object postBody = slideDto;

        // create path and map variables
        String methodPath = "/slides/{name}/layoutSlides/{slideIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update a layoutSlide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param slideDto Slide update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return LayoutSlide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public LayoutSlide updateLayoutSlide(String name, Integer slideIndex, LayoutSlide slideDto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<LayoutSlide> resp = updateLayoutSlideWithHttpInfo(name, slideIndex, slideDto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<LayoutSlide> resp = updateLayoutSlideWithHttpInfo(name, slideIndex, slideDto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update a layoutSlide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param slideDto Slide update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;LayoutSlide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<LayoutSlide> updateLayoutSlideWithHttpInfo(String name, Integer slideIndex, LayoutSlide slideDto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateLayoutSlideCall(name, slideIndex, slideDto, password, folder, storage, null, null);
        Type returnType = new TypeToken<LayoutSlide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update a layoutSlide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param slideDto Slide update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateLayoutSlideAsync(String name, Integer slideIndex, LayoutSlide slideDto, String password, String folder, String storage, final ApiCallback<LayoutSlide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateLayoutSlideCall(name, slideIndex, slideDto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<LayoutSlide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateNotesSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto A NotesSlide object with notes slide data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateNotesSlideCall(String name, Integer slideIndex, NotesSlide dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateNotesSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateNotesSlide(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateNotesSlide(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/notesSlide"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update notes slide properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto A NotesSlide object with notes slide data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return NotesSlide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public NotesSlide updateNotesSlide(String name, Integer slideIndex, NotesSlide dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<NotesSlide> resp = updateNotesSlideWithHttpInfo(name, slideIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<NotesSlide> resp = updateNotesSlideWithHttpInfo(name, slideIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update notes slide properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto A NotesSlide object with notes slide data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;NotesSlide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<NotesSlide> updateNotesSlideWithHttpInfo(String name, Integer slideIndex, NotesSlide dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateNotesSlideCall(name, slideIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<NotesSlide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update notes slide properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param dto A NotesSlide object with notes slide data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateNotesSlideAsync(String name, Integer slideIndex, NotesSlide dto, String password, String folder, String storage, final ApiCallback<NotesSlide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateNotesSlideCall(name, slideIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<NotesSlide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateParagraph
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateParagraphCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling updateParagraph(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateParagraph(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update paragraph properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph updateParagraph(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = updateParagraphWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = updateParagraphWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update paragraph properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> updateParagraphWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateParagraphCall(name, slideIndex, shapeIndex, paragraphIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update paragraph properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateParagraphAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateParagraphCall(name, slideIndex, shapeIndex, paragraphIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updatePortion
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updatePortionCall(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updatePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updatePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updatePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling updatePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling updatePortion(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updatePortion(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update portion properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion updatePortion(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = updatePortionWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = updatePortionWithHttpInfo(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update portion properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> updatePortionWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updatePortionCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update portion properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updatePortionAsync(String name, Integer slideIndex, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updatePortionCall(name, slideIndex, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSection
     * @param name Document name. (required)
     * @param sectionIndex The position of the section to be updated. (required)
     * @param sectionName Section name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSectionCall(String name, Integer sectionIndex, String sectionName, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSection(Async)");
        }
        // verify the required parameter 'sectionIndex' is set
        if (sectionIndex == null) {
            throw new ApiException("Missing the required parameter 'sectionIndex' when calling updateSection(Async)");
        }
        // verify the required parameter 'sectionName' is set
        if (sectionName == null) {
            throw new ApiException("Missing the required parameter 'sectionName' when calling updateSection(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/{name}/sections/{sectionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "sectionIndex" + "\\}", apiClient.objectToString(sectionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "sectionName", sectionName);
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update section name.
     * 
     * @param name Document name. (required)
     * @param sectionIndex The position of the section to be updated. (required)
     * @param sectionName Section name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Sections
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Sections updateSection(String name, Integer sectionIndex, String sectionName, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Sections> resp = updateSectionWithHttpInfo(name, sectionIndex, sectionName, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Sections> resp = updateSectionWithHttpInfo(name, sectionIndex, sectionName, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update section name.
     * 
     * @param name Document name. (required)
     * @param sectionIndex The position of the section to be updated. (required)
     * @param sectionName Section name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Sections&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Sections> updateSectionWithHttpInfo(String name, Integer sectionIndex, String sectionName, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSectionCall(name, sectionIndex, sectionName, password, folder, storage, null, null);
        Type returnType = new TypeToken<Sections>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update section name. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param sectionIndex The position of the section to be updated. (required)
     * @param sectionName Section name. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSectionAsync(String name, Integer sectionIndex, String sectionName, String password, String folder, String storage, final ApiCallback<Sections> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSectionCall(name, sectionIndex, sectionName, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Sections>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateShape
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateShapeCall(String name, Integer slideIndex, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateShape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateShape(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateShape(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update shape properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase updateShape(String name, Integer slideIndex, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = updateShapeWithHttpInfo(name, slideIndex, shapeIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = updateShapeWithHttpInfo(name, slideIndex, shapeIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update shape properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> updateShapeWithHttpInfo(String name, Integer slideIndex, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateShapeCall(name, slideIndex, shapeIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update shape properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateShapeAsync(String name, Integer slideIndex, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateShapeCall(name, slideIndex, shapeIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSlide
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param slideDto Slide update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSlideCall(String name, Integer slideIndex, Slide slideDto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSlide(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSlide(Async)");
        }
        // verify the required parameter 'slideDto' is set
        if (slideDto == null) {
            throw new ApiException("Missing the required parameter 'slideDto' when calling updateSlide(Async)");
        }
        Object postBody = slideDto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param slideDto Slide update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Slide
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Slide updateSlide(String name, Integer slideIndex, Slide slideDto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Slide> resp = updateSlideWithHttpInfo(name, slideIndex, slideDto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Slide> resp = updateSlideWithHttpInfo(name, slideIndex, slideDto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update a slide.
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param slideDto Slide update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Slide&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Slide> updateSlideWithHttpInfo(String name, Integer slideIndex, Slide slideDto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSlideCall(name, slideIndex, slideDto, password, folder, storage, null, null);
        Type returnType = new TypeToken<Slide>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update a slide. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param slideDto Slide update data. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSlideAsync(String name, Integer slideIndex, Slide slideDto, String password, String folder, String storage, final ApiCallback<Slide> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSlideCall(name, slideIndex, slideDto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Slide>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSpecialSlideAnimationEffect
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideAnimationEffectCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer effectIndex, Effect effect, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSpecialSlideAnimationEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSpecialSlideAnimationEffect(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling updateSpecialSlideAnimationEffect(Async)");
        }
        // verify the required parameter 'effectIndex' is set
        if (effectIndex == null) {
            throw new ApiException("Missing the required parameter 'effectIndex' when calling updateSpecialSlideAnimationEffect(Async)");
        }
        // verify the required parameter 'effect' is set
        if (effect == null) {
            throw new ApiException("Missing the required parameter 'effect' when calling updateSpecialSlideAnimationEffect(Async)");
        }
        Object postBody = effect;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation/mainSequence/{effectIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "effectIndex" + "\\}", apiClient.objectToString(effectIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Modify an animation effect for a special slide (master, layout, notes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation updateSpecialSlideAnimationEffect(String name, Integer slideIndex, SpecialSlideType slideType, Integer effectIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = updateSpecialSlideAnimationEffectWithHttpInfo(name, slideIndex, slideType, effectIndex, effect, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = updateSpecialSlideAnimationEffectWithHttpInfo(name, slideIndex, slideType, effectIndex, effect, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Modify an animation effect for a special slide (master, layout, notes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> updateSpecialSlideAnimationEffectWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer effectIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSpecialSlideAnimationEffectCall(name, slideIndex, slideType, effectIndex, effect, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Modify an animation effect for a special slide (master, layout, notes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideAnimationEffectAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer effectIndex, Effect effect, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSpecialSlideAnimationEffectCall(name, slideIndex, slideType, effectIndex, effect, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSpecialSlideAnimationInteractiveSequenceEffect
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideAnimationInteractiveSequenceEffectCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Integer effectIndex, Effect effect, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling updateSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'sequenceIndex' is set
        if (sequenceIndex == null) {
            throw new ApiException("Missing the required parameter 'sequenceIndex' when calling updateSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'effectIndex' is set
        if (effectIndex == null) {
            throw new ApiException("Missing the required parameter 'effectIndex' when calling updateSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        // verify the required parameter 'effect' is set
        if (effect == null) {
            throw new ApiException("Missing the required parameter 'effect' when calling updateSpecialSlideAnimationInteractiveSequenceEffect(Async)");
        }
        Object postBody = effect;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/animation/interactiveSequences/{sequenceIndex}/{effectIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "sequenceIndex" + "\\}", apiClient.objectToString(sequenceIndex)).replaceAll("\\{" + "effectIndex" + "\\}", apiClient.objectToString(effectIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Modify an animation effect for a special slide (master, layout, notes) interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return SlideAnimation
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public SlideAnimation updateSpecialSlideAnimationInteractiveSequenceEffect(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Integer effectIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<SlideAnimation> resp = updateSpecialSlideAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, slideType, sequenceIndex, effectIndex, effect, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<SlideAnimation> resp = updateSpecialSlideAnimationInteractiveSequenceEffectWithHttpInfo(name, slideIndex, slideType, sequenceIndex, effectIndex, effect, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Modify an animation effect for a special slide (master, layout, notes) interactive sequence.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;SlideAnimation&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<SlideAnimation> updateSpecialSlideAnimationInteractiveSequenceEffectWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Integer effectIndex, Effect effect, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSpecialSlideAnimationInteractiveSequenceEffectCall(name, slideIndex, slideType, sequenceIndex, effectIndex, effect, password, folder, storage, null, null);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Modify an animation effect for a special slide (master, layout, notes) interactive sequence. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param sequenceIndex The position of the interactive sequence. (required)
     * @param effectIndex The position of the effect to be modified. (required)
     * @param effect Animation effect DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideAnimationInteractiveSequenceEffectAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer sequenceIndex, Integer effectIndex, Effect effect, String password, String folder, String storage, final ApiCallback<SlideAnimation> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSpecialSlideAnimationInteractiveSequenceEffectCall(name, slideIndex, slideType, sequenceIndex, effectIndex, effect, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<SlideAnimation>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSpecialSlideParagraph
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideParagraphCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling updateSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling updateSpecialSlideParagraph(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateSpecialSlideParagraph(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update paragraph properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph updateSpecialSlideParagraph(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = updateSpecialSlideParagraphWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = updateSpecialSlideParagraphWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update paragraph properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> updateSpecialSlideParagraphWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSpecialSlideParagraphCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update paragraph properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideParagraphAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSpecialSlideParagraphCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSpecialSlidePortion
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlidePortionCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling updateSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling updateSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling updateSpecialSlidePortion(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateSpecialSlidePortion(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update portion properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion updateSpecialSlidePortion(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = updateSpecialSlidePortionWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = updateSpecialSlidePortionWithHttpInfo(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update portion properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> updateSpecialSlidePortionWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSpecialSlidePortionCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update portion properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlidePortionAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSpecialSlidePortionCall(name, slideIndex, slideType, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSpecialSlideShape
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideShapeCall(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSpecialSlideShape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling updateSpecialSlideShape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateSpecialSlideShape(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateSpecialSlideShape(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update shape properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase updateSpecialSlideShape(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = updateSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, shapeIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = updateSpecialSlideShapeWithHttpInfo(name, slideIndex, slideType, shapeIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update shape properties.
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> updateSpecialSlideShapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSpecialSlideShapeCall(name, slideIndex, slideType, shapeIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update shape properties. (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideShapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSpecialSlideShapeCall(name, slideIndex, slideType, shapeIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSpecialSlideSubshape
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideSubshapeCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling updateSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateSpecialSlideSubshape(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateSpecialSlideSubshape(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update shape properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase updateSpecialSlideSubshape(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = updateSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = updateSpecialSlideSubshapeWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update shape properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> updateSpecialSlideSubshapeWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSpecialSlideSubshapeCall(name, slideIndex, slideType, path, shapeIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update shape properties (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideSubshapeAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSpecialSlideSubshapeCall(name, slideIndex, slideType, path, shapeIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSpecialSlideSubshapeParagraph
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideSubshapeParagraphCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling updateSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling updateSpecialSlideSubshapeParagraph(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateSpecialSlideSubshapeParagraph(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update paragraph properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph updateSpecialSlideSubshapeParagraph(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = updateSpecialSlideSubshapeParagraphWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = updateSpecialSlideSubshapeParagraphWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update paragraph properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> updateSpecialSlideSubshapeParagraphWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSpecialSlideSubshapeParagraphCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update paragraph properties (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideSubshapeParagraphAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSpecialSlideSubshapeParagraphCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSpecialSlideSubshapePortion
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideSubshapePortionCall(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'slideType' is set
        if (slideType == null) {
            throw new ApiException("Missing the required parameter 'slideType' when calling updateSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling updateSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling updateSpecialSlideSubshapePortion(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateSpecialSlideSubshapePortion(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/{slideType}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "slideType" + "\\}", apiClient.objectToString(slideType)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update portion properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion updateSpecialSlideSubshapePortion(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = updateSpecialSlideSubshapePortionWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = updateSpecialSlideSubshapePortionWithHttpInfo(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update portion properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> updateSpecialSlideSubshapePortionWithHttpInfo(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSpecialSlideSubshapePortionCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update portion properties (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Parent slide index. (required)
     * @param slideType Slide type (master, layout or notes). (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSpecialSlideSubshapePortionAsync(String name, Integer slideIndex, SpecialSlideType slideType, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSpecialSlideSubshapePortionCall(name, slideIndex, slideType, path, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSubshape
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSubshapeCall(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSubshape(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSubshape(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateSubshape(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateSubshape(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update shape properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ShapeBase
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ShapeBase updateSubshape(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<ShapeBase> resp = updateSubshapeWithHttpInfo(name, slideIndex, path, shapeIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<ShapeBase> resp = updateSubshapeWithHttpInfo(name, slideIndex, path, shapeIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update shape properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;ShapeBase&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<ShapeBase> updateSubshapeWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSubshapeCall(name, slideIndex, path, shapeIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update shape properties (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param dto Shape DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSubshapeAsync(String name, Integer slideIndex, String path, Integer shapeIndex, ShapeBase dto, String password, String folder, String storage, final ApiCallback<ShapeBase> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSubshapeCall(name, slideIndex, path, shapeIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<ShapeBase>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSubshapeParagraph
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSubshapeParagraphCall(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSubshapeParagraph(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSubshapeParagraph(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateSubshapeParagraph(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling updateSubshapeParagraph(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateSubshapeParagraph(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update paragraph properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Paragraph
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Paragraph updateSubshapeParagraph(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Paragraph> resp = updateSubshapeParagraphWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Paragraph> resp = updateSubshapeParagraphWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update paragraph properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Paragraph&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Paragraph> updateSubshapeParagraphWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSubshapeParagraphCall(name, slideIndex, path, shapeIndex, paragraphIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update paragraph properties (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param dto Paragraph DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSubshapeParagraphAsync(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Paragraph dto, String password, String folder, String storage, final ApiCallback<Paragraph> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSubshapeParagraphCall(name, slideIndex, path, shapeIndex, paragraphIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Paragraph>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for updateSubshapePortion
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call updateSubshapePortionCall(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'name' is set
        if (name == null) {
            throw new ApiException("Missing the required parameter 'name' when calling updateSubshapePortion(Async)");
        }
        // verify the required parameter 'slideIndex' is set
        if (slideIndex == null) {
            throw new ApiException("Missing the required parameter 'slideIndex' when calling updateSubshapePortion(Async)");
        }
        // verify the required parameter 'shapeIndex' is set
        if (shapeIndex == null) {
            throw new ApiException("Missing the required parameter 'shapeIndex' when calling updateSubshapePortion(Async)");
        }
        // verify the required parameter 'paragraphIndex' is set
        if (paragraphIndex == null) {
            throw new ApiException("Missing the required parameter 'paragraphIndex' when calling updateSubshapePortion(Async)");
        }
        // verify the required parameter 'portionIndex' is set
        if (portionIndex == null) {
            throw new ApiException("Missing the required parameter 'portionIndex' when calling updateSubshapePortion(Async)");
        }
        // verify the required parameter 'dto' is set
        if (dto == null) {
            throw new ApiException("Missing the required parameter 'dto' when calling updateSubshapePortion(Async)");
        }
        Object postBody = dto;

        // create path and map variables
        String methodPath = "/slides/{name}/slides/{slideIndex}/shapes/{path}/{shapeIndex}/paragraphs/{paragraphIndex}/portions/{portionIndex}"
            .replaceAll("\\{" + "name" + "\\}", apiClient.objectToString(name)).replaceAll("\\{" + "slideIndex" + "\\}", apiClient.objectToString(slideIndex)).replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path)).replaceAll("\\{" + "shapeIndex" + "\\}", apiClient.objectToString(shapeIndex)).replaceAll("\\{" + "paragraphIndex" + "\\}", apiClient.objectToString(paragraphIndex)).replaceAll("\\{" + "portionIndex" + "\\}", apiClient.objectToString(portionIndex));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "folder", folder);
        apiClient.addQueryParameter(queryParams, "storage", storage);

        Map<String, String> headerParams = new HashMap<String, String>();
        if (password != null)
        headerParams.put("password", apiClient.parameterToString(password));

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "application/json"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Update portion properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return Portion
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public Portion updateSubshapePortion(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage) throws ApiException {
        try {
            ApiResponse<Portion> resp = updateSubshapePortionWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<Portion> resp = updateSubshapePortionWithHttpInfo(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage);
            return resp.getData();
        }
    }

    /**
     * Update portion properties (for smart art and group shapes).
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @return ApiResponse&lt;Portion&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<Portion> updateSubshapePortionWithHttpInfo(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage) throws ApiException {
        com.squareup.okhttp.Call call = updateSubshapePortionCall(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage, null, null);
        Type returnType = new TypeToken<Portion>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Update portion properties (for smart art and group shapes). (asynchronously)
     * 
     * @param name Document name. (required)
     * @param slideIndex Slide index. (required)
     * @param path Shape path. 
     * @param shapeIndex Shape index. (required)
     * @param paragraphIndex Paragraph index. (required)
     * @param portionIndex Portion index. (required)
     * @param dto Portion DTO. (required)
     * @param password Document password. 
     * @param folder Document folder. 
     * @param storage Document storage. 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call updateSubshapePortionAsync(String name, Integer slideIndex, String path, Integer shapeIndex, Integer paragraphIndex, Integer portionIndex, Portion dto, String password, String folder, String storage, final ApiCallback<Portion> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = updateSubshapePortionCall(name, slideIndex, path, shapeIndex, paragraphIndex, portionIndex, dto, password, folder, storage, progressListener, progressRequestListener);
        Type returnType = new TypeToken<Portion>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }
    /**
     * Build call for uploadFile
     * @param path Path where to upload including filename and extension e.g. /file.ext or /Folder 1/file.ext             If the content is multipart and path does not contains the file name it tries to get them from filename parameter             from Content-Disposition header.              
     * @param file File to upload (required)
     * @param storageName Storage name 
     * @param progressListener Progress listener
     * @param progressRequestListener Progress request listener
     * @return Call to execute
     * @throws ApiException If fail to serialize the request body object
     */
    public com.squareup.okhttp.Call uploadFileCall(String path, byte[] file, String storageName, final ProgressResponseBody.ProgressListener progressListener, final ProgressRequestBody.ProgressRequestListener progressRequestListener) throws ApiException {
        // verify the required parameter 'file' is set
        if (file == null) {
            throw new ApiException("Missing the required parameter 'file' when calling uploadFile(Async)");
        }
        Object postBody = null;

        // create path and map variables
        String methodPath = "/slides/storage/file/{path}"
            .replaceAll("\\{" + "path" + "\\}", apiClient.objectToString(path));

        List<Pair> queryParams = new ArrayList<Pair>();
        apiClient.addQueryParameter(queryParams, "storageName", storageName);

        Map<String, String> headerParams = new HashMap<String, String>();

        Map<String, Object> formParams = new LinkedHashMap<String, Object>();
        if (file != null)
        formParams.put("file", file);

        final String[] accepts = {
            "application/json"
        };
        final String accept = apiClient.selectHeaderAccept(accepts);
        if (accept != null) headerParams.put("Accept", accept);

        final String[] contentTypes = {
            "multipart/form-data"
        };
        final String contentType = apiClient.selectHeaderContentType(contentTypes);
        headerParams.put("Content-Type", contentType);

        if(progressListener != null) {
            apiClient.getHttpClient().networkInterceptors().add(new com.squareup.okhttp.Interceptor() {
                @Override
                public com.squareup.okhttp.Response intercept(com.squareup.okhttp.Interceptor.Chain chain) throws IOException {
                    com.squareup.okhttp.Response originalResponse = chain.proceed(chain.request());
                    return originalResponse.newBuilder()
                    .body(new ProgressResponseBody(originalResponse.body(), progressListener))
                    .build();
                }
            });
        }
        return apiClient.buildCall(methodPath, "PUT", queryParams, postBody, headerParams, formParams, progressRequestListener);
    }

    /**
     * Upload file
     * 
     * @param path Path where to upload including filename and extension e.g. /file.ext or /Folder 1/file.ext             If the content is multipart and path does not contains the file name it tries to get them from filename parameter             from Content-Disposition header.              
     * @param file File to upload (required)
     * @param storageName Storage name 
     * @return FilesUploadResult
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public FilesUploadResult uploadFile(String path, byte[] file, String storageName) throws ApiException {
        try {
            ApiResponse<FilesUploadResult> resp = uploadFileWithHttpInfo(path, file, storageName);
            return resp.getData();
        } catch (NeedRepeatRequestException e) {
            ApiResponse<FilesUploadResult> resp = uploadFileWithHttpInfo(path, file, storageName);
            return resp.getData();
        }
    }

    /**
     * Upload file
     * 
     * @param path Path where to upload including filename and extension e.g. /file.ext or /Folder 1/file.ext             If the content is multipart and path does not contains the file name it tries to get them from filename parameter             from Content-Disposition header.              
     * @param file File to upload (required)
     * @param storageName Storage name 
     * @return ApiResponse&lt;FilesUploadResult&gt;
     * @throws ApiException If fail to call the API, e.g. server error or cannot deserialize the response body
     */
    public ApiResponse<FilesUploadResult> uploadFileWithHttpInfo(String path, byte[] file, String storageName) throws ApiException {
        com.squareup.okhttp.Call call = uploadFileCall(path, file, storageName, null, null);
        Type returnType = new TypeToken<FilesUploadResult>(){}.getType();
        return apiClient.execute(call, returnType);
    }

    /**
     * Upload file (asynchronously)
     * 
     * @param path Path where to upload including filename and extension e.g. /file.ext or /Folder 1/file.ext             If the content is multipart and path does not contains the file name it tries to get them from filename parameter             from Content-Disposition header.              
     * @param file File to upload (required)
     * @param storageName Storage name 
     * @param callback The callback to be executed when the API call finishes
     * @return The request call
     * @throws ApiException If fail to process the API call, e.g. serializing the request body object
     */
    public com.squareup.okhttp.Call uploadFileAsync(String path, byte[] file, String storageName, final ApiCallback<FilesUploadResult> callback) throws ApiException {

        ProgressResponseBody.ProgressListener progressListener = null;
        ProgressRequestBody.ProgressRequestListener progressRequestListener = null;

        if (callback != null) {
            progressListener = new ProgressResponseBody.ProgressListener() {
                @Override
                public void update(long bytesRead, long contentLength, boolean done) {
                    callback.onDownloadProgress(bytesRead, contentLength, done);
                }
            };

            progressRequestListener = new ProgressRequestBody.ProgressRequestListener() {
                @Override
                public void onRequestProgress(long bytesWritten, long contentLength, boolean done) {
                    callback.onUploadProgress(bytesWritten, contentLength, done);
                }
            };
        }

        com.squareup.okhttp.Call call = uploadFileCall(path, file, storageName, progressListener, progressRequestListener);
        Type returnType = new TypeToken<FilesUploadResult>(){}.getType();
        apiClient.executeAsync(call, returnType, callback);
        return call;
    }

    private final ApiClient apiClient;
}
